(***********************************************************************



                    Mathematica-Compatible Notebook



This notebook can be used on any computer system with Mathematica 3.0,

MathReader 3.0, or any compatible application. The data for the notebook 

starts with the line of stars above.



To get the notebook into a Mathematica-compatible application, do one of 

the following:



* Save the data starting with the line of stars above into a file

  with a name ending in .nb, then open the file inside the application;



* Copy the data starting with the line of stars above to the

  clipboard, then use the Paste menu command inside the application.



Data for notebooks contains only printable 7-bit ASCII and can be

sent directly in email or through ftp in text mode.  Newlines can be

CR, LF or CRLF (Unix, Macintosh or MS-DOS style).



NOTE: If you modify the data for this notebook not in a Mathematica-

compatible application, you must delete the line below containing the 

word CacheID, otherwise Mathematica-compatible applications may try to 

use invalid cache data.



For more information on notebooks and Mathematica-compatible 

applications, contact Wolfram Research:

  web: http://www.wolfram.com

  email: info@wolfram.com

  phone: +1-217-398-0700 (U.S.)



Notebook reader applications are available free of charge from 

Wolfram Research.

***********************************************************************)



(*CacheID: 232*)





(*NotebookFileLineBreakTest

NotebookFileLineBreakTest*)

(*NotebookOptionsPosition[    271235,       9708]*)

(*NotebookOutlinePosition[    272186,       9740]*)

(*  CellTagsIndexPosition[    272142,       9736]*)

(*WindowFrame->Normal*)







Notebook[{

Cell[TextData[StyleBox["Example # 2 : ESRF Superconducting Wiggler",

  FontSize->24]], "Title",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["Version : 0.3", "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell["Introduction", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[{

  StyleBox[

  "This example consists in the creation of a set of racetrack and circular \

coils, plotting the coil geometry and the magnetic field produced. This \

geometry corresponds to a 4T superconducting wiggler presently in operation   \

at the ESRF. It is assumed that the reader has some experience with ",

    Evaluatable->False,

    AspectRatioFixed->True],

  StyleBox["Mathematica ",

    Evaluatable->False,

    AspectRatioFixed->True,

    FontSlant->"Italic"],

  StyleBox[" and that he has successfully run Example#1.",

    Evaluatable->False,

    AspectRatioFixed->True],

  "\n",

  StyleBox[

  "Evaluate sections in the order of presentation: \"Load and Initialize \

Radia\" followed by \"Build the Geometry\", \"",

    Evaluatable->False,

    AspectRatioFixed->True],

  "Display the Geometry with QuickDraw 3D",

  StyleBox[

  "\", \"Plot the Geometry\", \"Plot the Magnetic Field\" and \"Plot the \

Field Integrals\".",

    Evaluatable->False,

    AspectRatioFixed->True],

  "\n",

  StyleBox[

  "If successful, try to modify some parameters (see the Reference Guide for \

the explanations on the ",

    Evaluatable->False,

    AspectRatioFixed->True],

  StyleBox["Radia",

    Evaluatable->False,

    AspectRatioFixed->True,

    FontSlant->"Italic"],

  StyleBox[

  " functions) and re-execute the corresponding section. All sections must be \

evaluated in the order of presentation. A section may be evaluated several   \

times with the same or different parameters if the previous sections have \

been evaluated before. The only limitation is memory. The Radia.exe memory \

can be re-initialized by re-executing the section entitled \"Load and   \

Initialize Radia\". The Kernel memory can be re-initialized by calling Exit[] \

and then re-executing all sections of this example. If the Front-End is   \

running out of memory, close some windows or close the Front-End and start it \

again. Note that if by mistake any section is executed before the previous \

ones are executed, it may be necessary to exit the Kernel and re-start \

everything from the very beginning.",

    Evaluatable->False,

    AspectRatioFixed->True]

}], "Text",

  Evaluatable->False,

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData["Load and Initialize Radia"], "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"The following instruction loads the Radia package and returns the Radia \

version number.",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["<<Radia`;", "Input",

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell["Build the Geometry", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"These instructions define 4 racetrack coils and one circular coil together \

with their mirror symmetric counterparts. j1 and j2 are current densities in \

the coils.",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["\<\

RadUtiMem[];



(* Current Densities in A/mm^2 *)

j1=128;j2=256;



(* Coil Presentation Parameters *)

n1=3;n2=6;c2={1,0,0};c1={0,1,1};thcn=0.001;



(* Create 5 Coils *)

Rt1=radObjRaceTrk[{0.,0.,38.},{9.5,24.5},{120.,0.},36,n1,j1];

radObjDrwAtr[Rt1,c1,thcn];

Rt3=radObjRaceTrk[{0.,0.,76.},{10.,25.},{90.,0.},24,n1,j1];

radObjDrwAtr[Rt3,c1,thcn];

Rt2=radObjRaceTrk[{0.,0.,38.},{24.5,55.5},{120.,0.},36,n1,j2];

radObjDrwAtr[Rt2,c2,thcn];

Rt4=radObjRaceTrk[{0.,0.,76.},{25.,55.},{90.,0.},24,n1,j2];

radObjDrwAtr[Rt4,c2,thcn];

Rt5=radObjRaceTrk[{0.,0.,60.},{150.,166.3},{0.,0.},39,n2,-j2];

radObjDrwAtr[Rt5,c2,thcn];



Grp=radObjCnt[{ Rt1,Rt2,Rt3,Rt4,Rt5}];



(* Define Mirror Coils *)

RadTrfZerPara[Grp,{0,0,0},{0,0,1}];\

\>", "Input",

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell["Display the Geometry with QuickDraw 3D", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[{

  StyleBox[

  "If you have QuickDraw 3D installed on your platform (freely available for  \

PC and Macs from  Apple at \"",

    Evaluatable->False,

    AspectRatioFixed->True],

  StyleBox["http://www.apple.com/quicktime/qd3d/\" ",

    FontFamily->"Monaco",

    FontSize->9],

  StyleBox[

  ") , execute the following line to display the geometry in a dedicated \

window where you will be able to zoom, rotate etc... When you have finished, \

Quit from the Menu File of Radia.exe (for Macs) or Exit from the Menu File of \

the Viewer window (for PC) to release the memory required by QuickDraw3D and \

continue working in ",

    Evaluatable->False,

    AspectRatioFixed->True],

  StyleBox["Mathematica",

    Evaluatable->False,

    AspectRatioFixed->True,

    FontSlant->"Italic"],

  StyleBox[". ",

    Evaluatable->False,

    AspectRatioFixed->True]

}], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell["radObjDrwQD3D[Grp];", "Input",

  AspectRatioFixed->True]

}, Open  ]],



Cell[CellGroupData[{



Cell[TextData["Plot the Geometry"], "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"These instructions plot the geometry of coils previously created.",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell["\<\

(* Special Options for the Plot[]*)

RadPlot3DOptions[];



(* Save the Geometry in \"dr\" *)

dr=radObjDrw[Grp];



(* Draw the Geometry *)

Show[Graphics3D[dr

,PlotLabel->FontForm[\"SCW\",{\"Times\",14}]

,DefaultFont -> {\"Times\",10}]];\

\>", "Input",

  AspectRatioFixed->True],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: 1 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics3D

/Times findfont 10  scalefont  setfont

% Scaling calculations

0 1 0 1 [

[.5 1.0125 -17.5 0 ]

[.5 1.0125 17.5 15 ]

[.67549 .76518 -12.7076 0 ]

[.67549 .76518 13.2924 15 ]

[.77455 .72368 -4.34079 0 ]

[.77455 .72368 4.65921 15 ]

[.88457 .67759 -9.02638 0 ]

[.88457 .67759 9.97362 15 ]

[.77675 .78615 -6.75234 0 ]

[.77675 .78615 7.24766 15 ]

[.4996 .16081 -12.9993 -15 ]

[.4996 .16081 13.0007 0 ]

[.6742 .20658 -4.60823 -15 ]

[.6742 .20658 4.39177 0 ]

[.83751 .24939 -9.9401 -15 ]

[.83751 .24939 9.0599 0 ]

[.6727 .14409 -7.16836 -15 ]

[.6727 .14409 6.83164 0 ]

[.97016 .36933 0 -5.65233 ]

[.97016 .36933 21 9.34767 ]

[.97576 .45869 0 -5.79093 ]

[.97576 .45869 9 9.20907 ]

[.98148 .55022 0 -5.93326 ]

[.98148 .55022 14 9.06674 ]

[1.03669 .47257 0 -5.79093 ]

[1.03669 .47257 13 9.20907 ]

[ 0 0 0 0 ]

[ 1 1 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

gsave

.5 1.0125 -78.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 14.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 14.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(SCW) show

93.250000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 14.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.003 w

.60761 .78104 m

.97417 .62726 L

s

.25 Mabswid

.67521 .75268 m

.67507 .74643 L

s

gsave

.67549 .76518 -73.7076 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

69.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(100) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.7741 .71119 m

.77388 .70495 L

s

gsave

.77455 .72368 -65.3408 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.88395 .66511 m

.88364 .65887 L

s

gsave

.88457 .67759 -70.0264 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(100) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.69419 .74472 m

.6941 .74097 L

s

.71356 .73659 m

.71346 .73284 L

s

.73333 .7283 m

.73321 .72455 L

s

.7535 .71983 m

.75338 .71609 L

s

.79514 .70237 m

.795 .69862 L

s

.81663 .69335 m

.81647 .68961 L

s

.83858 .68414 m

.83842 .6804 L

s

.86102 .67473 m

.86084 .67098 L

s

.6566 .76049 m

.65653 .75674 L

s

.63836 .76814 m

.63829 .76439 L

s

.62047 .77564 m

.62041 .7719 L

s

.90739 .65527 m

.90719 .65153 L

s

.93137 .64522 m

.93116 .64147 L

s

.95589 .63493 m

.95567 .63118 L

s

gsave

.77675 .78615 -67.7523 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

72.562500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.003 w

.36102 .13705 m

.95343 .29205 L

s

.25 Mabswid

.4996 .17331 m

.4996 .17956 L

s

gsave

.4996 .16081 -73.9993 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

69.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(100) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.6745 .21907 m

.67465 .22532 L

s

gsave

.6742 .20658 -65.6082 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.83809 .26188 m

.83838 .26812 L

s

gsave

.83751 .24939 -70.9401 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(100) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.53554 .18271 m

.53556 .18646 L

s

.57099 .19199 m

.57103 .19574 L

s

.60596 .20114 m

.60602 .20489 L

s

.64046 .21017 m

.64053 .21391 L

s

.70809 .22786 m

.70819 .23161 L

s

.74123 .23653 m

.74136 .24028 L

s

.77394 .24509 m

.77408 .24884 L

s

.80623 .25354 m

.80638 .25728 L

s

.46316 .16377 m

.46314 .16752 L

s

.42621 .15411 m

.42617 .15786 L

s

.38874 .1443 m

.38868 .14805 L

s

.86955 .27011 m

.86974 .27385 L

s

.90061 .27823 m

.90081 .28198 L

s

.93127 .28626 m

.93149 .29 L

s

gsave

.6727 .14409 -68.1684 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Y) show

72.562500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.003 w

.95343 .29205 m

.97417 .62726 L

s

.25 Mabswid

.95803 .36634 m

.95196 .36485 L

s

gsave

.97016 .36933 -61 -9.65233 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

69.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(50) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.96357 .45591 m

.95748 .45452 L

s

gsave

.97576 .45869 -61 -9.79093 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.96925 .54767 m

.96313 .54639 L

s

gsave

.98148 .55022 -61 -9.93326 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(50) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.95913 .38409 m

.95548 .3832 L

s

.96023 .40191 m

.95658 .40104 L

s

.96134 .41982 m

.95769 .41897 L

s

.96245 .43782 m

.9588 .43698 L

s

.96469 .47408 m

.96103 .47326 L

s

.96582 .49234 m

.96216 .49154 L

s

.96696 .5107 m

.96329 .5099 L

s

.9681 .52914 m

.96443 .52836 L

s

.95694 .34869 m

.9533 .34778 L

s

.95585 .33112 m

.95221 .33019 L

s

.95477 .31363 m

.95113 .31269 L

s

.95369 .29622 m

.95006 .29527 L

s

.9704 .56629 m

.96673 .56554 L

s

.97156 .585 m

.96788 .58426 L

s

.97272 .60381 m

.96904 .60308 L

s

.97389 .62271 m

.97021 .622 L

s

gsave

1.03669 .47257 -61 -9.79093 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Z) show

71.500000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.001 w

[ .01 .01 ] 0 setdash

.08119 .3876 m

.06355 .70016 L

s

.06355 .70016 m

.60761 .78104 L

s

.60761 .78104 m

.60367 .49439 L

s

.60367 .49439 m

.08119 .3876 L

s

.36102 .13705 m

.95343 .29205 L

s

.95343 .29205 m

.97417 .62726 L

s

.97417 .62726 m

.35383 .5079 L

s

.35383 .5079 m

.36102 .13705 L

s

.08119 .3876 m

.06355 .70016 L

s

.06355 .70016 m

.35383 .5079 L

s

.35383 .5079 m

.36102 .13705 L

s

.36102 .13705 m

.08119 .3876 L

s

.60367 .49439 m

.95343 .29205 L

s

.95343 .29205 m

.97417 .62726 L

s

.97417 .62726 m

.60761 .78104 L

s

.60761 .78104 m

.60367 .49439 L

s

0 0 m

1 0 L

1 1 L

0 1 L

closepath

clip

newpath

.50123 .47253 m .4288 .5305 L .50124 .53361 L .825 0 0 r

F

.50123 .47253 m .42937 .46926 L .4288 .5305 L F

.50112 .46273 m .42937 .46926 L .50123 .47253 L .722 0 0 r

F

.57303 .46903 m .50123 .47253 L .50124 .53361 L .783 0 0 r

F

.56646 .45952 m .50123 .47253 L .57303 .46903 L .722 0 0 r

F

.56646 .45952 m .50112 .46273 L .50123 .47253 L F

.42937 .46926 m .3599 .52105 L .4288 .5305 L .865 0 0 r

F

.42937 .46926 m .36105 .45932 L .3599 .52105 L F

.43573 .45973 m .36105 .45932 L .42937 .46926 L .722 0 0 r

F

.50112 .46273 m .43573 .45973 L .42937 .46926 L F

0 g

[ ] 0 setdash

.42937 .46926 m

.50123 .47253 L

s

.57303 .46903 m .50124 .53361 L .57363 .53028 L .783 0 0 r

F

.64117 .45887 m .57303 .46903 L .57363 .53028 L .737 0 0 r

F

.62835 .4502 m .57303 .46903 L .64117 .45887 L .722 0 0 r

F

.62835 .4502 m .56646 .45952 L .57303 .46903 L F

0 g

.50123 .47253 m

.57303 .46903 L

s

.50113 .52429 m .50124 .53361 L .4288 .5305 L .712 0 0 r

F

.567 .52124 m .50124 .53361 L .50113 .52429 L F

.567 .52124 m .57363 .53028 L .50124 .53361 L F

.50112 .46273 m .4352 .52144 L .43573 .45973 L .825 0 0 r

F

.50112 .46273 m .50113 .52429 L .4352 .52144 L F

.56646 .45952 m .50113 .52429 L .50112 .46273 L .783 0 0 r

F

.4352 .52144 m .4288 .5305 L .3599 .52105 L .712 0 0 r

F

.50113 .52429 m .4288 .5305 L .4352 .52144 L F

0 g

.4288 .5305 m

.50124 .53361 L

s

.64117 .45887 m .57363 .53028 L .64233 .52062 L .737 0 0 r

F

.62942 .51238 m .57363 .53028 L .567 .52124 L .712 0 0 r

F

.62942 .51238 m .64233 .52062 L .57363 .53028 L F

0 g

.50124 .53361 m

.57363 .53028 L

s

.43573 .45973 m .37366 .45062 L .36105 .45932 L .722 0 0 r

F

.43573 .45973 m .37261 .51277 L .37366 .45062 L .866 0 0 r

F

0 g

.42513 .46864 m

.42937 .46926 L

s

.43573 .45973 m .4352 .52144 L .37261 .51277 L .866 0 0 r

F

0 g

.43573 .45973 m

.50112 .46273 L

s

.56646 .45952 m .567 .52124 L .50113 .52429 L .783 0 0 r

F

.62835 .4502 m .567 .52124 L .56646 .45952 L .736 0 0 r

F

0 g

.50112 .46273 m

.56646 .45952 L

s

.37366 .45062 m .3599 .52105 L .36105 .45932 L .466 0 0 r

F

0 g

.37166 .46086 m

.37348 .46113 L

s

.36105 .45932 m .29821 .50557 L .3599 .52105 L .91 0 0 r

F

.36105 .45932 m .29989 .44305 L .29821 .50557 L F

.37366 .45062 m .29989 .44305 L .36105 .45932 L .722 0 0 r

F

.37366 .45062 m .36105 .45932 L .3599 .52105 L .466 0 0 r

F

.70202 .44239 m .64117 .45887 L .64233 .52062 L .679 0 0 r

F

.68343 .43512 m .64117 .45887 L .70202 .44239 L .722 0 0 r

F

.68343 .43512 m .62835 .4502 L .64117 .45887 L F

0 g

.61787 .46234 m

.64117 .45887 L

s

.4352 .52144 m .3599 .52105 L .37261 .51277 L .712 0 0 r

F

0 g

.4352 .52144 m

.50113 .52429 L

s

.37366 .45062 m .37261 .51277 L .3599 .52105 L .466 0 0 r

F

.37366 .45062 m .3183 .43572 L .29989 .44305 L .722 0 0 r

F

.37366 .45062 m .31677 .49861 L .3183 .43572 L .911 0 0 r

F

.37366 .45062 m .3599 .52105 L .37261 .51277 L .466 0 0 r

F

.37366 .45062 m .37261 .51277 L .31677 .49861 L .911 0 0 r

F

0 g

.37366 .45062 m

.43573 .45973 L

s

.62835 .4502 m .62942 .51238 L .567 .52124 L .736 0 0 r

F

0 g

.50113 .52429 m

.567 .52124 L

s

.37261 .51277 m .3599 .52105 L .29821 .50557 L .712 0 0 r

F

0 g

.3599 .52105 m

.4288 .5305 L

s

.36008 .51156 m

.36012 .5096 L

s

.68343 .43512 m .62942 .51238 L .62835 .4502 L .677 0 0 r

F

0 g

.56646 .45952 m

.62835 .4502 L

s

.70202 .44239 m .64233 .52062 L .70371 .50495 L .679 0 0 r

F

.68497 .49803 m .64233 .52062 L .62942 .51238 L .712 0 0 r

F

.68497 .49803 m .70371 .50495 L .64233 .52062 L F

0 g

.57363 .53028 m

.64233 .52062 L

s

.50126 .66369 m .42696 .72536 L .50127 .72793 L .825 0 0 r

F

.50126 .66369 m .42757 .66094 L .42696 .72536 L F

.50115 .65544 m .42757 .66094 L .50126 .66369 L .685 0 0 r

F

.5749 .66074 m .50126 .66369 L .50127 .72793 L .783 0 0 r

F

.56817 .65273 m .50126 .66369 L .5749 .66074 L .685 0 0 r

F

.56817 .65273 m .50115 .65544 L .50126 .66369 L F

.29989 .44305 m .2474 .48464 L .29821 .50557 L .964 0 0 r

F

.29989 .44305 m .24954 .42104 L .2474 .48464 L F

.3183 .43572 m .24954 .42104 L .29989 .44305 L .722 0 0 r

F

0 g

.29989 .44305 m

.318 .44787 L

s

.75194 .4202 m .70202 .44239 L .70371 .50495 L .594 0 0 r

F

.72832 .41488 m .70202 .44239 L .75194 .4202 L .722 0 0 r

F

.72832 .41488 m .68343 .43512 L .70202 .44239 L F

0 g

.67281 .4503 m

.70202 .44239 L

s

.42757 .66094 m .35626 .71753 L .42696 .72536 L .865 0 0 r

F

.42757 .66094 m .35747 .65256 L .35626 .71753 L F

.43407 .65291 m .35747 .65256 L .42757 .66094 L .685 0 0 r

F

.50115 .65544 m .43407 .65291 L .42757 .66094 L F

0 g

.42757 .66094 m

.50126 .66369 L

s

.5749 .66074 m .50127 .72793 L .57552 .72517 L .783 0 0 r

F

.64481 .65218 m .5749 .66074 L .57552 .72517 L .737 0 0 r

F

.63169 .64487 m .5749 .66074 L .64481 .65218 L .685 0 0 r

F

.63169 .64487 m .56817 .65273 L .5749 .66074 L F

0 g

.50126 .66369 m

.5749 .66074 L

s

.37261 .51277 m .29821 .50557 L .31677 .49861 L .712 0 0 r

F

0 g

.37261 .51277 m

.37366 .45062 L

s

.37261 .51277 m

.4352 .52144 L

s

.3599 .52105 m

.37261 .51277 L

s

.68343 .43512 m .68497 .49803 L .62942 .51238 L .677 0 0 r

F

0 g

.567 .52124 m

.62942 .51238 L

s

.50116 .72022 m .50127 .72793 L .42696 .72536 L .669 0 0 r

F

.56874 .71768 m .50127 .72793 L .50116 .72022 L F

.56874 .71768 m .57552 .72517 L .50127 .72793 L F

.3183 .43572 m .273 .41564 L .24954 .42104 L .722 0 0 r

F

.3183 .43572 m .27106 .4795 L .273 .41564 L .966 0 0 r

F

.3183 .43572 m .31677 .49861 L .27106 .4795 L F

0 g

.3183 .43572 m

.37366 .45062 L

s

.72832 .41488 m .68497 .49803 L .68343 .43512 L .591 0 0 r

F

0 g

.62835 .4502 m

.68343 .43512 L

s

.50115 .65544 m .43352 .71785 L .43407 .65291 L .825 0 0 r

F

.50115 .65544 m .50116 .72022 L .43352 .71785 L F

.56817 .65273 m .50116 .72022 L .50115 .65544 L .783 0 0 r

F

.31677 .49861 m .29821 .50557 L .2474 .48464 L .712 0 0 r

F

0 g

.29821 .50557 m

.3599 .52105 L

s

.75194 .4202 m .70371 .50495 L .75409 .48384 L .594 0 0 r

F

.73028 .47878 m .70371 .50495 L .68497 .49803 L .712 0 0 r

F

.73028 .47878 m .75409 .48384 L .70371 .50495 L F

0 g

.64233 .52062 m

.70371 .50495 L

s

.43352 .71785 m .42696 .72536 L .35626 .71753 L .669 0 0 r

F

.50116 .72022 m .42696 .72536 L .43352 .71785 L F

0 g

.42696 .72536 m

.50127 .72793 L

s

.64481 .65218 m .57552 .72517 L .64604 .71717 L .737 0 0 r

F

.63281 .71034 m .57552 .72517 L .56874 .71768 L .669 0 0 r

F

.63281 .71034 m .64604 .71717 L .57552 .72517 L F

0 g

.50127 .72793 m

.57552 .72517 L

s

.43407 .65291 m .37038 .64522 L .35747 .65256 L .685 0 0 r

F

.43407 .65291 m .36927 .71066 L .37038 .64522 L .866 0 0 r

F

0 g

.42536 .66067 m

.42757 .66094 L

s

.43407 .65291 m .43352 .71785 L .36927 .71066 L .866 0 0 r

F

0 g

.43407 .65291 m

.50115 .65544 L

s

.56817 .65273 m .56874 .71768 L .50116 .72022 L .783 0 0 r

F

.63169 .64487 m .56874 .71768 L .56817 .65273 L .736 0 0 r

F

0 g

.50115 .65544 m

.56817 .65273 L

s

.37038 .64522 m .35626 .71753 L .35747 .65256 L .466 0 0 r

F

0 g

.36868 .6539 m

.37023 .65409 L

s

.35747 .65256 m .29289 .7047 L .35626 .71753 L .91 0 0 r

F

.35747 .65256 m .29465 .63884 L .29289 .7047 L F

.37038 .64522 m .29465 .63884 L .35747 .65256 L .685 0 0 r

F

.37038 .64522 m .35747 .65256 L .35626 .71753 L .466 0 0 r

F

.70732 .63828 m .64481 .65218 L .64604 .71717 L .679 0 0 r

F

.68826 .63215 m .64481 .65218 L .70732 .63828 L .685 0 0 r

F

.68826 .63215 m .63169 .64487 L .64481 .65218 L F

0 g

.62307 .65484 m

.64481 .65218 L

s

.44898 .47414 m .39976 .52839 L .44858 .53271 L .846 0 0 r

F

.44898 .47414 m .40054 .4696 L .39976 .52839 L F

.4478 .45464 m .40054 .4696 L .44898 .47414 L .716 0 0 r

F

.4478 .45464 m .42549 .51216 L .44739 .51413 L 0 .663 .746 r

F

.49687 .46945 m .44898 .47414 L .44858 .53271 L .759 0 0 r

F

.46927 .4525 m .44898 .47414 L .49687 .46945 L .716 0 0 r

F

.46927 .4525 m .4478 .45464 L .44898 .47414 L F

.46927 .4525 m .4478 .45464 L .44739 .51413 L 0 .59 .745 r

F

.4618 .41407 m .41336 .44813 L .4616 .45274 L .846 0 0 r

F

.4618 .41407 m .41381 .40932 L .41336 .44813 L F

.46089 .39414 m .41381 .40932 L .4618 .41407 L .723 0 0 r

F

.50936 .40916 m .4618 .41407 L .4616 .45274 L .759 0 0 r

F

.48284 .39183 m .4618 .41407 L .50936 .40916 L .723 0 0 r

F

.48284 .39183 m .46089 .39414 L .4618 .41407 L F

.31677 .49861 m .2474 .48464 L .27106 .4795 L .712 0 0 r

F

0 g

.31677 .49861 m

.37261 .51277 L

s

.43945 .45729 m .42608 .45257 L .40054 .4696 L .716 0 0 r

F

.42608 .45257 m .42549 .51216 L .39976 .52839 L .466 0 0 r

F

.42608 .45257 m .39976 .52839 L .42549 .51216 L F

.42608 .45257 m .409 .50666 L .42549 .51216 L 0 .744 .732 r

F

.4478 .45464 m .42608 .45257 L .43945 .45729 L .716 0 0 r

F

.4478 .45464 m .42608 .45257 L .42549 .51216 L 0 .663 .746 r

F

.42608 .45257 m .39976 .52839 L .40054 .4696 L .466 0 0 r

F

.40054 .4696 m .36244 .51624 L .39976 .52839 L .941 0 0 r

F

.40054 .4696 m .36352 .45686 L .36244 .51624 L F

.42608 .45257 m .36352 .45686 L .40054 .4696 L .716 0 0 r

F

.42608 .45257 m .40054 .4696 L .39976 .52839 L .466 0 0 r

F

.4522 .39694 m .43874 .3919 L .41381 .40932 L .723 0 0 r

F

.46089 .39414 m .43874 .3919 L .4522 .39694 L F

.43874 .3919 m .41336 .44813 L .41381 .40932 L .466 0 0 r

F

.43874 .3919 m .41381 .40932 L .41336 .44813 L F

.43874 .3919 m .42169 .42518 L .42343 .42581 L 0 .745 .731 r

F

.43874 .3919 m .43841 .43122 L .41336 .44813 L .466 0 0 r

F

.43874 .3919 m .41336 .44813 L .43841 .43122 L F

.43874 .3919 m .42343 .42581 L .43841 .43122 L 0 .745 .731 r

F

.41381 .40932 m .3766 .43516 L .41336 .44813 L .942 0 0 r

F

.46068 .43339 m .4616 .45274 L .41336 .44813 L .718 0 0 r

F

.46068 .43339 m .41336 .44813 L .43841 .43122 L F

.43841 .43122 m .41336 .44813 L .3766 .43516 L F

.41511 .45332 m .40972 .4468 L .36352 .45686 L .716 0 0 r

F

.42608 .45257 m .40972 .4468 L .41511 .45332 L F

.40972 .4468 m .40232 .49903 L .409 .50666 L 0 .875 .618 r

F

.42608 .45257 m .40972 .4468 L .409 .50666 L 0 .744 .732 r

F

0 g

.40054 .4696 m

.40711 .46522 L

s

.49687 .46945 m .44858 .53271 L .49684 .52824 L .759 0 0 r

F

.53236 .45658 m .49687 .46945 L .49684 .52824 L .626 0 0 r

F

.50936 .40916 m .4616 .45274 L .50941 .44797 L .759 0 0 r

F

.48274 .43115 m .50941 .44797 L .4616 .45274 L .718 0 0 r

F

.48494 .44668 m .49687 .46945 L .53236 .45658 L .716 0 0 r

F

.48494 .44668 m .46927 .4525 L .4727 .4546 L F

.48494 .44668 m .4727 .4546 L .49687 .46945 L F

.54471 .39568 m .50936 .40916 L .50941 .44797 L .625 0 0 r

F

.54471 .39568 m .50941 .44797 L .54494 .43489 L F

.49889 .42505 m .50941 .44797 L .48274 .43115 L .718 0 0 r

F

.49889 .42505 m .54494 .43489 L .50941 .44797 L F

.62914 .34044 m .54471 .39568 L .54494 .43489 L p .491 0 0 r

F P

0 g

s

.49889 .42505 m .54494 .43489 L .54471 .39568 L p .894 0 0 r

F P

0 g

s

.4989 .38555 m .50936 .40916 L .54471 .39568 L .723 0 0 r

F

.4989 .38555 m .54471 .39568 L .54494 .43489 L .894 0 0 r

F

.54494 .43489 m .62986 .38124 L .62914 .34044 L p .491 0 0 r

F P

0 g

s

.4989 .38555 m .48284 .39183 L .4863 .39409 L .723 0 0 r

F

.4989 .38555 m .4863 .39409 L .50936 .40916 L F

.58189 .32931 m .4989 .38555 L .4989 .38555 L p 0 .364 .696 r

F P

0 g

s

.4989 .38555 m .54494 .43489 L .49889 .42505 L .894 0 0 r

F

.4989 .38555 m .54471 .39568 L .62914 .34044 L p .723 0 0 r

F P

0 g

s

.54471 .39568 m .4989 .38555 L .49889 .42505 L p .894 0 0 r

F P

0 g

s

.62914 .34044 m .58189 .32931 L .4989 .38555 L p .723 0 0 r

F P

0 g

s

.49889 .42505 m .4989 .38555 L .58189 .32931 L p .478 0 0 r

F P

0 g

s

.4989 .38555 m .49889 .42505 L p .58189 .32931 L 0 .364 .696 r

F P

0 g

s

.48284 .39183 m .46068 .43339 L .48274 .43115 L 0 .589 .745 r

F

.4989 .38555 m .48274 .43115 L .48284 .39183 L .62 0 0 r

F

.4989 .38555 m .48284 .39183 L .48274 .43115 L 0 .478 .728 r

F

.48284 .39183 m .48274 .43115 L .46068 .43339 L .758 0 0 r

F

.4989 .38555 m .49889 .42505 L .48274 .43115 L .62 0 0 r

F

.4989 .38555 m .48274 .43115 L .49889 .42505 L 0 .478 .728 r

F

.47556 .42007 m .49889 .42505 L .4989 .38555 L p 0 .7 .74 r

F P

0 g

s

.48284 .39183 m .46089 .39414 L .46068 .43339 L 0 .589 .745 r

F

.46927 .38296 m .46089 .39414 L .48284 .39183 L 0 .881 1 r

F

.48284 .39183 m .46068 .43339 L .46089 .39414 L .758 0 0 r

F

.47569 .38042 m .48284 .39183 L .4989 .38555 L 0 .881 1 r

F

.47569 .38042 m .46927 .38296 L .48284 .39183 L F

.47569 .38042 m .4989 .38555 L .49889 .42505 L 0 .7 .74 r

F

.47569 .38042 m .49889 .42505 L .47556 .42007 L F

.58189 .32931 m .58235 .37043 L .49889 .42505 L p .478 0 0 r

F P

0 g

s

.49889 .42505 m .58235 .37043 L .58189 .32931 L p 0 .364 .696 r

F P

0 g

s

.58235 .37043 m .49889 .42505 L .47556 .42007 L p 0 .885 1 r

F P

0 g

s

.58189 .32931 m .58189 .32931 L .4989 .38555 L 0 .364 .696 r

F

.62986 .38124 m .54494 .43489 L .49889 .42505 L p .718 0 0 r

F P

0 g

s

.48494 .44668 m .53236 .45658 L .64588 .38576 L p .716 0 0 r

F P

0 g

s

.53236 .45658 m .48494 .44668 L .48482 .50654 L p .893 0 0 r

F P

0 g

s

.53236 .45658 m .49684 .52824 L .53262 .51598 L .626 0 0 r

F

.48494 .44668 m .53236 .45658 L .53262 .51598 L .893 0 0 r

F

.48494 .44668 m .53262 .51598 L .48482 .50654 L F

.49889 .42505 m .58235 .37043 L .62986 .38124 L p .718 0 0 r

F P

0 g

s

.64588 .38576 m .59644 .37452 L .48494 .44668 L p .716 0 0 r

F P

0 g

s

.59644 .37452 m .48494 .44668 L .48482 .50654 L p 0 .364 .696 r

F P

0 g

s

.48494 .44668 m .46927 .4525 L .46903 .51209 L 0 .478 .728 r

F

.64588 .38576 m .53236 .45658 L .53262 .51598 L p .491 0 0 r

F P

0 g

s

.48482 .50654 m .53262 .51598 L .53236 .45658 L p .893 0 0 r

F P

0 g

s

.46927 .4525 m .44739 .51413 L .46903 .51209 L 0 .59 .745 r

F

.46927 .4525 m .46903 .51209 L .44739 .51413 L .758 0 0 r

F

.4478 .45464 m .44739 .51413 L .42549 .51216 L .847 0 0 r

F

.46927 .4525 m .44739 .51413 L .4478 .45464 L .758 0 0 r

F

.45525 .50409 m .44739 .51413 L .4468 .5049 L 0 .892 1 r

F

.48494 .44668 m .46903 .51209 L .46927 .4525 L .62 0 0 r

F

.48494 .44668 m .46903 .51209 L .48482 .50654 L 0 .478 .728 r

F

.48494 .44668 m .48482 .50654 L .48482 .50654 L .62 0 0 r

F

.48494 .44668 m .48482 .50654 L .46903 .51209 L F

.48494 .44668 m .48482 .50654 L .48494 .44668 L F

.46137 .50192 m .48482 .50654 L .48494 .44668 L p 0 .7 .741 r

F P

0 g

s

.46137 .50192 m .48482 .50654 L .46903 .51209 L 0 .892 1 r

F

.48274 .43115 m .4616 .45274 L .46068 .43339 L .718 0 0 r

F

.45561 .44411 m .4478 .45464 L .46927 .4525 L 0 .887 1 r

F

.46168 .44182 m .46927 .4525 L .48494 .44668 L F

.46168 .44182 m .45561 .44411 L .46927 .4525 L F

.48494 .44668 m .46168 .44182 L .46137 .50192 L p 0 .7 .741 r

F P

0 g

s

.46168 .44182 m .48494 .44668 L .48482 .50654 L 0 .7 .741 r

F

.48482 .50654 m .48494 .44668 L .59644 .37452 L p .477 0 0 r

F P

0 g

s

.46168 .44182 m .48482 .50654 L .46137 .50192 L 0 .7 .741 r

F

.48482 .50654 m .59726 .43774 L .59644 .37452 L p 0 .364 .696 r

F P

0 g

s

.59644 .37452 m .59726 .43774 L .48482 .50654 L p .477 0 0 r

F P

0 g

s

.59726 .43774 m .48482 .50654 L .46137 .50192 L p 0 .892 1 r

F P

0 g

s

.72832 .41488 m .73028 .47878 L .68497 .49803 L .591 0 0 r

F

0 g

.62942 .51238 m

.68497 .49803 L

s

.43857 .41177 m

.46078 .41397 L

s

.41381 .40932 m .37725 .39597 L .3766 .43516 L .942 0 0 r

F

.43874 .3919 m .37725 .39597 L .41381 .40932 L .723 0 0 r

F

0 g

.41353 .43281 m

.41381 .40932 L

s

.41353 .44815 m

.45003 .45164 L

s

.43352 .71785 m .35626 .71753 L .36927 .71066 L .669 0 0 r

F

0 g

.43352 .71785 m

.50116 .72022 L

s

.37038 .64522 m .36927 .71066 L .35626 .71753 L .466 0 0 r

F

.37038 .64522 m .31351 .63266 L .29465 .63884 L .685 0 0 r

F

.37038 .64522 m .3119 .69891 L .31351 .63266 L .911 0 0 r

F

.37038 .64522 m .35626 .71753 L .36927 .71066 L .466 0 0 r

F

.37038 .64522 m .36927 .71066 L .3119 .69891 L .911 0 0 r

F

0 g

.37038 .64522 m

.43407 .65291 L

s

.63169 .64487 m .63281 .71034 L .56874 .71768 L .736 0 0 r

F

0 g

.50116 .72022 m

.56874 .71768 L

s

.44739 .51413 m .44858 .53271 L .39976 .52839 L .706 0 0 r

F

.46903 .51209 m .44858 .53271 L .44739 .51413 L F

.46903 .51209 m .49684 .52824 L .44858 .53271 L F

.36927 .71066 m .35626 .71753 L .29289 .7047 L .669 0 0 r

F

0 g

.35626 .71753 m

.42696 .72536 L

s

.35641 .70966 m

.35644 .70804 L

s

.68826 .63215 m .63281 .71034 L .63169 .64487 L .677 0 0 r

F

0 g

.56817 .65273 m

.63169 .64487 L

s

.70732 .63828 m .64604 .71717 L .7091 .70418 L .679 0 0 r

F

.68989 .69844 m .64604 .71717 L .63281 .71034 L .669 0 0 r

F

.68989 .69844 m .7091 .70418 L .64604 .71717 L F

0 g

.57552 .72517 m

.64604 .71717 L

s

.24954 .42104 m .21108 .45913 L .2474 .48464 L 1 0 0 r

F

.24954 .42104 m .21358 .39423 L .21108 .45913 L F

.273 .41564 m .21358 .39423 L .24954 .42104 L .722 0 0 r

F

0 g

.24954 .42104 m

.27253 .43109 L

s

.72832 .41488 m .75194 .4202 L .75409 .48384 L .896 0 0 r

F

0 g

.7288 .43048 m

.73339 .42844 L

s

.72832 .41488 m .75409 .48384 L .75194 .4202 L .896 0 0 r

F

.78735 .39325 m .75194 .4202 L .75409 .48384 L .444 0 0 r

F

.75983 .39039 m .75194 .4202 L .78735 .39325 L .722 0 0 r

F

.75983 .39039 m .72832 .41488 L .75194 .4202 L F

.44739 .51413 m .39976 .52839 L .42549 .51216 L .706 0 0 r

F

.42549 .51216 m .39976 .52839 L .36244 .51624 L F

0 g

.39995 .51381 m

.40054 .4696 L

s

.39976 .52839 m

.44858 .53271 L

s

.48482 .50654 m .49684 .52824 L .46903 .51209 L .706 0 0 r

F

.48482 .50654 m .53262 .51598 L .49684 .52824 L F

0 g

.44858 .53271 m

.49684 .52824 L

s

.273 .41564 m .24099 .39128 L .21358 .39423 L .722 0 0 r

F

.273 .41564 m .23872 .45632 L .24099 .39128 L 1 0 0 r

F

.273 .41564 m .27106 .4795 L .23872 .45632 L F

0 g

.273 .41564 m

.3183 .43572 L

s

.72832 .41488 m .75409 .48384 L .73028 .47878 L .896 0 0 r

F

.72832 .41488 m .73028 .47878 L .75409 .48384 L F

.75983 .39039 m .73028 .47878 L .72832 .41488 L .435 0 0 r

F

0 g

.68343 .43512 m

.72832 .41488 L

s

.75001 .41976 m

.75194 .4202 L

s

.29465 .63884 m .24059 .68732 L .29289 .7047 L .964 0 0 r

F

.29465 .63884 m .24285 .62026 L .24059 .68732 L F

.31351 .63266 m .24285 .62026 L .29465 .63884 L .685 0 0 r

F

0 g

.29465 .63884 m

.31326 .6429 L

s

.75868 .61955 m .70732 .63828 L .7091 .70418 L .594 0 0 r

F

.73446 .61506 m .70732 .63828 L .75868 .61955 L .685 0 0 r

F

.73446 .61506 m .68826 .63215 L .70732 .63828 L F

0 g

.67953 .64446 m

.70732 .63828 L

s

.36352 .45686 m .34654 .49912 L .36244 .51624 L 1 0 0 r

F

.36352 .45686 m .34776 .43889 L .34654 .49912 L F

.40972 .4468 m .34776 .43889 L .36352 .45686 L .716 0 0 r

F

.39896 .44543 m .4031 .43879 L .34776 .43889 L F

.40972 .4468 m .4031 .43879 L .39896 .44543 L F

.40972 .4468 m .4031 .43879 L .40232 .49903 L 0 .875 .618 r

F

.40972 .4468 m .40232 .49903 L .4031 .43879 L 1 0 0 r

F

.40972 .4468 m .409 .50666 L .40232 .49903 L F

.4478 .45464 m .42549 .51216 L .42608 .45257 L .847 0 0 r

F

.44722 .44495 m .42608 .45257 L .4478 .45464 L 0 .887 1 r

F

.44722 .44495 m .43873 .44413 L .42608 .45257 L F

.43873 .44413 m .42608 .45257 L .42549 .51216 L 0 .353 .691 r

F

.43873 .44413 m .42549 .51216 L .42608 .45257 L F

.42608 .45257 m .42549 .51216 L .409 .50666 L .944 0 0 r

F

.43873 .44413 m .42549 .51216 L .43824 .50412 L 0 .353 .691 r

F

.43873 .44413 m .43824 .50412 L .42549 .51216 L F

.43824 .50412 m .42549 .51216 L .409 .50666 L 0 .892 1 r

F

.42608 .45257 m .409 .50666 L .40972 .4468 L .944 0 0 r

F

.43184 .50196 m .409 .50666 L .40232 .49903 L 0 .892 1 r

F

.4031 .43879 m .40232 .49903 L .40745 .49127 L .1 0 0 r

F

.4031 .43879 m .40745 .49127 L .40232 .49903 L 0 .1 .537 r

F

0 g

.36352 .45686 m

.40054 .4696 L

s

.36927 .71066 m .29289 .7047 L .3119 .69891 L .669 0 0 r

F

0 g

.36927 .71066 m

.37038 .64522 L

s

.36927 .71066 m

.43352 .71785 L

s

.35626 .71753 m

.36927 .71066 L

s

.44813 .59887 m .39807 .65556 L .44772 .65941 L .846 0 0 r

F

.44813 .59887 m .39888 .59479 L .39807 .65556 L F

.44692 .58135 m .39888 .59479 L .44813 .59887 L .693 0 0 r

F

.49681 .59466 m .44813 .59887 L .44772 .65941 L .759 0 0 r

F

.46875 .57943 m .44813 .59887 L .49681 .59466 L .693 0 0 r

F

.46875 .57943 m .44692 .58135 L .44813 .59887 L F

.68826 .63215 m .68989 .69844 L .63281 .71034 L .677 0 0 r

F

0 g

.56874 .71768 m

.63281 .71034 L

s

.37725 .39597 m .36111 .41689 L .3766 .43516 L 1 0 0 r

F

.37725 .39597 m .36185 .37715 L .36111 .41689 L F

.42211 .38569 m .36185 .37715 L .37725 .39597 L .723 0 0 r

F

.42748 .39265 m .42211 .38569 L .37725 .39597 L F

.42211 .38569 m .42169 .42518 L .41499 .4168 L 1 0 0 r

F

.42211 .38569 m .41499 .4168 L .42169 .42518 L 0 .876 .612 r

F

.43874 .3919 m .42211 .38569 L .42748 .39265 L .723 0 0 r

F

0 g

.41381 .40932 m

.41725 .40691 L

s

.43105 .39727 m

.43105 .39727 L

s

.42192 .40365 m

.43105 .39727 L

s

.37725 .39597 m

.41381 .40932 L

s

.27106 .4795 m .2474 .48464 L .21108 .45913 L .712 0 0 r

F

0 g

.2474 .48464 m

.29821 .50557 L

s

.78735 .39325 m .75409 .48384 L .78986 .45819 L .444 0 0 r

F

.76211 .45547 m .75409 .48384 L .73028 .47878 L .712 0 0 r

F

0 g

.75194 .4202 m

.75335 .46188 L

s

.76211 .45547 m .78986 .45819 L .75409 .48384 L .712 0 0 r

F

0 g

.70371 .50495 m

.75409 .48384 L

s

.4134 .4481 m

.42621 .43946 L

s

.45561 .44411 m .44722 .44495 L .4478 .45464 L 0 .887 1 r

F

0 g

.43865 .45377 m

.4478 .45464 L

s

.4478 .45464 m

.46162 .45326 L

s

.46089 .39414 m .43841 .43122 L .46068 .43339 L 0 .663 .745 r

F

.46089 .39414 m .43874 .3919 L .43841 .43122 L F

.46042 .3839 m .43874 .3919 L .46089 .39414 L 0 .881 1 r

F

.46927 .38296 m .46042 .3839 L .46089 .39414 L F

.46089 .39414 m .43841 .43122 L .43874 .3919 L .847 0 0 r

F

.46089 .39414 m .46068 .43339 L .43841 .43122 L F

0 g

.46089 .39414 m

.47565 .39258 L

s

.4256 .50134 m

.42608 .45257 L

s

.43873 .44413 m .40972 .4468 L .42608 .45257 L 0 .887 1 r

F

0 g

.4256 .50134 m

.42608 .45257 L

s

.46042 .3839 m .45149 .38299 L .43874 .3919 L 0 .881 1 r

F

.45149 .38299 m .43841 .43122 L .43874 .3919 L 0 .353 .691 r

F

0 g

.4488 .39292 m

.46089 .39414 L

s

.43874 .3919 m .42211 .38569 L .42169 .42518 L 0 .745 .731 r

F

.45149 .38299 m .42211 .38569 L .43874 .3919 L 0 .881 1 r

F

.45149 .38299 m .43874 .3919 L .43841 .43122 L 0 .353 .691 r

F

.43874 .3919 m .42169 .42518 L .42211 .38569 L .945 0 0 r

F

.43874 .3919 m .43841 .43122 L .42169 .42518 L F

.44692 .58135 m .42482 .57949 L .39888 .59479 L .693 0 0 r

F

.42482 .57949 m .39807 .65556 L .39888 .59479 L .466 0 0 r

F

0 g

.41886 .59645 m

.44813 .59887 L

s

.39888 .59479 m .36009 .64476 L .39807 .65556 L .941 0 0 r

F

.39888 .59479 m .36121 .58334 L .36009 .64476 L F

.42482 .57949 m .36121 .58334 L .39888 .59479 L .693 0 0 r

F

.42482 .57949 m .39888 .59479 L .39807 .65556 L .466 0 0 r

F

.49681 .59466 m .44772 .65941 L .49679 .65543 L .759 0 0 r

F

.5329 .5831 m .49681 .59466 L .49679 .65543 L .626 0 0 r

F

.48468 .5742 m .49681 .59466 L .5329 .5831 L .693 0 0 r

F

.48468 .5742 m .46875 .57943 L .49681 .59466 L F

0 g

.44813 .59887 m

.49681 .59466 L

s

.31351 .63266 m .26691 .6157 L .24285 .62026 L .685 0 0 r

F

.31351 .63266 m .26486 .68305 L .26691 .6157 L .966 0 0 r

F

.31351 .63266 m .3119 .69891 L .26486 .68305 L F

0 g

.31351 .63266 m

.36013 .64296 L

s

.27106 .4795 m .21108 .45913 L .23872 .45632 L .712 0 0 r

F

0 g

.27106 .4795 m

.31677 .49861 L

s

.42169 .42518 m .3766 .43516 L .36111 .41689 L .718 0 0 r

F

.43841 .43122 m .3766 .43516 L .42169 .42518 L F

0 g

.3766 .43516 m

.38697 .43882 L

s

.73446 .61506 m .68989 .69844 L .68826 .63215 L .591 0 0 r

F

0 g

.63169 .64487 m

.68826 .63215 L

s

.75983 .39039 m .76211 .45547 L .73028 .47878 L .435 0 0 r

F

0 g

.73028 .47878 m

.75409 .48384 L

s

.72832 .41488 m

.73028 .47878 L

s

.68497 .49803 m

.73028 .47878 L

s

.3119 .69891 m .29289 .7047 L .24059 .68732 L .669 0 0 r

F

0 g

.29289 .7047 m

.35626 .71753 L

s

.46021 .42345 m .46068 .43339 L .43841 .43122 L 0 .885 1 r

F

.4691 .42254 m .46068 .43339 L .46021 .42345 L F

.4691 .42254 m .48274 .43115 L .46068 .43339 L F

0 g

.43841 .43122 m

.46068 .43339 L

s

.409 .50666 m .36244 .51624 L .34654 .49912 L .706 0 0 r

F

.42549 .51216 m .36244 .51624 L .409 .50666 L F

0 g

.36244 .51624 m

.39976 .52839 L

s

.75868 .61955 m .7091 .70418 L .76094 .68666 L .594 0 0 r

F

.73652 .68245 m .7091 .70418 L .68989 .69844 L .669 0 0 r

F

.73652 .68245 m .76094 .68666 L .7091 .70418 L F

0 g

.64604 .71717 m

.7091 .70418 L

s

.53262 .51598 m .64711 .44847 L .64588 .38576 L p .491 0 0 r

F P

0 g

s

.64711 .44847 m .53262 .51598 L .48482 .50654 L p .706 0 0 r

F P

0 g

s

.49684 .52824 m

.53262 .51598 L

s

.53245 .4774 m

.5325 .48948 L

s

.48482 .50654 m

.53262 .51598 L

s

.44649 .64288 m .44772 .65941 L .39807 .65556 L .679 0 0 r

F

.4685 .64107 m .44772 .65941 L .44649 .64288 L F

.4685 .64107 m .49679 .65543 L .44772 .65941 L F

.43238 .44187 m .4031 .43879 L .40972 .4468 L 0 .887 1 r

F

0 g

.42621 .43946 m

.43841 .43122 L

s

.43873 .44413 m .43238 .44187 L .40972 .4468 L 0 .887 1 r

F

0 g

.40972 .4468 m

.42608 .45257 L

s

.47556 .42007 m .49889 .42505 L .48274 .43115 L 0 .885 1 r

F

.46168 .44182 m .48494 .44668 L .59644 .37452 L p 0 .887 1 r

F P

0 g

s

.46068 .43339 m

.48274 .43115 L

s

.45149 .38299 m .43841 .43122 L .45123 .42257 L 0 .353 .691 r

F

.45149 .38299 m .45123 .42257 L .43841 .43122 L F

.45123 .42257 m .43841 .43122 L .42169 .42518 L 0 .885 1 r

F

0 g

.43848 .4237 m

.43874 .3919 L

s

.46021 .42345 m .43841 .43122 L .45123 .42257 L 0 .885 1 r

F

0 g

.43841 .43122 m

.43841 .43122 L

s

.47556 .42007 m .48274 .43115 L .4691 .42254 L 0 .885 1 r

F

.41117 .38414 m .41544 .37705 L .36185 .37715 L .723 0 0 r

F

.42211 .38569 m .41544 .37705 L .41117 .38414 L F

.42211 .38569 m .41499 .4168 L .41544 .37705 L 1 0 0 r

F

.42211 .38569 m .41544 .37705 L .41499 .4168 L 0 .876 .612 r

F

.41544 .37705 m .42031 .40827 L .41499 .4168 L 0 .1 .54 r

F

0 g

.42211 .38569 m

.43874 .3919 L

s

.44484 .38048 m .41544 .37705 L .42211 .38569 L 0 .881 1 r

F

.45149 .38299 m .44484 .38048 L .42211 .38569 L F

.47569 .38042 m .4989 .38555 L .58189 .32931 L p F P

0 g

s

.4989 .38555 m .47569 .38042 L .47556 .42007 L p 0 .7 .74 r

F P

0 g

s

.49813 .38538 m

.4989 .38555 L

s

.4468 .5049 m .44739 .51413 L .42549 .51216 L 0 .892 1 r

F

0 g

.39976 .52839 m

.42549 .51216 L

s

.42556 .50522 m

.42558 .50325 L

s

.42556 .50522 m

.42558 .50325 L

s

.45525 .50409 m .46903 .51209 L .44739 .51413 L 0 .892 1 r

F

.44722 .44495 m .43824 .50412 L .43873 .44413 L 0 .663 .745 r

F

.44722 .44495 m .4468 .5049 L .43824 .50412 L F

.45561 .44411 m .4468 .5049 L .44722 .44495 L 0 .589 .745 r

F

.46042 .3839 m .45123 .42257 L .45149 .38299 L 0 .663 .745 r

F

.46042 .3839 m .46021 .42345 L .45123 .42257 L F

.46927 .38296 m .46021 .42345 L .46042 .3839 L 0 .588 .744 r

F

.43873 .44413 m .43184 .50196 L .43238 .44187 L 0 .745 .731 r

F

0 g

.42608 .45257 m

.43232 .4484 L

s

.43873 .44413 m .43824 .50412 L .43184 .50196 L 0 .745 .731 r

F

0 g

.43873 .44413 m

.44722 .44495 L

s

.45561 .44411 m .45525 .50409 L .4468 .5049 L 0 .589 .745 r

F

.46168 .44182 m .45525 .50409 L .45561 .44411 L 0 .475 .727 r

F

0 g

.44722 .44495 m

.45561 .44411 L

s

.4468 .5049 m .42549 .51216 L .43824 .50412 L 0 .892 1 r

F

0 g

.42549 .51216 m

.44739 .51413 L

s

.42549 .51216 m

.42549 .51216 L

s

.46137 .50192 m .46903 .51209 L .45525 .50409 L 0 .892 1 r

F

0 g

.44739 .51413 m

.46903 .51209 L

s

.48481 .50655 m

.48482 .50654 L

s

.46903 .51209 m

.48481 .50655 L

s

.45149 .38299 m .44454 .42012 L .44484 .38048 L 0 .745 .73 r

F

0 g

.43874 .3919 m

.44478 .38768 L

s

.45149 .38299 m .45123 .42257 L .44454 .42012 L 0 .745 .73 r

F

0 g

.45149 .38299 m

.46042 .3839 L

s

.46927 .38296 m .4691 .42254 L .46021 .42345 L 0 .588 .744 r

F

.47569 .38042 m .4691 .42254 L .46927 .38296 L 0 .475 .727 r

F

0 g

.46042 .3839 m

.46927 .38296 L

s

.42482 .57949 m .42422 .64113 L .39807 .65556 L .466 0 0 r

F

.44649 .64288 m .39807 .65556 L .42422 .64113 L .679 0 0 r

F

.42482 .57949 m .39807 .65556 L .42422 .64113 L .466 0 0 r

F

.42422 .64113 m .39807 .65556 L .36009 .64476 L .679 0 0 r

F

0 g

.39807 .65556 m

.44772 .65941 L

s

.39824 .6426 m

.39888 .59479 L

s

.5329 .5831 m .49679 .65543 L .53317 .64453 L .626 0 0 r

F

.48456 .63613 m .49679 .65543 L .4685 .64107 L .679 0 0 r

F

.48456 .63613 m .53317 .64453 L .49679 .65543 L F

0 g

.44772 .65941 m

.49679 .65543 L

s

.43238 .44187 m .42988 .43875 L .4031 .43879 L 0 .887 1 r

F

.43238 .44187 m .42932 .49899 L .42988 .43875 L 0 .876 .61 r

F

.43238 .44187 m .43184 .50196 L .42932 .49899 L F

0 g

.43238 .44187 m

.43873 .44413 L

s

.47556 .42007 m .55826 .36494 L .58235 .37043 L p 0 .885 1 r

F P

0 g

s

.59644 .37452 m .57217 .369 L .46168 .44182 L p 0 .887 1 r

F P

0 g

s

.46137 .50192 m .46168 .44182 L .57217 .369 L p 0 .357 .693 r

F P

0 g

s

.46927 .38296 m

.47329 .38137 L

s

.48485 .49083 m

.48488 .47371 L

s

.46168 .44182 m .46137 .50192 L .45525 .50409 L 0 .475 .727 r

F

0 g

.45561 .44411 m

.46168 .44182 L

s

.3119 .69891 m .24059 .68732 L .26486 .68305 L .669 0 0 r

F

0 g

.3119 .69891 m

.36927 .71066 L

s

.44484 .38048 m .44224 .37701 L .41544 .37705 L 0 .881 1 r

F

.44484 .38048 m .44193 .41675 L .44224 .37701 L 0 .876 .604 r

F

.44484 .38048 m .44454 .42012 L .44193 .41675 L F

0 g

.44484 .38048 m

.45149 .38299 L

s

.58189 .32931 m .55794 .32367 L .47569 .38042 L p 0 .881 1 r

F P

0 g

s

.47556 .42007 m .47569 .38042 L .55794 .32367 L p 0 .358 .693 r

F P

0 g

s

.47569 .38042 m .47556 .42007 L .4691 .42254 L 0 .475 .727 r

F

0 g

.47329 .38137 m

.47569 .38042 L

s

.73446 .61506 m .73652 .68245 L .68989 .69844 L .591 0 0 r

F

0 g

.63281 .71034 m

.68989 .69844 L

s

.44454 .42012 m .42169 .42518 L .41499 .4168 L 0 .885 1 r

F

.45123 .42257 m .42169 .42518 L .44454 .42012 L F

0 g

.43841 .43122 m

.45123 .42257 L

s

.45123 .42257 m

.45149 .38299 L

s

.42169 .42518 m .36111 .41689 L .41499 .4168 L .718 0 0 r

F

0 g

.42169 .42518 m

.43841 .43122 L

s

.21358 .39423 m .19257 .43031 L .21108 .45913 L 1 0 0 r

F

.21358 .39423 m .1953 .36395 L .19257 .43031 L F

.24099 .39128 m .1953 .36395 L .21358 .39423 L .722 0 0 r

F

0 g

.21358 .39423 m

.24019 .41407 L

s

.34776 .43889 m .35731 .48137 L .34654 .49912 L .1 0 0 r

F

.4031 .43879 m .35847 .42026 L .34776 .43889 L .716 0 0 r

F

.34776 .43889 m .35847 .42026 L .35731 .48137 L .1 0 0 r

F

0 g

.3579 .45045 m

.36352 .45686 L

s

.42988 .43875 m .40819 .43065 L .4031 .43879 L 0 .887 1 r

F

.4031 .43879 m .40745 .49127 L .40819 .43065 L .1 0 0 r

F

.4031 .43879 m .40819 .43065 L .40745 .49127 L 0 .1 .537 r

F

0 g

.40802 .44475 m

.40972 .4468 L

s

.4031 .43879 m .40819 .43065 L .35847 .42026 L .716 0 0 r

F

.42988 .43875 m .43137 .49599 L .43192 .43561 L 0 .1 .55 r

F

0 g

.43187 .44123 m

.43238 .44187 L

s

.42988 .43875 m .42932 .49899 L .43137 .49599 L 0 .1 .55 r

F

.42988 .43875 m .43192 .43561 L .40819 .43065 L 0 .887 1 r

F

0 g

.45123 .42257 m

.46021 .42345 L

s

.46021 .42345 m

.4691 .42254 L

s

.36121 .58334 m .34388 .62952 L .36009 .64476 L 1 0 0 r

F

.36121 .58334 m .34515 .56719 L .34388 .62952 L F

.40818 .57431 m .34515 .56719 L .36121 .58334 L .693 0 0 r

F

.42482 .57949 m .40818 .57431 L .36121 .58334 L F

0 g

.36121 .58334 m

.39888 .59479 L

s

.48468 .5742 m .5329 .5831 L .53317 .64453 L .893 0 0 r

F

0 g

.49681 .59466 m

.49843 .59414 L

s

.64978 .58438 m .6485 .51939 L .5329 .5831 L p .491 0 0 r

F P

0 g

s

.5329 .5831 m .53317 .64453 L .64978 .58438 L p .491 0 0 r

F P

0 g

s

.53317 .64453 m .5329 .5831 L .48468 .5742 L p .893 0 0 r

F P

0 g

s

.48468 .5742 m .5329 .5831 L .6485 .51939 L p .693 0 0 r

F P

0 g

s

.36185 .37715 m .37201 .39796 L .36111 .41689 L .1 0 0 r

F

.41544 .37705 m .3727 .35765 L .36185 .37715 L .723 0 0 r

F

.36185 .37715 m .3727 .35765 L .37201 .39796 L .1 0 0 r

F

0 g

.37215 .38974 m

.37725 .39597 L

s

.44224 .37701 m .42073 .36827 L .41544 .37705 L 0 .881 1 r

F

.41544 .37705 m .42073 .36827 L .42031 .40827 L 0 .1 .54 r

F

.41544 .37705 m .42031 .40827 L .42073 .36827 L .1 0 0 r

F

.41544 .37705 m .41499 .4168 L .42031 .40827 L F

.41544 .37705 m .42073 .36827 L .3727 .35765 L .723 0 0 r

F

.80498 .36288 m .78735 .39325 L .78986 .45819 L .1 0 0 r

F

.77507 .36294 m .78735 .39325 L .80498 .36288 L .722 0 0 r

F

.77507 .36294 m .75983 .39039 L .78735 .39325 L F

0 g

.76064 .41358 m

.78735 .39325 L

s

.43824 .50412 m .409 .50666 L .43184 .50196 L 0 .892 1 r

F

0 g

.42549 .51216 m

.43824 .50412 L

s

.409 .50666 m .34654 .49912 L .40232 .49903 L .706 0 0 r

F

0 g

.409 .50666 m

.42549 .51216 L

s

.44224 .37701 m .44413 .41336 L .44443 .37351 L 0 .1 .553 r

F

0 g

.44438 .37986 m

.44484 .38048 L

s

.44224 .37701 m .44193 .41675 L .44413 .41336 L 0 .1 .553 r

F

.44224 .37701 m .44443 .37351 L .42073 .36827 L 0 .881 1 r

F

.48482 .50654 m .59726 .43774 L .64711 .44847 L p .706 0 0 r

F P

0 g

s

.48482 .50654 m

.48482 .50654 L

s

.4691 .42254 m

.47315 .42099 L

s

.46051 .66595 m .4104 .70363 L .4603 .70729 L .846 0 0 r

F

.46051 .66595 m .41088 .66214 L .4104 .70363 L F

.45954 .64993 m .41088 .66214 L .46051 .66595 L .676 0 0 r

F

.50968 .66201 m .46051 .66595 L .4603 .70729 L .759 0 0 r

F

.48224 .64807 m .46051 .66595 L .50968 .66201 L .676 0 0 r

F

.48224 .64807 m .45954 .64993 L .46051 .66595 L F

.44692 .58135 m .42422 .64113 L .44649 .64288 L 0 .663 .746 r

F

.44692 .58135 m .42482 .57949 L .42422 .64113 L F

.44632 .57264 m .42482 .57949 L .44692 .58135 L 0 .899 1 r

F

.46875 .57943 m .44692 .58135 L .44649 .64288 L 0 .59 .745 r

F

.45485 .57188 m .44692 .58135 L .46875 .57943 L 0 .899 1 r

F

.45485 .57188 m .44632 .57264 L .44692 .58135 L F

.44692 .58135 m .42422 .64113 L .42482 .57949 L .847 0 0 r

F

0 g

.44692 .58135 m

.44692 .58135 L

s

.44692 .58135 m .44649 .64288 L .42422 .64113 L .847 0 0 r

F

.46875 .57943 m .44649 .64288 L .44692 .58135 L .758 0 0 r

F

.24099 .39128 m .22515 .3639 L .1953 .36395 L .722 0 0 r

F

.24099 .39128 m .22269 .43026 L .22515 .3639 L 1 0 0 r

F

.24099 .39128 m .23872 .45632 L .22269 .43026 L F

0 g

.24099 .39128 m

.273 .41564 L

s

.43824 .50412 m

.4468 .5049 L

s

.4468 .5049 m

.45525 .50409 L

s

.24285 .62026 m .2031 .66612 L .24059 .68732 L 1 0 0 r

F

.24285 .62026 m .20574 .5976 L .2031 .66612 L F

.26691 .6157 m .20574 .5976 L .24285 .62026 L .685 0 0 r

F

0 g

.24285 .62026 m

.26651 .62875 L

s

.43192 .43561 m .40745 .49127 L .40819 .43065 L 0 .7 .741 r

F

.43192 .43561 m .43137 .49599 L .40745 .49127 L F

.55794 .32367 m .55826 .36494 L .47556 .42007 L p 0 .358 .693 r

F P

0 g

s

.5411 .36193 m .43192 .43561 L .43137 .49599 L p 0 .349 .689 r

F P

0 g

s

.44224 .37701 m

.44361 .37482 L

s

.43824 .50412 m

.43837 .48744 L

s

.47561 .40613 m

.47569 .38042 L

s

.44454 .42012 m .41499 .4168 L .44193 .41675 L 0 .885 1 r

F

.52565 .31606 m .44443 .37351 L .44413 .41336 L p 0 .348 .688 r

F P

0 g

s

.44413 .41336 m .44443 .37351 L p .42112 .4071 L 0 .7 .74 r

F P

0 g

s

.42031 .40827 m .4211 .40844 L p .42112 .4071 L 0 .7 .74 r

F P

0 g

s

.4211 .40844 m .44413 .41336 L p .42112 .4071 L 0 .7 .74 r

F P

0 g

s

.44443 .37351 m .44413 .41336 L .4211 .40844 L 0 .7 .74 r

F

.42112 .4071 m .4211 .40844 L .42031 .40827 L F

.44443 .37351 m .4211 .40844 L .42112 .4071 L F

.43192 .43561 m .40819 .43065 L .40745 .49127 L p 0 .7 .741 r

F P

0 g

s

.40745 .49127 m .43137 .49599 L .43192 .43561 L p 0 .7 .741 r

F P

0 g

s

.40819 .43065 m .40745 .49127 L p .4204 .47521 L .454 0 0 r

F P

0 g

s

.42084 .43329 m .43192 .43561 L .47672 .40538 L p 0 .887 1 r

F P

0 g

s

.47672 .40538 m .5411 .36193 L p .42084 .43329 L 0 .887 1 r

F P

0 g

s

.44193 .41675 m .41499 .4168 L .42031 .40827 L 0 .885 1 r

F

.44193 .41675 m .42031 .40827 L .44413 .41336 L F

.44413 .41336 m .5258 .35755 L .52565 .31606 L p 0 .348 .688 r

F P

0 g

s

.5258 .35755 m .44413 .41336 L .42031 .40827 L p 0 .885 1 r

F P

0 g

s

.40819 .43065 m .42084 .43329 L p .5411 .36193 L 0 .887 1 r

F P

0 g

s

.42031 .40827 m .50118 .35195 L .5258 .35755 L p 0 .885 1 r

F P

0 g

s

.5411 .36193 m .5163 .35629 L .40819 .43065 L p 0 .887 1 r

F P

0 g

s

.5163 .35629 m .42096 .42187 L p .4204 .47521 L .454 0 0 r

F P

0 g

s

.42096 .42187 m .40819 .43065 L p .4204 .47521 L .454 0 0 r

F P

0 g

s

.40745 .49127 m .40819 .43065 L .42096 .42187 L p 0 .342 .685 r

F P

0 g

s

.42096 .42187 m .5163 .35629 L p .4204 .47521 L 0 .342 .685 r

F P

0 g

s

.40745 .49127 m .42096 .42187 L .4204 .47521 L 0 .342 .685 r

F

0 g

.41544 .37705 m

.41994 .36959 L

s

.77507 .36294 m .76211 .45547 L .75983 .39039 L .1 0 0 r

F

0 g

.72832 .41488 m

.75983 .39039 L

s

.73446 .61506 m .75868 .61955 L .76094 .68666 L .896 0 0 r

F

0 g

.73486 .62824 m

.7388 .6268 L

s

.73446 .61506 m .76094 .68666 L .75868 .61955 L .896 0 0 r

F

.79522 .59677 m .75868 .61955 L .76094 .68666 L .444 0 0 r

F

.76697 .59436 m .75868 .61955 L .79522 .59677 L .685 0 0 r

F

.76697 .59436 m .73446 .61506 L .75868 .61955 L F

.42073 .36827 m .44443 .37351 L .52565 .31606 L p 0 .881 1 r

F P

0 g

s

.44443 .37351 m .42073 .36827 L .42031 .40827 L p 0 .7 .74 r

F P

0 g

s

.44443 .37351 m .42031 .40827 L .42073 .36827 L 0 .7 .74 r

F

0 g

.44429 .39157 m

.44443 .37351 L

s

.42482 .57949 m .40743 .63623 L .42422 .64113 L 0 .744 .732 r

F

.42482 .57949 m .40818 .57431 L .40743 .63623 L F

0 g

.39888 .59479 m

.408 .58941 L

s

.43768 .57191 m .40818 .57431 L .42482 .57949 L 0 .899 1 r

F

.44632 .57264 m .43768 .57191 L .42482 .57949 L F

.43768 .57191 m .42482 .57949 L .42422 .64113 L 0 .353 .691 r

F

.43768 .57191 m .42422 .64113 L .42482 .57949 L F

.42482 .57949 m .40743 .63623 L .40818 .57431 L .944 0 0 r

F

.42482 .57949 m .42422 .64113 L .40743 .63623 L F

.46875 .57943 m .44649 .64288 L .4685 .64107 L 0 .59 .745 r

F

.48468 .5742 m .46875 .57943 L .4685 .64107 L 0 .478 .728 r

F

.46102 .56983 m .46875 .57943 L .48468 .5742 L 0 .899 1 r

F

.46102 .56983 m .45485 .57188 L .46875 .57943 L F

.46875 .57943 m .4685 .64107 L .44649 .64288 L .758 0 0 r

F

.48468 .5742 m .4685 .64107 L .46875 .57943 L .62 0 0 r

F

.48468 .5742 m .4685 .64107 L .48456 .63613 L 0 .478 .728 r

F

.48468 .5742 m .48456 .63613 L .48456 .63613 L .62 0 0 r

F

.48468 .5742 m .48456 .63613 L .4685 .64107 L F

.48468 .5742 m .48456 .63613 L .48468 .5742 L F

.46102 .56983 m .48468 .5742 L .48456 .63613 L 0 .7 .741 r

F

.48456 .63613 m .48468 .5742 L .46102 .56983 L p F P

0 g

s

.43184 .50196 m .40232 .49903 L .42932 .49899 L 0 .892 1 r

F

0 g

.43184 .50196 m

.43824 .50412 L

s

.57217 .369 m .57279 .43247 L .46137 .50192 L p 0 .357 .693 r

F P

0 g

s

.46137 .50192 m .57279 .43247 L .59726 .43774 L p 0 .892 1 r

F P

0 g

s

.46137 .50192 m

.48482 .50654 L

s

.46137 .50192 m

.46159 .45907 L

s

.45525 .50409 m

.46137 .50192 L

s

.41499 .4168 m .36111 .41689 L .37201 .39796 L .718 0 0 r

F

0 g

.36111 .41689 m

.36515 .42166 L

s

.45954 .64993 m .43662 .64813 L .41088 .66214 L .676 0 0 r

F

.43662 .64813 m .4104 .70363 L .41088 .66214 L .466 0 0 r

F

0 g

.42934 .66356 m

.46051 .66595 L

s

.41088 .66214 m .37234 .69335 L .4104 .70363 L .942 0 0 r

F

.41088 .66214 m .37303 .6514 L .37234 .69335 L F

0 g

.39807 .65556 m

.41104 .6484 L

s

.43662 .64813 m .37303 .6514 L .41088 .66214 L .676 0 0 r

F

.43662 .64813 m .41088 .66214 L .4104 .70363 L .466 0 0 r

F

.41499 .4168 m .37201 .39796 L .42031 .40827 L .718 0 0 r

F

.50968 .66201 m .4603 .70729 L .50973 .70351 L .759 0 0 r

F

.54624 .65117 m .50968 .66201 L .50973 .70351 L .625 0 0 r

F

.49886 .64303 m .50968 .66201 L .54624 .65117 L .676 0 0 r

F

0 g

.49679 .65543 m

.5046 .65309 L

s

.49886 .64303 m .48224 .64807 L .50968 .66201 L .676 0 0 r

F

0 g

.46051 .66595 m

.50968 .66201 L

s

.45932 .69194 m .4603 .70729 L .4104 .70363 L .665 0 0 r

F

.48215 .69016 m .4603 .70729 L .45932 .69194 L F

.48215 .69016 m .50973 .70351 L .4603 .70729 L F

.52565 .31606 m .50117 .3103 L .42073 .36827 L p 0 .881 1 r

F P

0 g

s

.42031 .40827 m .42073 .36827 L .50117 .3103 L p 0 .341 .685 r

F P

0 g

s

.42073 .36827 m .42031 .40827 L .37201 .39796 L .894 0 0 r

F

.50117 .3103 m .42073 .36827 L .42031 .40827 L p .453 0 0 r

F P

0 g

s

.37201 .39796 m .42031 .40827 L .42073 .36827 L p .894 0 0 r

F P

0 g

s

.50117 .3103 m .50118 .35195 L .42031 .40827 L p 0 .341 .685 r

F P

0 g

s

.42031 .40827 m .50118 .35195 L .50117 .3103 L p .453 0 0 r

F P

0 g

s

.50118 .35195 m .42031 .40827 L .37201 .39796 L p .718 0 0 r

F P

0 g

s

.35847 .42026 m .40819 .43065 L .5163 .35629 L p .716 0 0 r

F P

0 g

s

.40819 .43065 m .35847 .42026 L .35731 .48137 L p .893 0 0 r

F P

0 g

s

.35731 .48137 m .40745 .49127 L .40819 .43065 L p .893 0 0 r

F P

0 g

s

.40819 .43065 m .35731 .48137 L .35847 .42026 L .893 0 0 r

F

.40819 .43065 m .40745 .49127 L .35731 .48137 L F

.26691 .6157 m .23388 .59511 L .20574 .5976 L .685 0 0 r

F

.26691 .6157 m .23149 .66379 L .23388 .59511 L 1 0 0 r

F

.26691 .6157 m .26486 .68305 L .23149 .66379 L F

0 g

.26691 .6157 m

.31351 .63266 L

s

.40232 .49903 m .34654 .49912 L .35731 .48137 L .706 0 0 r

F

0 g

.34654 .49912 m

.36244 .51624 L

s

.42932 .49899 m .40232 .49903 L .40745 .49127 L 0 .892 1 r

F

.40232 .49903 m .35731 .48137 L .40745 .49127 L .706 0 0 r

F

0 g

.40232 .49903 m

.409 .50666 L

s

.42932 .49899 m .40745 .49127 L .43137 .49599 L 0 .892 1 r

F

0 g

.42932 .49899 m

.43184 .50196 L

s

.42073 .36827 m .37201 .39796 L .3727 .35765 L .894 0 0 r

F

.3727 .35765 m .42073 .36827 L .50117 .3103 L p .723 0 0 r

F P

0 g

s

.42073 .36827 m .3727 .35765 L .37201 .39796 L p .894 0 0 r

F P

0 g

s

.4206 .38065 m

.42073 .36827 L

s

.73446 .61506 m .76094 .68666 L .73652 .68245 L .896 0 0 r

F

.73446 .61506 m .73652 .68245 L .76094 .68666 L F

.76697 .59436 m .73652 .68245 L .73446 .61506 L .435 0 0 r

F

0 g

.68826 .63215 m

.73446 .61506 L

s

.75828 .61948 m

.75868 .61955 L

s

.40743 .63623 m .36009 .64476 L .34388 .62952 L .679 0 0 r

F

.42422 .64113 m .36009 .64476 L .40743 .63623 L F

0 g

.36009 .64476 m

.38185 .65095 L

s

.23872 .45632 m .21108 .45913 L .19257 .43031 L .712 0 0 r

F

0 g

.21108 .45913 m

.2474 .48464 L

s

.48468 .5742 m .48456 .63613 L .53317 .64453 L p .893 0 0 r

F P

0 g

s

.48468 .5742 m .53317 .64453 L .48456 .63613 L .893 0 0 r

F

.64978 .58438 m .53317 .64453 L .48456 .63613 L p .679 0 0 r

F P

0 g

s

.5329 .5831 m

.53307 .62093 L

s

.52385 .64732 m

.53317 .64453 L

s

.80498 .36288 m .78986 .45819 L .80771 .42929 L .1 0 0 r

F

.77754 .42934 m .78986 .45819 L .76211 .45547 L .712 0 0 r

F

.77754 .42934 m .80771 .42929 L .78986 .45819 L F

0 g

.75409 .48384 m

.78986 .45819 L

s

.40818 .57431 m .40063 .62944 L .40743 .63623 L 0 .875 .618 r

F

.40818 .57431 m .40144 .56711 L .34515 .56719 L .693 0 0 r

F

.40818 .57431 m .40144 .56711 L .40063 .62944 L 0 .875 .618 r

F

.43123 .56987 m .40144 .56711 L .40818 .57431 L 0 .899 1 r

F

.43768 .57191 m .43123 .56987 L .40818 .57431 L F

0 g

.40818 .57431 m

.40818 .57431 L

s

.40818 .57431 m .40063 .62944 L .40144 .56711 L 1 0 0 r

F

.40818 .57431 m .40743 .63623 L .40063 .62944 L F

.6485 .51939 m .59819 .50926 L .48468 .5742 L p .693 0 0 r

F P

0 g

s

.59904 .57482 m .59819 .50926 L .48468 .5742 L p 0 .364 .696 r

F P

0 g

s

.48468 .5742 m

.5329 .5831 L

s

.48456 .63613 m .59904 .57482 L .64978 .58438 L p .679 0 0 r

F P

0 g

s

.63457 .65048 m .6338 .60668 L .54624 .65117 L p .491 0 0 r

F P

0 g

s

.49886 .64303 m .54624 .65117 L .6338 .60668 L p .676 0 0 r

F P

0 g

s

.6338 .60668 m .58488 .5977 L .49886 .64303 L p .676 0 0 r

F P

0 g

s

.49886 .64303 m .58488 .5977 L .58537 .64187 L p .478 0 0 r

F P

0 g

s

.58537 .64187 m .58488 .5977 L .49886 .64303 L p 0 .364 .696 r

F P

0 g

s

.58488 .5977 m .58537 .64187 L p .58452 .64024 L 0 .702 .734 r

F P

0 g

s

.48468 .5742 m .48456 .63613 L .58389 .58293 L p 0 .364 .696 r

F P

0 g

s

.48456 .63613 m .48468 .5742 L p .5838 .57473 L .477 0 0 r

F P

0 g

s

.59904 .57482 m .58389 .58293 L p .5838 .57473 L .477 0 0 r

F P

0 g

s

.58389 .58293 m .48456 .63613 L p .5838 .57473 L .477 0 0 r

F P

0 g

s

.46071 .63201 m .48456 .63613 L .4685 .64107 L 0 .904 1 r

F

.46102 .56983 m .46071 .63201 L .48456 .63613 L p 0 .7 .741 r

F P

0 g

s

.46102 .56983 m .48456 .63613 L .46071 .63201 L 0 .7 .741 r

F

.58389 .58293 m .59904 .57482 L p .5838 .57473 L 0 .364 .696 r

F P

0 g

s

.48468 .5742 m .58389 .58293 L .5838 .57473 L 0 .364 .696 r

F

.59904 .57482 m .48456 .63613 L .46071 .63201 L p 0 .904 1 r

F P

0 g

s

.47485 .6389 m .49886 .64303 L .58488 .5977 L p 0 .905 1 r

F P

0 g

s

.58488 .5977 m .56006 .59314 L .47485 .6389 L p 0 .905 1 r

F P

0 g

s

.58405 .59754 m .58537 .64187 L .58488 .5977 L 0 .702 .734 r

F

.56006 .59314 m .58452 .64024 L .58405 .59754 L F

.58452 .64024 m .58537 .64187 L .58405 .59754 L F

.56006 .59314 m .58405 .59754 L p .58452 .64024 L F P

0 g

s

.58405 .59754 m .58488 .5977 L p .58452 .64024 L 0 .702 .734 r

F P

0 g

s

.46102 .56983 m .48468 .5742 L .59819 .50926 L p 0 .899 1 r

F P

0 g

s

.48468 .5742 m .59819 .50926 L .59904 .57482 L p .477 0 0 r

F P

0 g

s

.44588 .63466 m .44649 .64288 L .42422 .64113 L 0 .904 1 r

F

.45448 .63395 m .44649 .64288 L .44588 .63466 L F

.45448 .63395 m .4685 .64107 L .44649 .64288 L F

0 g

.44649 .64288 m

.44649 .64288 L

s

.43137 .49599 m .54145 .42573 L .5411 .36193 L p 0 .349 .689 r

F P

0 g

s

.54145 .42573 m .43137 .49599 L .40745 .49127 L p 0 .892 1 r

F P

0 g

s

.42932 .49899 m

.43137 .49599 L

s

.43152 .47949 m

.43169 .46121 L

s

.40745 .49127 m

.43137 .49599 L

s

.40232 .49903 m

.40745 .49127 L

s

.23872 .45632 m .19257 .43031 L .22269 .43026 L .712 0 0 r

F

0 g

.23872 .45632 m

.27106 .4795 L

s

.26486 .68305 m .24059 .68732 L .2031 .66612 L .669 0 0 r

F

0 g

.24059 .68732 m

.29289 .7047 L

s

.44632 .57264 m .43717 .63397 L .43768 .57191 L 0 .663 .745 r

F

.44632 .57264 m .44588 .63466 L .43717 .63397 L F

.45485 .57188 m .44588 .63466 L .44632 .57264 L 0 .589 .745 r

F

.43662 .64813 m .43628 .69022 L .4104 .70363 L .466 0 0 r

F

.45932 .69194 m .4104 .70363 L .43628 .69022 L .665 0 0 r

F

.43662 .64813 m .4104 .70363 L .43628 .69022 L .466 0 0 r

F

.43628 .69022 m .4104 .70363 L .37234 .69335 L .665 0 0 r

F

0 g

.4104 .70363 m

.4603 .70729 L

s

.41054 .69148 m

.41088 .66214 L

s

.41104 .6484 m

.42422 .64113 L

s

.54624 .65117 m .50973 .70351 L .5465 .69313 L .625 0 0 r

F

.49886 .68532 m .50973 .70351 L .48215 .69016 L .665 0 0 r

F

.49886 .68532 m .5465 .69313 L .50973 .70351 L F

0 g

.4603 .70729 m

.50973 .70351 L

s

.77507 .36294 m .77754 .42934 L .76211 .45547 L .1 0 0 r

F

0 g

.73028 .47878 m

.76211 .45547 L

s

.79522 .59677 m .76094 .68666 L .79787 .66534 L .444 0 0 r

F

.76937 .66308 m .76094 .68666 L .73652 .68245 L .669 0 0 r

F

0 g

.75868 .61955 m

.76033 .66841 L

s

.76937 .66308 m .79787 .66534 L .76094 .68666 L .669 0 0 r

F

0 g

.7091 .70418 m

.76094 .68666 L

s

.43768 .57191 m .42422 .64113 L .43717 .63397 L 0 .353 .691 r

F

.43768 .57191 m .43717 .63397 L .42422 .64113 L F

.43768 .57191 m .43066 .63205 L .43123 .56987 L 0 .745 .731 r

F

0 g

.42482 .57949 m

.43117 .57575 L

s

.43768 .57191 m .43717 .63397 L .43066 .63205 L 0 .745 .731 r

F

0 g

.43768 .57191 m

.44632 .57264 L

s

.45485 .57188 m .45448 .63395 L .44588 .63466 L 0 .589 .745 r

F

.46102 .56983 m .45448 .63395 L .45485 .57188 L 0 .475 .727 r

F

0 g

.44632 .57264 m

.45485 .57188 L

s

.43717 .63397 m .42422 .64113 L .40743 .63623 L 0 .904 1 r

F

0 g

.42428 .63495 m

.42482 .57949 L

s

.42428 .63495 m

.42482 .57949 L

s

.44588 .63466 m .42422 .64113 L .43717 .63397 L 0 .904 1 r

F

0 g

.42422 .64113 m

.42422 .64113 L

s

.46071 .63201 m .4685 .64107 L .45448 .63395 L 0 .904 1 r

F

.43123 .56987 m .42868 .56707 L .40144 .56711 L 0 .899 1 r

F

.42868 .56707 m .40661 .55979 L .40144 .56711 L F

.40144 .56711 m .40583 .62253 L .40661 .55979 L .1 0 0 r

F

.43123 .56987 m .42809 .6294 L .42868 .56707 L 0 .876 .61 r

F

.43123 .56987 m .43066 .63205 L .42809 .6294 L F

0 g

.43123 .56987 m

.43768 .57191 L

s

.57413 .57012 m .46071 .63201 L .46102 .56983 L p 0 .357 .693 r

F P

0 g

s

.48458 .62214 m

.48459 .61897 L

s

.59819 .50926 m .57349 .50429 L .46102 .56983 L p 0 .899 1 r

F P

0 g

s

.46102 .56983 m .57349 .50429 L .57413 .57012 L p 0 .357 .693 r

F P

0 g

s

.46102 .56983 m .46071 .63201 L .45448 .63395 L 0 .475 .727 r

F

0 g

.45485 .57188 m

.46102 .56983 L

s

.5163 .35629 m .51644 .42035 L .40745 .49127 L p 0 .342 .685 r

F P

0 g

s

.40745 .49127 m .51644 .42035 L .54145 .42573 L p 0 .892 1 r

F P

0 g

s

.40745 .49127 m .51644 .42035 L .5163 .35629 L p .454 0 0 r

F P

0 g

s

.51644 .42035 m .40745 .49127 L .35731 .48137 L p .706 0 0 r

F P

0 g

s

.40781 .46201 m

.40819 .43065 L

s

.26486 .68305 m .2031 .66612 L .23149 .66379 L .669 0 0 r

F

0 g

.26486 .68305 m

.3119 .69891 L

s

.37201 .39796 m .45124 .34058 L .50118 .35195 L p .718 0 0 r

F P

0 g

s

.5163 .35629 m .4643 .34447 L .35847 .42026 L p .716 0 0 r

F P

0 g

s

.35731 .48137 m .35847 .42026 L .4643 .34447 L p .437 0 0 r

F P

0 g

s

.39853 .42863 m

.40819 .43065 L

s

.34776 .43889 m

.35847 .42026 L

s

.34515 .56719 m .3548 .61371 L .34388 .62952 L .1 0 0 r

F

.40144 .56711 m .356 .55044 L .34515 .56719 L .693 0 0 r

F

.34515 .56719 m .356 .55044 L .3548 .61371 L .1 0 0 r

F

0 g

.35549 .57758 m

.36121 .58334 L

s

.40144 .56711 m

.40144 .56711 L

s

.76697 .59436 m .76937 .66308 L .73652 .68245 L .435 0 0 r

F

0 g

.73652 .68245 m

.76094 .68666 L

s

.73446 .61506 m

.73652 .68245 L

s

.68989 .69844 m

.73652 .68245 L

s

.40144 .56711 m .40063 .62944 L .40583 .62253 L .1 0 0 r

F

.40144 .56711 m .40583 .62253 L .40063 .62944 L 0 .1 .537 r

F

.40063 .62944 m .3548 .61371 L .40583 .62253 L .679 0 0 r

F

.40144 .56711 m .40661 .55979 L .40583 .62253 L 0 .1 .537 r

F

.40144 .56711 m .40661 .55979 L .356 .55044 L .693 0 0 r

F

0 g

.40144 .56711 m

.40144 .56711 L

s

.42868 .56707 m .43018 .62673 L .43075 .56424 L 0 .1 .55 r

F

0 g

.43071 .5693 m

.43123 .56987 L

s

.42868 .56707 m .42809 .6294 L .43018 .62673 L 0 .1 .55 r

F

.42868 .56707 m .43075 .56424 L .40661 .55979 L 0 .899 1 r

F

.50117 .3103 m .45151 .2986 L .3727 .35765 L p .723 0 0 r

F P

0 g

s

.37201 .39796 m .3727 .35765 L .45151 .2986 L p .437 0 0 r

F P

0 g

s

.36185 .37715 m

.3727 .35765 L

s

.39952 .36358 m

.41481 .36696 L

s

.43066 .63205 m .40743 .63623 L .40063 .62944 L 0 .904 1 r

F

.43717 .63397 m .40743 .63623 L .43066 .63205 L F

0 g

.40743 .63623 m

.42422 .64113 L

s

.42422 .64113 m

.43717 .63397 L

s

.40743 .63623 m .34388 .62952 L .40063 .62944 L .679 0 0 r

F

.37303 .6514 m .35623 .67884 L .37234 .69335 L 1 0 0 r

F

.37303 .6514 m .35702 .63626 L .35623 .67884 L F

.4194 .64313 m .35702 .63626 L .37303 .6514 L .676 0 0 r

F

.43662 .64813 m .4194 .64313 L .37303 .6514 L F

0 g

.37303 .6514 m

.41088 .66214 L

s

.54624 .65117 m .5465 .69313 L .63457 .65048 L p .491 0 0 r

F P

0 g

s

.5465 .69313 m .54624 .65117 L .49886 .64303 L p .894 0 0 r

F P

0 g

s

.50968 .66201 m

.51532 .66033 L

s

.49886 .64303 m .54624 .65117 L .5465 .69313 L .894 0 0 r

F

0 g

.43717 .63397 m

.44588 .63466 L

s

.44588 .63466 m

.45448 .63395 L

s

.45954 .64993 m .43628 .69022 L .43662 .64813 L .847 0 0 r

F

.45954 .64993 m .45932 .69194 L .43628 .69022 L F

.48224 .64807 m .45932 .69194 L .45954 .64993 L .758 0 0 r

F

.45954 .64993 m .43628 .69022 L .45932 .69194 L 0 .663 .745 r

F

.45954 .64993 m .43662 .64813 L .43628 .69022 L F

.45905 .6417 m .43662 .64813 L .45954 .64993 L 0 .905 1 r

F

.48224 .64807 m .45954 .64993 L .45932 .69194 L 0 .589 .745 r

F

.4682 .64094 m .45954 .64993 L .48224 .64807 L 0 .905 1 r

F

.4682 .64094 m .45905 .6417 L .45954 .64993 L F

.43075 .56424 m .40583 .62253 L .40661 .55979 L 0 .7 .741 r

F

.43075 .56424 m .43018 .62673 L .40583 .62253 L F

.54222 .5641 m .54185 .49792 L .43075 .56424 L p 0 .349 .689 r

F P

0 g

s

.43075 .56424 m .43018 .62673 L .54222 .5641 L p 0 .349 .689 r

F P

0 g

s

.43717 .63397 m

.43727 .62277 L

s

.43018 .62673 m .43075 .56424 L .40661 .55979 L p 0 .7 .741 r

F P

0 g

s

.40661 .55979 m .43075 .56424 L .54185 .49792 L p 0 .899 1 r

F P

0 g

s

.40661 .55979 m

.43075 .56424 L

s

.43662 .64813 m .41896 .68542 L .4194 .64313 L .945 0 0 r

F

0 g

.41088 .66214 m

.41925 .65758 L

s

.43662 .64813 m .43628 .69022 L .41896 .68542 L .945 0 0 r

F

.45905 .6417 m .44981 .64097 L .43662 .64813 L 0 .905 1 r

F

.44981 .64097 m .43628 .69022 L .43662 .64813 L 0 .353 .691 r

F

0 g

.4476 .64899 m

.45954 .64993 L

s

.43662 .64813 m .41896 .68542 L .43628 .69022 L 0 .745 .731 r

F

.43662 .64813 m .4194 .64313 L .41896 .68542 L F

.44981 .64097 m .4194 .64313 L .43662 .64813 L 0 .905 1 r

F

.44981 .64097 m .43662 .64813 L .43628 .69022 L 0 .353 .691 r

F

.48224 .64807 m .48215 .69016 L .45932 .69194 L .758 0 0 r

F

.49886 .64303 m .48215 .69016 L .48224 .64807 L .62 0 0 r

F

.48224 .64807 m .45932 .69194 L .48215 .69016 L 0 .589 .745 r

F

.49886 .64303 m .48224 .64807 L .48215 .69016 L 0 .478 .728 r

F

.47485 .6389 m .48224 .64807 L .49886 .64303 L 0 .905 1 r

F

.47485 .6389 m .4682 .64094 L .48224 .64807 L F

0 g

.45954 .64993 m

.48224 .64807 L

s

.43066 .63205 m .40063 .62944 L .42809 .6294 L 0 .904 1 r

F

0 g

.43066 .63205 m

.43717 .63397 L

s

.46071 .63201 m .57413 .57012 L .59904 .57482 L p 0 .904 1 r

F P

0 g

s

.45448 .63395 m

.46071 .63201 L

s

.46071 .63201 m

.46082 .60961 L

s

.46071 .63201 m

.48111 .63553 L

s

.45151 .2986 m .45124 .34058 L .37201 .39796 L p .437 0 0 r

F P

0 g

s

.37201 .39796 m

.3727 .35765 L

s

.36111 .41689 m

.37201 .39796 L

s

.37201 .39796 m

.38557 .40085 L

s

.41896 .68542 m .37234 .69335 L .35623 .67884 L .665 0 0 r

F

.43628 .69022 m .37234 .69335 L .41896 .68542 L F

0 g

.37234 .69335 m

.4104 .70363 L

s

.4104 .70363 m

.43628 .69022 L

s

.49886 .64303 m .49886 .68532 L .5465 .69313 L p .894 0 0 r

F P

0 g

s

.49886 .64303 m .5465 .69313 L .49886 .68532 L .894 0 0 r

F

.63457 .65048 m .5465 .69313 L .49886 .68532 L p .665 0 0 r

F P

0 g

s

.50973 .70351 m

.5465 .69313 L

s

.49886 .64303 m

.54624 .65117 L

s

.54624 .65117 m

.54637 .67312 L

s

.40661 .55979 m .40583 .62253 L .43018 .62673 L p 0 .7 .741 r

F P

0 g

s

.51675 .5593 m .40583 .62253 L .40661 .55979 L p 0 .342 .685 r

F P

0 g

s

.54185 .49792 m .5166 .49284 L .40661 .55979 L p 0 .899 1 r

F P

0 g

s

.40661 .55979 m .5166 .49284 L .51675 .5593 L p 0 .342 .685 r

F P

0 g

s

.51675 .5593 m .5166 .49284 L .40661 .55979 L p .454 0 0 r

F P

0 g

s

.356 .55044 m .40661 .55979 L .5166 .49284 L p .693 0 0 r

F P

0 g

s

.5166 .49284 m .46364 .48218 L .356 .55044 L p .693 0 0 r

F P

0 g

s

.46364 .48218 m .5166 .49284 L .51675 .5593 L p .9 0 0 r

F P

0 g

s

.54185 .49792 m .51675 .5593 L .54222 .5641 L 0 .702 .733 r

F

.5166 .49284 m .54185 .49792 L .54222 .5641 L p F P

0 g

s

.54185 .49792 m .53425 .48662 L .5166 .49284 L 0 .899 1 r

F

.54185 .49792 m .54913 .56185 L .5487 .49555 L 0 .465 .722 r

F

.54185 .49792 m .54222 .5641 L .54913 .56185 L F

.54185 .49792 m .5487 .49555 L .53425 .48662 L 0 .899 1 r

F

.54185 .49792 m .5166 .49284 L .51675 .5593 L 0 .702 .733 r

F

.5166 .49284 m .51675 .5593 L .51675 .5593 L .604 0 0 r

F

.54222 .5641 m .51675 .5593 L .5166 .49284 L p 0 .702 .733 r

F P

0 g

s

.5166 .49284 m .51675 .5593 L .53456 .55342 L .604 0 0 r

F

.5166 .49284 m .53456 .55342 L .51675 .5593 L 0 .461 .72 r

F

.51675 .5593 m .53084 .55127 L .53456 .55342 L .679 0 0 r

F

.5166 .49284 m .51675 .5593 L .5166 .49284 L .604 0 0 r

F

.5487 .49555 m .5585 .56102 L .55799 .49466 L 0 .582 .739 r

F

.5487 .49555 m .54913 .56185 L .5585 .56102 L F

.5487 .49555 m .55844 .4843 L .53425 .48662 L 0 .899 1 r

F

.5487 .49555 m .55799 .49466 L .55844 .4843 L F

.55799 .49466 m .56781 .56183 L .56722 .49552 L 0 .661 .739 r

F

.55799 .49466 m .56722 .49552 L .58242 .48655 L 0 .899 1 r

F

.57349 .50429 m .59819 .50926 L .59904 .57482 L p 0 .702 .733 r

F P

0 g

s

.57349 .50429 m .59904 .57482 L .59819 .50926 L 0 .702 .733 r

F

.57614 .50109 m .59819 .50926 L .60523 .50104 L 0 .899 1 r

F

.59819 .50926 m .6485 .51939 L .64978 .58438 L p .9 0 0 r

F P

0 g

s

.59819 .50926 m .64978 .58438 L .6485 .51939 L .9 0 0 r

F

.60523 .50104 m .59819 .50926 L .6485 .51939 L .693 0 0 r

F

.64978 .58438 m .59904 .57482 L .59819 .50926 L p .9 0 0 r

F P

0 g

s

.59819 .50926 m .59904 .57482 L .64978 .58438 L .9 0 0 r

F

.60523 .50104 m .59819 .50926 L .59904 .57482 L 0 .132 .596 r

F

.60523 .50104 m .59904 .57482 L .59819 .50926 L .181 0 0 r

F

.57386 .49788 m .57614 .50109 L .60523 .50104 L 0 .899 1 r

F

.60523 .50104 m .59904 .57482 L .60615 .56705 L 0 .132 .596 r

F

.60523 .50104 m .60615 .56705 L .59904 .57482 L .181 0 0 r

F

.57386 .49788 m .60523 .50104 L .59955 .49271 L 0 .899 1 r

F

.57614 .50109 m .57349 .50429 L .59819 .50926 L F

.56722 .49552 m .57386 .49788 L .59955 .49271 L F

.56722 .49552 m .59955 .49271 L .58242 .48655 L F

.59904 .57482 m .57413 .57012 L .57349 .50429 L p 0 .702 .733 r

F P

0 g

s

.57349 .50429 m .57413 .57012 L .59904 .57482 L 0 .702 .733 r

F

.58242 .48655 m .58316 .55335 L .60043 .55918 L .962 0 0 r

F

.58242 .48655 m .60043 .55918 L .59955 .49271 L F

.59955 .49271 m .60043 .55918 L .60615 .56705 L 1 0 0 r

F

.59955 .49271 m .60615 .56705 L .60523 .50104 L F

.59955 .49271 m .60523 .50104 L .60615 .56705 L 0 .873 .523 r

F

.59955 .49271 m .60615 .56705 L .60043 .55918 L F

.66536 .50095 m .6485 .51939 L .64978 .58438 L .216 0 0 r

F

.66536 .50095 m .64978 .58438 L .6668 .56696 L F

.60043 .55918 m .65482 .54894 L .6668 .56696 L .679 0 0 r

F

.60043 .55918 m .6121 .56055 L .60615 .56705 L F

.6121 .56055 m .6668 .56696 L .60615 .56705 L F

.57614 .50109 m .57413 .57012 L .57349 .50429 L 0 .116 .587 r

F

.57614 .50109 m .57681 .56709 L .57413 .57012 L F

.57386 .49788 m .57681 .56709 L .57614 .50109 L 0 .874 .536 r

F

.57386 .49788 m .57451 .56406 L .57681 .56709 L F

.56722 .49552 m .57451 .56406 L .57386 .49788 L 0 .751 .718 r

F

.56722 .49552 m .56781 .56183 L .57451 .56406 L F

.56722 .49552 m .58316 .55335 L .56781 .56183 L 0 .353 .691 r

F

.56722 .49552 m .58242 .48655 L .58316 .55335 L F

.56722 .49552 m .58316 .55335 L .58242 .48655 L F

.56722 .49552 m .56781 .56183 L .58316 .55335 L F

.55799 .49466 m .58242 .48655 L .55844 .4843 L 0 .899 1 r

F

.55799 .49466 m .5585 .56102 L .56781 .56183 L 0 .661 .739 r

F

.55844 .4843 m .55896 .55123 L .58316 .55335 L .851 0 0 r

F

.55844 .4843 m .58316 .55335 L .58242 .48655 L F

.53425 .48662 m .55896 .55123 L .55844 .4843 L .752 0 0 r

F

.5166 .49284 m .53456 .55342 L .53425 .48662 L .604 0 0 r

F

.5166 .49284 m .46331 .54922 L .51675 .5593 L .9 0 0 r

F

.51675 .5593 m .50364 .53553 L .53084 .55127 L .679 0 0 r

F

0 g

.40144 .56711 m

.40661 .55979 L

s

.40661 .55979 m .40583 .62253 L .51675 .5593 L p .454 0 0 r

F P

0 g

s

.40583 .62253 m .40661 .55979 L .356 .55044 L p .893 0 0 r

F P

0 g

s

.40661 .55979 m .3548 .61371 L .356 .55044 L .893 0 0 r

F

.40661 .55979 m .40583 .62253 L .3548 .61371 L F

.4643 .34447 m .46399 .40907 L .35731 .48137 L p .437 0 0 r

F P

0 g

s

.35731 .48137 m .46399 .40907 L .51644 .42035 L p .706 0 0 r

F P

0 g

s

.35731 .48137 m

.35847 .42026 L

s

.35731 .48137 m

.40745 .49127 L

s

.34654 .49912 m

.35731 .48137 L

s

.40063 .62944 m .34388 .62952 L .3548 .61371 L .679 0 0 r

F

0 g

.34388 .62952 m

.35692 .64177 L

s

.42809 .6294 m .40063 .62944 L .40583 .62253 L 0 .904 1 r

F

0 g

.40063 .62944 m

.40063 .62944 L

s

.40063 .62944 m

.40743 .63623 L

s

.45882 .68405 m .45932 .69194 L .43628 .69022 L 0 .908 1 r

F

0 g

.43628 .69022 m

.43662 .64813 L

s

.46802 .68332 m .45932 .69194 L .45882 .68405 L 0 .908 1 r

F

.46802 .68332 m .48215 .69016 L .45932 .69194 L F

.42809 .6294 m .40583 .62253 L .43018 .62673 L 0 .904 1 r

F

0 g

.42809 .6294 m

.43066 .63205 L

s

.1953 .36395 m .19456 .39988 L .19257 .43031 L .1 0 0 r

F

.22515 .3639 m .19735 .33201 L .1953 .36395 L .722 0 0 r

F

.1953 .36395 m .19735 .33201 L .19456 .39988 L .1 0 0 r

F

0 g

.19599 .3651 m

.21358 .39423 L

s

.22515 .3639 m .22522 .40288 L .22773 .33516 L .1 0 0 r

F

0 g

.22657 .36636 m

.24099 .39128 L

s

.22515 .3639 m .22269 .43026 L .22522 .40288 L .1 0 0 r

F

.22515 .3639 m .22773 .33516 L .19735 .33201 L .722 0 0 r

F

.77185 .33418 m .77754 .42934 L .77507 .36294 L .885 0 0 r

F

0 g

.75983 .39039 m

.77371 .36538 L

s

.77185 .33418 m .77507 .36294 L .80498 .36288 L .722 0 0 r

F

.77185 .33418 m .80498 .36288 L .8022 .33091 L F

.8022 .33091 m .80498 .36288 L .80771 .42929 L .856 0 0 r

F

0 g

.78735 .39325 m

.80408 .36443 L

s

.20574 .5976 m .18385 .64214 L .2031 .66612 L 1 0 0 r

F

.20574 .5976 m .18673 .57199 L .18385 .64214 L F

.23388 .59511 m .18673 .57199 L .20574 .5976 L .685 0 0 r

F

0 g

.20574 .5976 m

.23321 .61438 L

s

.44981 .64097 m .44953 .68335 L .43628 .69022 L 0 .353 .691 r

F

.45882 .68405 m .43628 .69022 L .44953 .68335 L 0 .908 1 r

F

.44981 .64097 m .43628 .69022 L .44953 .68335 L 0 .353 .691 r

F

.44953 .68335 m .43628 .69022 L .41896 .68542 L 0 .908 1 r

F

0 g

.43628 .69022 m

.45932 .69194 L

s

.49886 .64303 m .49886 .68532 L .48215 .69016 L .62 0 0 r

F

.49886 .64303 m .48215 .69016 L .49886 .68532 L 0 .478 .728 r

F

.47471 .68136 m .48215 .69016 L .46802 .68332 L 0 .908 1 r

F

.47471 .68136 m .49886 .68532 L .48215 .69016 L F

0 g

.45932 .69194 m

.48215 .69016 L

s

.4194 .64313 m .41249 .63619 L .35702 .63626 L .676 0 0 r

F

.4194 .64313 m .412 .67877 L .41249 .63619 L 1 0 0 r

F

.4194 .64313 m .41896 .68542 L .412 .67877 L F

.412 .67877 m .36743 .66379 L .40232 .6695 L .665 0 0 r

F

.4194 .64313 m .412 .67877 L .41896 .68542 L 0 .876 .612 r

F

.4194 .64313 m .41249 .63619 L .412 .67877 L F

.41249 .63619 m .41748 .67199 L .412 .67877 L 0 .1 .54 r

F

.41249 .63619 m .412 .67877 L .41748 .67199 L .1 0 0 r

F

.412 .67877 m .40232 .6695 L .41748 .67199 L .665 0 0 r

F

.44292 .63894 m .41249 .63619 L .4194 .64313 L 0 .905 1 r

F

.44981 .64097 m .44292 .63894 L .4194 .64313 L F

0 g

.4194 .64313 m

.43662 .64813 L

s

.58537 .64187 m .49886 .68532 L .49886 .64303 L p .478 0 0 r

F P

0 g

s

.49886 .64303 m .49886 .68532 L .58537 .64187 L p 0 .364 .696 r

F P

0 g

s

.49886 .68532 m .49886 .64303 L .47485 .6389 L p 0 .7 .74 r

F P

0 g

s

.47485 .6389 m .49886 .64303 L .49886 .68532 L 0 .7 .74 r

F

0 g

.49886 .68532 m

.5465 .69313 L

s

.81356 .57108 m .79522 .59677 L .79787 .66534 L .1 0 0 r

F

.78281 .57113 m .79522 .59677 L .81356 .57108 L .685 0 0 r

F

.78281 .57113 m .76697 .59436 L .79522 .59677 L F

0 g

.76765 .61396 m

.79522 .59677 L

s

.54222 .5641 m .43018 .62673 L .40583 .62253 L p 0 .904 1 r

F P

0 g

s

.40583 .62253 m

.43018 .62673 L

s

.43032 .61204 m

.43035 .60855 L

s

.42809 .6294 m

.43018 .62673 L

s

.45905 .6417 m .44953 .68335 L .44981 .64097 L 0 .663 .745 r

F

.45905 .6417 m .45882 .68405 L .44953 .68335 L F

.4682 .64094 m .45882 .68405 L .45905 .6417 L 0 .588 .744 r

F

.23388 .59511 m .21743 .57194 L .18673 .57199 L .685 0 0 r

F

.23388 .59511 m .21482 .6421 L .21743 .57194 L 1 0 0 r

F

.23388 .59511 m .23149 .66379 L .21482 .6421 L F

0 g

.23388 .59511 m

.26691 .6157 L

s

.44981 .64097 m .4426 .68141 L .44292 .63894 L 0 .745 .73 r

F

0 g

.43662 .64813 m

.44287 .64474 L

s

.44981 .64097 m .44953 .68335 L .4426 .68141 L 0 .745 .73 r

F

0 g

.44981 .64097 m

.45905 .6417 L

s

.4682 .64094 m .46802 .68332 L .45882 .68405 L 0 .588 .744 r

F

.47485 .6389 m .46802 .68332 L .4682 .64094 L 0 .475 .727 r

F

0 g

.45905 .6417 m

.4682 .64094 L

s

.78281 .57113 m .76937 .66308 L .76697 .59436 L .1 0 0 r

F

0 g

.73446 .61506 m

.76697 .59436 L

s

.62914 .34044 m .62986 .38124 L .58235 .37043 L p .899 0 0 r

F P

0 g

s

.58235 .37043 m .58189 .32931 L .62914 .34044 L p .899 0 0 r

F P

0 g

s

.58189 .32931 m .62986 .38124 L .62914 .34044 L .899 0 0 r

F

.64495 .31969 m .62914 .34044 L .62986 .38124 L .211 0 0 r

F

.58871 .31979 m .62914 .34044 L .64495 .31969 L .723 0 0 r

F

.58871 .31979 m .58189 .32931 L .5964 .33273 L F

.58189 .32931 m .58235 .37043 L .62986 .38124 L .899 0 0 r

F

.58871 .31979 m .58235 .37043 L .58189 .32931 L .177 0 0 r

F

.58871 .31979 m .58189 .32931 L .58235 .37043 L 0 .128 .594 r

F

.56059 .31984 m .58189 .32931 L .58871 .31979 L 0 .881 1 r

F

.58871 .31979 m .58921 .36118 L .58235 .37043 L .177 0 0 r

F

.58871 .31979 m .58235 .37043 L .58921 .36118 L 0 .128 .594 r

F

.55822 .316 m .56059 .31984 L .58871 .31979 L 0 .881 1 r

F

.55822 .316 m .58871 .31979 L .58298 .31015 L F

.58298 .31015 m .58871 .31979 L .58921 .36118 L 0 .874 .532 r

F

.58871 .31979 m .5964 .33273 L .62914 .34044 L .723 0 0 r

F

0 g

.5964 .33273 m

.62914 .34044 L

s

.58884 .33095 m

.5964 .33273 L

s

.44292 .63894 m .44022 .63615 L .41249 .63619 L 0 .905 1 r

F

.44292 .63894 m .43989 .67873 L .44022 .63615 L 0 .876 .604 r

F

.44292 .63894 m .4426 .68141 L .43989 .67873 L F

0 g

.44292 .63894 m

.44981 .64097 L

s

.47485 .6389 m .47471 .68136 L .49886 .68532 L p 0 .7 .74 r

F P

0 g

s

.47485 .6389 m .49886 .68532 L .47471 .68136 L 0 .7 .74 r

F

.56041 .6375 m .47471 .68136 L .47485 .6389 L p 0 .358 .693 r

F P

0 g

s

.47485 .6389 m .56006 .59314 L .56041 .6375 L p 0 .358 .693 r

F P

0 g

s

.47485 .6389 m .47471 .68136 L .46802 .68332 L 0 .475 .727 r

F

0 g

.4682 .64094 m

.47485 .6389 L

s

.40583 .62253 m .51675 .5593 L .54222 .5641 L p 0 .904 1 r

F P

0 g

s

.40063 .62944 m

.40583 .62253 L

s

.356 .55044 m .3548 .61371 L .40583 .62253 L p .893 0 0 r

F P

0 g

s

.51675 .5593 m .40583 .62253 L .3548 .61371 L p .679 0 0 r

F P

0 g

s

.40616 .59646 m

.40661 .55979 L

s

.41896 .68542 m .35623 .67884 L .412 .67877 L .665 0 0 r

F

.4426 .68141 m .41896 .68542 L .412 .67877 L 0 .908 1 r

F

.44953 .68335 m .41896 .68542 L .4426 .68141 L F

0 g

.41896 .68542 m

.43628 .69022 L

s

.43628 .69022 m

.44953 .68335 L

s

.44953 .68335 m

.44981 .64097 L

s

.49886 .68532 m .58537 .64187 L .63457 .65048 L p .665 0 0 r

F P

0 g

s

.58537 .64187 m .49886 .68532 L .47471 .68136 L p 0 .908 1 r

F P

0 g

s

.48215 .69016 m

.49886 .68532 L

s

.46331 .54922 m .3548 .61371 L .356 .55044 L p .437 0 0 r

F P

0 g

s

.356 .55044 m .46364 .48218 L .46331 .54922 L p .437 0 0 r

F P

0 g

s

.34515 .56719 m

.356 .55044 L

s

.44953 .68335 m

.45882 .68405 L

s

.45882 .68405 m

.46802 .68332 L

s

.22269 .43026 m .19257 .43031 L .19456 .39988 L .712 0 0 r

F

0 g

.19257 .43031 m

.21108 .45913 L

s

.22269 .43026 m .19456 .39988 L .22522 .40288 L .712 0 0 r

F

0 g

.22269 .43026 m

.23872 .45632 L

s

.35702 .63626 m .36743 .66379 L .35623 .67884 L .1 0 0 r

F

.41249 .63619 m .36818 .62056 L .35702 .63626 L .676 0 0 r

F

.35702 .63626 m .36818 .62056 L .36743 .66379 L .1 0 0 r

F

0 g

.36773 .64639 m

.37303 .6514 L

s

.35702 .63626 m

.36205 .62919 L

s

.44022 .63615 m .41794 .62911 L .41249 .63619 L 0 .905 1 r

F

.41249 .63619 m .41794 .62911 L .41748 .67199 L 0 .1 .54 r

F

0 g

.41781 .64153 m

.4194 .64313 L

s

.41249 .63619 m .41748 .67199 L .41794 .62911 L .1 0 0 r

F

.41249 .63619 m .41794 .62911 L .36818 .62056 L .676 0 0 r

F

0 g

.3623 .615 m

.40583 .62253 L

s

.44022 .63615 m .44216 .67603 L .44248 .63333 L 0 .1 .553 r

F

0 g

.44244 .63845 m

.44292 .63894 L

s

.44022 .63615 m .43989 .67873 L .44216 .67603 L 0 .1 .553 r

F

.44022 .63615 m .44248 .63333 L .41794 .62911 L 0 .905 1 r

F

.77185 .33418 m .77435 .40195 L .77754 .42934 L .885 0 0 r

F

.77435 .40195 m .80771 .42929 L .77754 .42934 L .712 0 0 r

F

0 g

.76211 .45547 m

.77754 .42934 L

s

.8022 .33091 m .80771 .42929 L .80499 .39884 L .856 0 0 r

F

.77435 .40195 m .80499 .39884 L .80771 .42929 L .712 0 0 r

F

0 g

.78986 .45819 m

.80771 .42929 L

s

.23149 .66379 m .2031 .66612 L .18385 .64214 L .669 0 0 r

F

0 g

.2031 .66612 m

.24059 .68732 L

s

.81356 .57108 m .79787 .66534 L .81645 .64129 L .1 0 0 r

F

.78542 .64133 m .79787 .66534 L .76937 .66308 L .669 0 0 r

F

.78542 .64133 m .81645 .64129 L .79787 .66534 L F

0 g

.76094 .68666 m

.79787 .66534 L

s

.64495 .31969 m .62986 .38124 L .64577 .36108 L .211 0 0 r

F

.58921 .36118 m .62986 .38124 L .58235 .37043 L .718 0 0 r

F

.58921 .36118 m .64577 .36108 L .62986 .38124 L F

0 g

.58235 .37043 m

.62986 .38124 L

s

.62914 .34044 m

.62951 .36111 L

s

.4426 .68141 m .412 .67877 L .43989 .67873 L 0 .908 1 r

F

0 g

.4426 .68141 m

.44953 .68335 L

s

.47471 .68136 m .56041 .6375 L .58537 .64187 L p 0 .908 1 r

F P

0 g

s

.46802 .68332 m

.47471 .68136 L

s

.47471 .68136 m

.49886 .68532 L

s

.47471 .68136 m

.47485 .6389 L

s

.52675 .63161 m .5266 .587 L .44248 .63333 L p 0 .348 .688 r

F P

0 g

s

.44248 .63333 m .44216 .67603 L .52675 .63161 L p 0 .348 .688 r

F P

0 g

s

.44216 .67603 m .44248 .63333 L .41794 .62911 L p 0 .7 .74 r

F P

0 g

s

.41794 .62911 m .44248 .63333 L .5266 .587 L p 0 .905 1 r

F P

0 g

s

.44248 .63333 m .41748 .67199 L .41794 .62911 L 0 .7 .74 r

F

.44248 .63333 m .44216 .67603 L .41748 .67199 L F

.23149 .66379 m .18385 .64214 L .21482 .6421 L .669 0 0 r

F

0 g

.23149 .66379 m

.26486 .68305 L

s

.78281 .57113 m .78542 .64133 L .76937 .66308 L .1 0 0 r

F

0 g

.73652 .68245 m

.76937 .66308 L

s

.412 .67877 m .35623 .67884 L .36743 .66379 L .665 0 0 r

F

0 g

.35623 .67884 m

.37234 .69335 L

s

.43989 .67873 m .412 .67877 L .41748 .67199 L 0 .908 1 r

F

0 g

.412 .67877 m

.41896 .68542 L

s

.43989 .67873 m .41748 .67199 L .44216 .67603 L 0 .908 1 r

F

0 g

.43989 .67873 m

.4426 .68141 L

s

.58189 .32931 m .58235 .37043 L .55826 .36494 L p 0 .702 .734 r

F P

0 g

s

.55826 .36494 m .55794 .32367 L .58189 .32931 L p 0 .702 .734 r

F P

0 g

s

.55794 .32367 m .58235 .37043 L .58189 .32931 L 0 .702 .734 r

F

.56059 .31984 m .55794 .32367 L .58189 .32931 L 0 .881 1 r

F

.3548 .61371 m .46331 .54922 L .51675 .5593 L p .679 0 0 r

F P

0 g

s

.3548 .61371 m

.3623 .615 L

s

.3548 .61371 m

.356 .55044 L

s

.34388 .62952 m

.3548 .61371 L

s

.41794 .62911 m .41748 .67199 L .44216 .67603 L p 0 .7 .74 r

F P

0 g

s

.50122 .62714 m .41748 .67199 L .41794 .62911 L p 0 .341 .685 r

F P

0 g

s

.5266 .587 m .50121 .58234 L .41794 .62911 L p 0 .905 1 r

F P

0 g

s

.41794 .62911 m .50121 .58234 L .50122 .62714 L p 0 .341 .685 r

F P

0 g

s

.50122 .62714 m .50121 .58234 L .41794 .62911 L p .453 0 0 r

F P

0 g

s

.50121 .58234 m .4494 .61807 L .50122 .62714 L .899 0 0 r

F

.5266 .587 m .50122 .62714 L .52675 .63161 L 0 .702 .734 r

F

.5266 .587 m .50121 .58234 L .50122 .62714 L F

.52675 .63161 m .50122 .62714 L .50121 .58234 L p F P

0 g

s

.50121 .58234 m .51929 .62156 L .50122 .62714 L 0 .462 .721 r

F

.50121 .58234 m .50122 .62714 L .51929 .62156 L .605 0 0 r

F

.36818 .62056 m .41794 .62911 L .50121 .58234 L p .676 0 0 r

F P

0 g

s

.50121 .58234 m .4497 .57288 L .36818 .62056 L p .676 0 0 r

F P

0 g

s

.4497 .57288 m .50121 .58234 L .50122 .62714 L p .899 0 0 r

F P

0 g

s

.50122 .62714 m .48914 .60546 L .51546 .61952 L .665 0 0 r

F

.50122 .62714 m .51546 .61952 L .51929 .62156 L F

.41794 .62911 m .36743 .66379 L .36818 .62056 L .894 0 0 r

F

.41794 .62911 m .41748 .67199 L .36743 .66379 L F

.41794 .62911 m .41748 .67199 L .50122 .62714 L p .453 0 0 r

F P

0 g

s

.41748 .67199 m .41794 .62911 L .36818 .62056 L p .894 0 0 r

F P

0 g

s

.52675 .63161 m .44216 .67603 L .41748 .67199 L p 0 .908 1 r

F P

0 g

s

.44226 .66283 m

.44229 .6587 L

s

.43989 .67873 m

.44216 .67603 L

s

.55794 .32367 m .55826 .36494 L .58235 .37043 L 0 .702 .734 r

F

.56059 .31984 m .55826 .36494 L .55794 .32367 L 0 .112 .584 r

F

0 g

.56036 .32424 m

.58189 .32931 L

s

.56093 .36123 m .58235 .37043 L .55826 .36494 L 0 .885 1 r

F

.56093 .36123 m .58921 .36118 L .58235 .37043 L F

0 g

.58189 .32931 m

.58225 .36119 L

s

.64588 .38576 m .64711 .44847 L .59726 .43774 L p .9 0 0 r

F P

0 g

s

.59726 .43774 m .59644 .37452 L .64588 .38576 L p .9 0 0 r

F P

0 g

s

.62986 .38124 m

.63847 .37033 L

s

.59644 .37452 m .64711 .44847 L .64588 .38576 L .9 0 0 r

F

.66238 .36529 m .64588 .38576 L .64711 .44847 L .216 0 0 r

F

.60334 .36539 m .64588 .38576 L .66238 .36529 L .716 0 0 r

F

.60334 .36539 m .59644 .37452 L .64588 .38576 L F

.59644 .37452 m .59726 .43774 L .64711 .44847 L .9 0 0 r

F

.60334 .36539 m .59644 .37452 L .59726 .43774 L 0 .132 .596 r

F

0 g

.60245 .37589 m

.63873 .38414 L

s

.63873 .38414 m

.64588 .38576 L

s

.41748 .67199 m .50122 .62714 L .52675 .63161 L p 0 .908 1 r

F P

0 g

s

.41748 .67199 m

.44216 .67603 L

s

.36818 .62056 m .36743 .66379 L .41748 .67199 L p .894 0 0 r

F P

0 g

s

.50122 .62714 m .41748 .67199 L .36743 .66379 L p .665 0 0 r

F P

0 g

s

.41772 .65001 m

.41794 .62911 L

s

.56059 .31984 m .56093 .36123 L .55826 .36494 L 0 .112 .584 r

F

0 g

.55826 .36494 m

.58235 .37043 L

s

.55822 .316 m .56093 .36123 L .56059 .31984 L 0 .875 .545 r

F

0 g

.55794 .32367 m

.55862 .32269 L

s

.55794 .32367 m

.55826 .36494 L

s

.58298 .31015 m .58921 .36118 L .58871 .31979 L 1 0 0 r

F

.58298 .31015 m .58871 .31979 L .64495 .31969 L .723 0 0 r

F

.58298 .31015 m .64495 .31969 L .6332 .29826 L F

.6332 .29826 m .64495 .31969 L .64577 .36108 L 1 0 0 r

F

0 g

.62914 .34044 m

.63904 .32745 L

s

.22773 .33516 m .24751 .3761 L .24986 .30705 L .186 0 0 r

F

.22773 .33516 m .22522 .40288 L .24751 .3761 L F

.22773 .33516 m .22123 .3006 L .19735 .33201 L .722 0 0 r

F

.22773 .33516 m .24986 .30705 L .22123 .3006 L F

0 g

.22515 .3639 m

.22773 .33516 L

s

.74904 .30613 m .77435 .40195 L .77185 .33418 L 1 0 0 r

F

.74904 .30613 m .77185 .33418 L .8022 .33091 L .722 0 0 r

F

0 g

.77185 .33418 m

.77507 .36294 L

s

.52565 .31606 m .5258 .35755 L .50118 .35195 L p 0 .702 .734 r

F P

0 g

s

.50118 .35195 m .50117 .3103 L .52565 .31606 L p 0 .702 .734 r

F P

0 g

s

.52565 .31606 m .53276 .35479 L .53258 .31322 L 0 .465 .722 r

F

.52565 .31606 m .5258 .35755 L .53276 .35479 L F

.52565 .31606 m .51849 .3031 L .50117 .3103 L 0 .881 1 r

F

.52565 .31606 m .53258 .31322 L .51849 .3031 L F

.52565 .31606 m .50118 .35195 L .5258 .35755 L 0 .702 .734 r

F

.52565 .31606 m .50117 .3103 L .50118 .35195 L F

.55822 .316 m .55855 .3575 L .56093 .36123 L 0 .875 .545 r

F

.55143 .31319 m .55855 .3575 L .55822 .316 L 0 .75 .719 r

F

.55143 .31319 m .55822 .316 L .58298 .31015 L 0 .881 1 r

F

0 g

.55822 .316 m

.56059 .31984 L

s

.4494 .61807 m .36743 .66379 L .36818 .62056 L p .437 0 0 r

F P

0 g

s

.36818 .62056 m .4497 .57288 L .4494 .61807 L p .437 0 0 r

F P

0 g

s

.36205 .62919 m

.36818 .62056 L

s

.19735 .33201 m .2186 .36995 L .19456 .39988 L .164 0 0 r

F

.19735 .33201 m .22123 .3006 L .2186 .36995 L F

0 g

.1953 .36395 m

.19735 .33201 L

s

.74904 .30613 m .8022 .33091 L .77757 .29957 L .722 0 0 r

F

.77757 .29957 m .8022 .33091 L .80499 .39884 L 1 0 0 r

F

0 g

.8022 .33091 m

.80498 .36288 L

s

.18673 .57199 m .18565 .61678 L .18385 .64214 L .1 0 0 r

F

.21743 .57194 m .18861 .54491 L .18673 .57199 L .685 0 0 r

F

.18673 .57199 m .18861 .54491 L .18565 .61678 L .1 0 0 r

F

0 g

.18745 .57296 m

.20574 .5976 L

s

.21743 .57194 m .21723 .61929 L .21988 .54759 L .1 0 0 r

F

0 g

.2189 .57402 m

.23388 .59511 L

s

.21743 .57194 m .21482 .6421 L .21723 .61929 L .1 0 0 r

F

.21743 .57194 m .21988 .54759 L .18861 .54491 L .685 0 0 r

F

.53258 .31322 m .54226 .35377 L .54203 .31216 L 0 .582 .74 r

F

.53258 .31322 m .53276 .35479 L .54226 .35377 L F

.53258 .31322 m .5423 .30041 L .51849 .3031 L 0 .881 1 r

F

.53258 .31322 m .54203 .31216 L .5423 .30041 L F

0 g

.52565 .31606 m

.53258 .31322 L

s

.55143 .31319 m .55172 .35476 L .55855 .3575 L 0 .75 .719 r

F

.55143 .31319 m .58298 .31015 L .56599 .30301 L 0 .881 1 r

F

.55143 .31319 m .56637 .34487 L .55172 .35476 L 0 .353 .691 r

F

.55143 .31319 m .56599 .30301 L .56637 .34487 L F

.55143 .31319 m .56637 .34487 L .56599 .30301 L F

.55143 .31319 m .55172 .35476 L .56637 .34487 L F

.54203 .31216 m .55172 .35476 L .55143 .31319 L 0 .661 .739 r

F

.54203 .31216 m .55143 .31319 L .56599 .30301 L 0 .881 1 r

F

.55855 .3575 m .58921 .36118 L .56093 .36123 L 0 .885 1 r

F

0 g

.55826 .36494 m

.56093 .36123 L

s

.58298 .31015 m .58921 .36118 L .58345 .3518 L 0 .874 .532 r

F

.58298 .31015 m .58345 .3518 L .58921 .36118 L 1 0 0 r

F

.58345 .3518 m .64577 .36108 L .58921 .36118 L .718 0 0 r

F

.55855 .3575 m .58345 .3518 L .58921 .36118 L 0 .885 1 r

F

.6332 .29826 m .64577 .36108 L .63397 .34026 L 1 0 0 r

F

.58345 .3518 m .63397 .34026 L .64577 .36108 L .718 0 0 r

F

0 g

.64242 .36533 m

.64577 .36108 L

s

.77969 .54676 m .78542 .64133 L .78281 .57113 L .885 0 0 r

F

0 g

.76697 .59436 m

.7813 .57334 L

s

.77969 .54676 m .78281 .57113 L .81356 .57108 L .685 0 0 r

F

.77969 .54676 m .81356 .57108 L .81094 .54399 L F

.81094 .54399 m .81356 .57108 L .81645 .64129 L .856 0 0 r

F

0 g

.79522 .59677 m

.81255 .57249 L

s

.54203 .31216 m .54226 .35377 L .55172 .35476 L 0 .661 .739 r

F

.54203 .31216 m .56599 .30301 L .5423 .30041 L 0 .881 1 r

F

0 g

.53258 .31322 m

.54203 .31216 L

s

.54203 .31216 m

.55143 .31319 L

s

.66238 .36529 m .64711 .44847 L .66378 .42894 L .216 0 0 r

F

.60422 .42904 m .64711 .44847 L .59726 .43774 L .706 0 0 r

F

.60422 .42904 m .66378 .42894 L .64711 .44847 L F

0 g

.59726 .43774 m

.64711 .44847 L

s

.64588 .38576 m

.64672 .42897 L

s

.50117 .3103 m .51859 .34496 L .50118 .35195 L 0 .462 .721 r

F

.50117 .3103 m .51849 .3031 L .51859 .34496 L F

0 g

.51852 .31438 m

.52565 .31606 L

s

.50117 .3103 m .51859 .34496 L .51849 .3031 L .605 0 0 r

F

.50117 .3103 m .50118 .35195 L .51859 .34496 L F

.50117 .3103 m .4896 .28235 L .45151 .2986 L .723 0 0 r

F

.50117 .3103 m .51849 .3031 L .4896 .28235 L F

0 g

.50117 .3103 m

.50117 .3103 L

s

.50117 .3103 m .45124 .34058 L .50118 .35195 L .899 0 0 r

F

.50117 .3103 m .45151 .2986 L .45124 .34058 L F

.50117 .3103 m .50118 .35195 L .45124 .34058 L p F P

0 g

s

.45124 .34058 m .45151 .2986 L .50117 .3103 L p .899 0 0 r

F P

0 g

s

.56599 .30301 m .58298 .31015 L .58345 .3518 L 0 .751 .718 r

F

.56599 .30301 m .58345 .3518 L .58298 .31015 L .961 0 0 r

F

.56599 .30301 m .58298 .31015 L .6332 .29826 L .723 0 0 r

F

0 g

.58298 .31015 m

.58871 .31979 L

s

.60334 .36539 m .59726 .43774 L .59644 .37452 L .181 0 0 r

F

.59644 .37452 m .59726 .43774 L .57279 .43247 L p 0 .702 .733 r

F P

0 g

s

.57279 .43247 m .57217 .369 L .59644 .37452 L p 0 .702 .733 r

F P

0 g

s

.57217 .369 m .59726 .43774 L .59644 .37452 L 0 .702 .733 r

F

.57477 .36544 m .59644 .37452 L .60334 .36539 L 0 .887 1 r

F

.57477 .36544 m .57217 .369 L .59644 .37452 L F

.5258 .35755 m .51859 .34496 L .53276 .35479 L 0 .885 1 r

F

0 g

.52565 .31606 m

.52577 .34994 L

s

.5258 .35755 m .50118 .35195 L .51859 .34496 L 0 .885 1 r

F

0 g

.50118 .35195 m

.502 .35214 L

s

.55172 .35476 m .58345 .3518 L .55855 .3575 L 0 .885 1 r

F

0 g

.55855 .3575 m

.56093 .36123 L

s

.36743 .66379 m .4494 .61807 L .50122 .62714 L p .665 0 0 r

F P

0 g

s

.36743 .66379 m

.36818 .62056 L

s

.36743 .66379 m

.41748 .67199 L

s

.35623 .67884 m

.36743 .66379 L

s

.22522 .40288 m .2186 .36995 L .24751 .3761 L .712 0 0 r

F

.22522 .40288 m .19456 .39988 L .2186 .36995 L F

0 g

.22269 .43026 m

.22522 .40288 L

s

.19257 .43031 m

.19456 .39988 L

s

.53276 .35479 m .54254 .34234 L .54226 .35377 L 0 .885 1 r

F

.53276 .35479 m .51859 .34496 L .54254 .34234 L F

0 g

.5258 .35755 m

.53276 .35479 L

s

.502 .35214 m

.5258 .35755 L

s

.55172 .35476 m .56637 .34487 L .58345 .3518 L 0 .885 1 r

F

.54226 .35377 m .56637 .34487 L .55172 .35476 L F

0 g

.55172 .35476 m

.55855 .3575 L

s

.55143 .31319 m

.55168 .35029 L

s

.74904 .30613 m .75138 .37522 L .77435 .40195 L 1 0 0 r

F

.75138 .37522 m .80499 .39884 L .77435 .40195 L .712 0 0 r

F

0 g

.77435 .40195 m

.77754 .42934 L

s

.54226 .35377 m .54254 .34234 L .56637 .34487 L 0 .885 1 r

F

0 g

.53276 .35479 m

.54226 .35377 L

s

.54226 .35377 m

.55172 .35476 L

s

.57217 .369 m .57279 .43247 L .59726 .43774 L 0 .702 .733 r

F

.57477 .36544 m .57279 .43247 L .57217 .369 L 0 .116 .587 r

F

0 g

.57465 .36956 m

.59644 .37452 L

s

.50118 .35195 m .48954 .32479 L .51859 .34496 L .718 0 0 r

F

0 g

.50118 .35195 m

.50118 .35195 L

s

.50118 .35195 m .45124 .34058 L .48954 .32479 L .718 0 0 r

F

.56599 .30301 m .58345 .3518 L .56637 .34487 L 0 .751 .718 r

F

.56599 .30301 m .56637 .34487 L .58345 .3518 L .961 0 0 r

F

.56637 .34487 m .63397 .34026 L .58345 .3518 L .718 0 0 r

F

0 g

.58345 .3518 m

.58921 .36118 L

s

.51849 .3031 m .54254 .34234 L .51859 .34496 L 0 .581 .739 r

F

.51849 .3031 m .5423 .30041 L .54254 .34234 L F

.51849 .3031 m .54254 .34234 L .5423 .30041 L .753 0 0 r

F

.51849 .3031 m .51859 .34496 L .54254 .34234 L F

.51849 .3031 m .54286 .27622 L .4896 .28235 L .723 0 0 r

F

.51849 .3031 m .5423 .30041 L .54286 .27622 L F

0 g

.50117 .3103 m

.51849 .3031 L

s

.5423 .30041 m .56599 .30301 L .56637 .34487 L 0 .661 .739 r

F

0 g

.56599 .30301 m

.56599 .30301 L

s

.56599 .30301 m .6332 .29826 L .59586 .28215 L .723 0 0 r

F

.56599 .30301 m .59642 .32459 L .56637 .34487 L .466 0 0 r

F

.56599 .30301 m .59586 .28215 L .59642 .32459 L F

.56599 .30301 m .59642 .32459 L .59586 .28215 L F

.56599 .30301 m .56637 .34487 L .59642 .32459 L F

.5423 .30041 m .56637 .34487 L .56599 .30301 L .851 0 0 r

F

.5423 .30041 m .56599 .30301 L .59586 .28215 L .723 0 0 r

F

.77757 .29957 m .80499 .39884 L .78019 .36896 L 1 0 0 r

F

.75138 .37522 m .78019 .36896 L .80499 .39884 L .712 0 0 r

F

0 g

.80499 .39884 m

.80771 .42929 L

s

.21482 .6421 m .18385 .64214 L .18565 .61678 L .669 0 0 r

F

0 g

.18385 .64214 m

.2031 .66612 L

s

.21482 .6421 m .18565 .61678 L .21723 .61929 L .669 0 0 r

F

0 g

.21482 .6421 m

.23149 .66379 L

s

.77969 .54676 m .78233 .61851 L .78542 .64133 L .885 0 0 r

F

.78233 .61851 m .81645 .64129 L .78542 .64133 L .669 0 0 r

F

0 g

.76937 .66308 m

.78542 .64133 L

s

.81094 .54399 m .81645 .64129 L .81389 .61592 L .856 0 0 r

F

.78233 .61851 m .81389 .61592 L .81645 .64129 L .669 0 0 r

F

0 g

.79787 .66534 m

.81645 .64129 L

s

.57477 .36544 m .57541 .42908 L .57279 .43247 L 0 .116 .587 r

F

.57253 .36188 m .57541 .42908 L .57477 .36544 L 0 .874 .536 r

F

0 g

.57217 .369 m

.5728 .36814 L

s

.57253 .36188 m .57477 .36544 L .60334 .36539 L 0 .887 1 r

F

.5423 .30041 m .56637 .34487 L .54254 .34234 L 0 .661 .739 r

F

.5423 .30041 m .54254 .34234 L .56637 .34487 L .851 0 0 r

F

0 g

.56599 .30301 m

.56637 .34487 L

s

.55172 .35476 m

.56637 .34487 L

s

.5423 .30041 m .59586 .28215 L .54286 .27622 L .723 0 0 r

F

0 g

.51849 .3031 m

.5423 .30041 L

s

.5423 .30041 m

.56599 .30301 L

s

.60334 .36539 m .59726 .43774 L .60422 .42904 L 0 .132 .596 r

F

.60334 .36539 m .60422 .42904 L .59726 .43774 L .181 0 0 r

F

.57541 .42908 m .60422 .42904 L .59726 .43774 L 0 .892 1 r

F

.57253 .36188 m .60334 .36539 L .59774 .35615 L 0 .887 1 r

F

.59774 .35615 m .60422 .42904 L .60334 .36539 L 1 0 0 r

F

0 g

.59644 .37452 m

.59907 .37104 L

s

.59774 .35615 m .60334 .36539 L .66238 .36529 L .716 0 0 r

F

.59774 .35615 m .60334 .36539 L .60422 .42904 L 0 .873 .523 r

F

.59774 .35615 m .66238 .36529 L .65064 .34413 L .716 0 0 r

F

.65064 .34413 m .66238 .36529 L .66378 .42894 L 1 0 0 r

F

0 g

.64588 .38576 m

.65528 .37409 L

s

.60523 .50104 m .6485 .51939 L .66536 .50095 L .693 0 0 r

F

0 g

.6485 .51939 m

.6491 .55002 L

s

.60536 .51071 m

.61285 .51221 L

s

.61285 .51221 m

.6485 .51939 L

s

.57541 .42908 m .59726 .43774 L .57279 .43247 L 0 .892 1 r

F

0 g

.57279 .43247 m

.59726 .43774 L

s

.45151 .2986 m .48954 .32479 L .45124 .34058 L .598 0 0 r

F

.45151 .2986 m .4896 .28235 L .48954 .32479 L F

0 g

.48956 .30756 m

.50117 .3103 L

s

.45124 .34058 m

.45151 .2986 L

s

.59586 .28215 m .6332 .29826 L .63397 .34026 L .964 0 0 r

F

0 g

.6332 .29826 m

.64495 .31969 L

s

.58488 .5977 m .6338 .60668 L .63457 .65048 L p .899 0 0 r

F P

0 g

s

.58488 .5977 m .63457 .65048 L .6338 .60668 L .899 0 0 r

F

.65028 .58993 m .6338 .60668 L .63457 .65048 L .211 0 0 r

F

.59197 .59001 m .6338 .60668 L .65028 .58993 L .676 0 0 r

F

.59197 .59001 m .58488 .5977 L .6338 .60668 L F

.5411 .36193 m .54145 .42573 L .51644 .42035 L p 0 .702 .733 r

F P

0 g

s

.51644 .42035 m .5163 .35629 L .5411 .36193 L p 0 .702 .733 r

F P

0 g

s

.5163 .35629 m .51644 .42035 L .51644 .42035 L .604 0 0 r

F

.5411 .36193 m .51644 .42035 L .54145 .42573 L 0 .702 .733 r

F

.5411 .36193 m .5163 .35629 L .51644 .42035 L F

.5163 .35629 m .51644 .42035 L .53392 .41377 L .604 0 0 r

F

.5163 .35629 m .51644 .42035 L .5163 .35629 L F

.5411 .36193 m .53363 .34939 L .5163 .35629 L 0 .887 1 r

F

.5163 .35629 m .53392 .41377 L .53363 .34939 L .604 0 0 r

F

.5411 .36193 m .54823 .42321 L .54782 .35929 L 0 .465 .722 r

F

.5411 .36193 m .54145 .42573 L .54823 .42321 L F

.5411 .36193 m .54782 .35929 L .53363 .34939 L 0 .887 1 r

F

0 g

.53368 .36024 m

.5411 .36193 L

s

.57253 .36188 m .57315 .42568 L .57541 .42908 L 0 .874 .536 r

F

.566 .35926 m .57315 .42568 L .57253 .36188 L 0 .751 .718 r

F

.566 .35926 m .57253 .36188 L .59774 .35615 L 0 .887 1 r

F

0 g

.57253 .36188 m

.57477 .36544 L

s

.51859 .34496 m .54311 .31883 L .54254 .34234 L .718 0 0 r

F

.51859 .34496 m .48954 .32479 L .54311 .31883 L F

0 g

.50118 .35195 m

.51859 .34496 L

s

.45124 .34058 m

.50118 .35195 L

s

.56637 .34487 m .59642 .32459 L .63397 .34026 L .718 0 0 r

F

.54254 .34234 m .59642 .32459 L .56637 .34487 L F

0 g

.56637 .34487 m

.58345 .3518 L

s

.54782 .35929 m .55744 .42228 L .55694 .35831 L 0 .582 .739 r

F

.54782 .35929 m .54823 .42321 L .55744 .42228 L F

.54782 .35929 m .55737 .34682 L .53363 .34939 L 0 .887 1 r

F

.54782 .35929 m .55694 .35831 L .55737 .34682 L F

0 g

.5411 .36193 m

.54782 .35929 L

s

.566 .35926 m .56657 .42318 L .57315 .42568 L 0 .751 .718 r

F

0 g

.57272 .42552 m

.57279 .43247 L

s

.566 .35926 m .59774 .35615 L .58092 .34931 L 0 .887 1 r

F

.566 .35926 m .58163 .41369 L .56657 .42318 L 0 .353 .691 r

F

.566 .35926 m .58092 .34931 L .58163 .41369 L F

.566 .35926 m .58163 .41369 L .58092 .34931 L F

.566 .35926 m .56657 .42318 L .58163 .41369 L F

.55694 .35831 m .56657 .42318 L .566 .35926 L 0 .661 .739 r

F

.55694 .35831 m .566 .35926 L .58092 .34931 L 0 .887 1 r

F

.54254 .34234 m .54311 .31883 L .59642 .32459 L .718 0 0 r

F

0 g

.51859 .34496 m

.54254 .34234 L

s

.54254 .34234 m

.56637 .34487 L

s

.55694 .35831 m .55744 .42228 L .56657 .42318 L 0 .661 .739 r

F

.55694 .35831 m .58092 .34931 L .55737 .34682 L 0 .887 1 r

F

0 g

.54782 .35929 m

.55694 .35831 L

s

.55694 .35831 m

.566 .35926 L

s

.59586 .28215 m .63397 .34026 L .59642 .32459 L .964 0 0 r

F

0 g

.63397 .34026 m

.63782 .34705 L

s

.5163 .35629 m .50354 .32841 L .4643 .34447 L .716 0 0 r

F

.5163 .35629 m .53363 .34939 L .50354 .32841 L F

.5163 .35629 m .46399 .40907 L .51644 .42035 L .9 0 0 r

F

.5163 .35629 m .4643 .34447 L .46399 .40907 L F

.5163 .35629 m .51644 .42035 L .46399 .40907 L p F P

0 g

s

.46399 .40907 m .4643 .34447 L .5163 .35629 L p .9 0 0 r

F P

0 g

s

.5163 .35629 m .53392 .41377 L .51644 .42035 L 0 .461 .72 r

F

.5163 .35629 m .53363 .34939 L .53392 .41377 L F

.59774 .35615 m .59859 .42021 L .60422 .42904 L 1 0 0 r

F

.58092 .34931 m .59859 .42021 L .59774 .35615 L .962 0 0 r

F

.58092 .34931 m .59774 .35615 L .65064 .34413 L .716 0 0 r

F

0 g

.59774 .35615 m

.59774 .35615 L

s

.59774 .35615 m .60422 .42904 L .59859 .42021 L 0 .873 .523 r

F

.58092 .34931 m .59774 .35615 L .59859 .42021 L 0 .752 .716 r

F

.63457 .65048 m .58537 .64187 L .58488 .5977 L p .899 0 0 r

F P

0 g

s

.58488 .5977 m .58537 .64187 L .63457 .65048 L .899 0 0 r

F

.65028 .58993 m .63457 .65048 L .65116 .63442 L .211 0 0 r

F

.5925 .6345 m .63457 .65048 L .58537 .64187 L .665 0 0 r

F

.5925 .6345 m .65116 .63442 L .63457 .65048 L F

0 g

.6338 .60668 m

.63429 .63444 L

s

.57315 .42568 m .60422 .42904 L .57541 .42908 L 0 .892 1 r

F

0 g

.57279 .43247 m

.57541 .42908 L

s

.59859 .42021 m .66378 .42894 L .60422 .42904 L .706 0 0 r

F

0 g

.59726 .43774 m

.60422 .42904 L

s

.57315 .42568 m .59859 .42021 L .60422 .42904 L 0 .892 1 r

F

.24986 .30705 m .2892 .35203 L .2912 .2818 L .496 0 0 r

F

.24986 .30705 m .24751 .3761 L .2892 .35203 L F

.24986 .30705 m .26676 .27225 L .22123 .3006 L .722 0 0 r

F

.24986 .30705 m .2912 .2818 L .26676 .27225 L F

.24986 .30705 m .2186 .36995 L .24751 .3761 L .896 0 0 r

F

.24986 .30705 m .22123 .3006 L .2186 .36995 L F

.24986 .30705 m .2186 .36995 L .22123 .3006 L F

.24986 .30705 m .24751 .3761 L .2186 .36995 L F

.65064 .34413 m .66378 .42894 L .65196 .40875 L 1 0 0 r

F

.59859 .42021 m .65196 .40875 L .66378 .42894 L .706 0 0 r

F

0 g

.64711 .44847 m

.66378 .42894 L

s

.60615 .56705 m .64978 .58438 L .59904 .57482 L .679 0 0 r

F

.60615 .56705 m .6668 .56696 L .64978 .58438 L F

0 g

.59904 .57482 m

.64978 .58438 L

s

.70708 .28102 m .75138 .37522 L .74904 .30613 L 1 0 0 r

F

.70708 .28102 m .74904 .30613 L .77757 .29957 L .722 0 0 r

F

0 g

.74904 .30613 m

.77185 .33418 L

s

.54145 .42573 m .53392 .41377 L .54823 .42321 L 0 .892 1 r

F

0 g

.5411 .36193 m

.54141 .41871 L

s

.54145 .42573 m .51644 .42035 L .53392 .41377 L 0 .892 1 r

F

.56657 .42318 m .59859 .42021 L .57315 .42568 L F

0 g

.57315 .42568 m

.57541 .42908 L

s

.59197 .59001 m .58537 .64187 L .58488 .5977 L .177 0 0 r

F

0 g

.59085 .59879 m

.6338 .60668 L

s

.59197 .59001 m .58488 .5977 L .58537 .64187 L 0 .128 .594 r

F

.56282 .59005 m .58488 .5977 L .59197 .59001 L 0 .905 1 r

F

.56282 .59005 m .56006 .59314 L .58488 .5977 L F

0 g

.58488 .5977 m

.58593 .59656 L

s

.58405 .59754 m

.58488 .5977 L

s

.53363 .34939 m .55787 .41131 L .55737 .34682 L .752 0 0 r

F

.53363 .34939 m .53392 .41377 L .55787 .41131 L F

.53363 .34939 m .55827 .32235 L .50354 .32841 L .716 0 0 r

F

.53363 .34939 m .55737 .34682 L .55827 .32235 L F

.53363 .34939 m .55787 .41131 L .53392 .41377 L 0 .581 .739 r

F

.53363 .34939 m .55737 .34682 L .55787 .41131 L F

.58092 .34931 m .58163 .41369 L .59859 .42021 L .962 0 0 r

F

.58092 .34931 m .65064 .34413 L .61256 .32821 L .716 0 0 r

F

.58092 .34931 m .59859 .42021 L .58163 .41369 L 0 .752 .716 r

F

.58092 .34931 m .61356 .39355 L .58163 .41369 L .466 0 0 r

F

.58092 .34931 m .61256 .32821 L .61356 .39355 L F

.58092 .34931 m .61356 .39355 L .61256 .32821 L F

.58092 .34931 m .58163 .41369 L .61356 .39355 L F

.55737 .34682 m .58163 .41369 L .58092 .34931 L .851 0 0 r

F

.55737 .34682 m .58092 .34931 L .61256 .32821 L .716 0 0 r

F

.55737 .34682 m .58092 .34931 L .58163 .41369 L 0 .661 .738 r

F

.54823 .42321 m .55787 .41131 L .55744 .42228 L 0 .892 1 r

F

.54823 .42321 m .53392 .41377 L .55787 .41131 L F

0 g

.54145 .42573 m

.54823 .42321 L

s

.56657 .42318 m .58163 .41369 L .59859 .42021 L 0 .892 1 r

F

.55744 .42228 m .58163 .41369 L .56657 .42318 L F

0 g

.56657 .42318 m

.57315 .42568 L

s

.56611 .37091 m

.56653 .41905 L

s

.22123 .3006 m .2645 .34292 L .2186 .36995 L .488 0 0 r

F

0 g

.24915 .3279 m

.24986 .30705 L

s

.22123 .3006 m .26676 .27225 L .2645 .34292 L .488 0 0 r

F

0 g

.19735 .33201 m

.22123 .3006 L

s

.21988 .54759 m .23999 .59694 L .24248 .52373 L .186 0 0 r

F

.21988 .54759 m .21723 .61929 L .23999 .59694 L F

.21988 .54759 m .21296 .51826 L .18861 .54491 L .685 0 0 r

F

.21988 .54759 m .24248 .52373 L .21296 .51826 L F

0 g

.21743 .57194 m

.21988 .54759 L

s

.4896 .28235 m .54311 .31883 L .48954 .32479 L .752 0 0 r

F

.4896 .28235 m .54286 .27622 L .54311 .31883 L F

0 g

.45151 .2986 m

.4896 .28235 L

s

.54286 .27622 m .59586 .28215 L .59642 .32459 L .852 0 0 r

F

0 g

.59586 .28215 m

.6332 .29826 L

s

.56599 .30301 m

.56968 .30044 L

s

.55744 .42228 m .55787 .41131 L .58163 .41369 L 0 .892 1 r

F

0 g

.54823 .42321 m

.55744 .42228 L

s

.55744 .42228 m

.56657 .42318 L

s

.70708 .28102 m .77757 .29957 L .73133 .27137 L .722 0 0 r

F

.73133 .27137 m .77757 .29957 L .78019 .36896 L 1 0 0 r

F

0 g

.77757 .29957 m

.8022 .33091 L

s

.75639 .52295 m .78233 .61851 L .77969 .54676 L 1 0 0 r

F

.75639 .52295 m .77969 .54676 L .81094 .54399 L .685 0 0 r

F

0 g

.77969 .54676 m

.78281 .57113 L

s

.55737 .34682 m .55787 .41131 L .58163 .41369 L .851 0 0 r

F

0 g

.56657 .42318 m

.58163 .41369 L

s

.55737 .34682 m .61256 .32821 L .55827 .32235 L .716 0 0 r

F

.55737 .34682 m .58163 .41369 L .55787 .41131 L 0 .661 .738 r

F

0 g

.58092 .34931 m

.5966 .33885 L

s

.51644 .42035 m .50358 .39374 L .53392 .41377 L .706 0 0 r

F

0 g

.51644 .42035 m

.54145 .42573 L

s

.5163 .35629 m

.5164 .40221 L

s

.5163 .35629 m

.5164 .40221 L

s

.51644 .42035 m .46399 .40907 L .50358 .39374 L .706 0 0 r

F

0 g

.51644 .42035 m

.51644 .42035 L

s

.58163 .41369 m .65196 .40875 L .59859 .42021 L .706 0 0 r

F

0 g

.59859 .42021 m

.59859 .42021 L

s

.18861 .54491 m .21017 .5918 L .18565 .61678 L .164 0 0 r

F

.18861 .54491 m .21296 .51826 L .21017 .5918 L F

0 g

.18673 .57199 m

.18861 .54491 L

s

.58537 .64187 m .56041 .6375 L .56006 .59314 L p 0 .702 .734 r

F P

0 g

s

.56006 .59314 m .56041 .6375 L .58537 .64187 L 0 .702 .734 r

F

0 g

.58488 .5977 m

.58537 .64187 L

s

.56282 .59005 m .56041 .6375 L .56006 .59314 L 0 .112 .584 r

F

0 g

.56264 .59361 m

.58405 .59754 L

s

.56006 .59314 m

.56109 .59199 L

s

.4643 .34447 m .50358 .39374 L .46399 .40907 L .597 0 0 r

F

.4643 .34447 m .50354 .32841 L .50358 .39374 L F

0 g

.50356 .35339 m

.5163 .35629 L

s

.46399 .40907 m

.4643 .34447 L

s

.45124 .34058 m

.48954 .32479 L

s

.75639 .52295 m .81094 .54399 L .78581 .51738 L .685 0 0 r

F

.78581 .51738 m .81094 .54399 L .81389 .61592 L 1 0 0 r

F

0 g

.81094 .54399 m

.81356 .57108 L

s

.61256 .32821 m .65064 .34413 L .65196 .40875 L .966 0 0 r

F

0 g

.65064 .34413 m

.66238 .36529 L

s

.24751 .3761 m .2645 .34292 L .2892 .35203 L .712 0 0 r

F

.24751 .3761 m .2186 .36995 L .2645 .34292 L F

0 g

.22522 .40288 m

.24751 .3761 L

s

.2186 .36995 m

.24751 .3761 L

s

.2186 .36995 m

.22123 .3006 L

s

.19456 .39988 m

.2186 .36995 L

s

.59197 .59001 m .5925 .6345 L .58537 .64187 L .177 0 0 r

F

0 g

.58537 .64187 m

.63457 .65048 L

s

.59197 .59001 m .58537 .64187 L .5925 .6345 L 0 .128 .594 r

F

.56037 .58695 m .56282 .59005 L .59197 .59001 L 0 .905 1 r

F

.56037 .58695 m .59197 .59001 L .58605 .58221 L F

.58605 .58221 m .59197 .59001 L .5925 .6345 L 0 .874 .532 r

F

.58605 .58221 m .5925 .6345 L .59197 .59001 L 1 0 0 r

F

.58605 .58221 m .5925 .6345 L .58656 .62703 L 0 .874 .532 r

F

.55332 .58467 m .56037 .58695 L .58605 .58221 L 0 .905 1 r

F

.55332 .58467 m .58605 .58221 L .56845 .57645 L F

.56845 .57645 m .56886 .62149 L .58656 .62703 L .961 0 0 r

F

.56845 .57645 m .58656 .62703 L .56886 .62149 L 0 .751 .718 r

F

.56282 .59005 m .56318 .63454 L .56041 .6375 L 0 .112 .584 r

F

.56037 .58695 m .56318 .63454 L .56282 .59005 L 0 .875 .545 r

F

.56037 .58695 m .56072 .63156 L .56318 .63454 L F

.55332 .58467 m .56072 .63156 L .56037 .58695 L 0 .75 .719 r

F

.55332 .58467 m .55364 .62938 L .56072 .63156 L F

.55332 .58467 m .56886 .62149 L .55364 .62938 L 0 .353 .691 r

F

.55332 .58467 m .55364 .62938 L .56886 .62149 L F

.54358 .58385 m .55364 .62938 L .55332 .58467 L 0 .661 .739 r

F

.54358 .58385 m .54384 .62859 L .55364 .62938 L F

.54358 .58385 m .55332 .58467 L .56845 .57645 L 0 .905 1 r

F

.54358 .58385 m .56845 .57645 L .54388 .57434 L F

.54388 .57434 m .54414 .61948 L .56886 .62149 L .851 0 0 r

F

.54388 .57434 m .56886 .62149 L .54414 .61948 L 0 .661 .739 r

F

.50121 .58234 m .5266 .587 L .52675 .63161 L p 0 .702 .734 r

F P

0 g

s

.5266 .587 m .53398 .62941 L .53378 .5847 L 0 .465 .722 r

F

.5266 .587 m .52675 .63161 L .53398 .62941 L F

.53378 .5847 m .54384 .62859 L .54358 .58385 L 0 .582 .74 r

F

.53378 .5847 m .53398 .62941 L .54384 .62859 L F

.5266 .587 m .51918 .57652 L .50121 .58234 L 0 .905 1 r

F

.51918 .57652 m .51929 .62156 L .54414 .61948 L .753 0 0 r

F

.51918 .57652 m .54414 .61948 L .51929 .62156 L 0 .581 .739 r

F

.51929 .62156 m .52386 .61782 L .54414 .61948 L .665 0 0 r

F

.5266 .587 m .53378 .5847 L .51918 .57652 L 0 .905 1 r

F

.53378 .5847 m .54388 .57434 L .51918 .57652 L F

.53378 .5847 m .54358 .58385 L .54388 .57434 L F

.51918 .57652 m .54414 .61948 L .54388 .57434 L .753 0 0 r

F

.51918 .57652 m .54388 .57434 L .54414 .61948 L 0 .581 .739 r

F

.52386 .61782 m .54477 .60069 L .54414 .61948 L .665 0 0 r

F

.54414 .61948 m .55423 .61692 L .56886 .62149 L F

.58605 .58221 m .58656 .62703 L .5925 .6345 L 1 0 0 r

F

.55332 .58467 m .56845 .57645 L .56886 .62149 L 0 .353 .691 r

F

.55332 .58467 m .56886 .62149 L .56845 .57645 L F

.56845 .57645 m .58656 .62703 L .58605 .58221 L .961 0 0 r

F

.56845 .57645 m .58605 .58221 L .58656 .62703 L 0 .751 .718 r

F

.56845 .57645 m .60009 .6053 L .56886 .62149 L .466 0 0 r

F

.56845 .57645 m .56886 .62149 L .60009 .6053 L F

.54388 .57434 m .56886 .62149 L .56845 .57645 L .851 0 0 r

F

.54388 .57434 m .56845 .57645 L .56886 .62149 L 0 .661 .739 r

F

.55423 .61692 m .57444 .6118 L .56886 .62149 L .665 0 0 r

F

.57444 .6118 m .60009 .6053 L .57827 .61661 L F

.57444 .6118 m .57827 .61661 L .56886 .62149 L F

.56886 .62149 m .58162 .62082 L .58656 .62703 L F

.58162 .62082 m .63901 .61781 L .58656 .62703 L F

.58656 .62703 m .59843 .62838 L .5925 .6345 L F

.59843 .62838 m .65116 .63442 L .5925 .6345 L F

.56318 .63454 m .58537 .64187 L .56041 .6375 L 0 .908 1 r

F

0 g

.56036 .63145 m

.56041 .6375 L

s

.56318 .63454 m .5925 .6345 L .58537 .64187 L 0 .908 1 r

F

0 g

.56041 .6375 m

.58537 .64187 L

s

.59955 .49271 m .60523 .50104 L .66536 .50095 L .693 0 0 r

F

.59955 .49271 m .66536 .50095 L .65345 .48188 L F

.65345 .48188 m .66536 .50095 L .6668 .56696 L 1 0 0 r

F

0 g

.6485 .51939 m

.65775 .50927 L

s

.59955 .49271 m

.60523 .50104 L

s

.70708 .28102 m .70906 .35129 L .75138 .37522 L 1 0 0 r

F

.70906 .35129 m .78019 .36896 L .75138 .37522 L .712 0 0 r

F

0 g

.75138 .37522 m

.77435 .40195 L

s

.57681 .56709 m .59904 .57482 L .57413 .57012 L 0 .904 1 r

F

0 g

.57407 .56391 m

.57413 .57012 L

s

.57681 .56709 m .60615 .56705 L .59904 .57482 L 0 .904 1 r

F

.54286 .27622 m .59642 .32459 L .54311 .31883 L .852 0 0 r

F

0 g

.59586 .28215 m

.59642 .32459 L

s

.59402 .32621 m

.59642 .32459 L

s

.59642 .32459 m

.60247 .32712 L

s

.4896 .28235 m

.54286 .27622 L

s

.54286 .27622 m

.59586 .28215 L

s

.48954 .32479 m

.54311 .31883 L

s

.58605 .58221 m .59197 .59001 L .65028 .58993 L .676 0 0 r

F

0 g

.54311 .31883 m

.59642 .32459 L

s

.58605 .58221 m .65028 .58993 L .63819 .5726 L .676 0 0 r

F

.63819 .5726 m .65028 .58993 L .65116 .63442 L 1 0 0 r

F

0 g

.6338 .60668 m

.64331 .59701 L

s

.64978 .58438 m

.65361 .58047 L

s

.57413 .57012 m

.59904 .57482 L

s

.5343 .4964 m

.5383 .49721 L

s

.53392 .41377 m .55879 .38795 L .55787 .41131 L .706 0 0 r

F

.53392 .41377 m .50358 .39374 L .55879 .38795 L F

0 g

.53392 .41377 m

.53392 .41377 L

s

.46399 .40907 m

.51644 .42035 L

s

.58163 .41369 m .61356 .39355 L .65196 .40875 L .706 0 0 r

F

.55787 .41131 m .61356 .39355 L .58163 .41369 L F

0 g

.58092 .34931 m

.58152 .40377 L

s

.58163 .41369 m

.58163 .41369 L

s

.21723 .61929 m .21017 .5918 L .23999 .59694 L .669 0 0 r

F

.21723 .61929 m .18565 .61678 L .21017 .5918 L F

0 g

.21482 .6421 m

.21723 .61929 L

s

.18385 .64214 m

.18565 .61678 L

s

.50206 .58249 m

.5192 .58564 L

s

.52672 .62094 m

.52675 .63161 L

s

.73133 .27137 m .78019 .36896 L .73357 .34208 L 1 0 0 r

F

.70906 .35129 m .73357 .34208 L .78019 .36896 L .712 0 0 r

F

0 g

.78019 .36896 m

.80499 .39884 L

s

.75639 .52295 m .75888 .59621 L .78233 .61851 L 1 0 0 r

F

.75888 .59621 m .81389 .61592 L .78233 .61851 L .669 0 0 r

F

0 g

.78233 .61851 m

.78542 .64133 L

s

.55787 .41131 m .55879 .38795 L .61356 .39355 L .706 0 0 r

F

0 g

.55787 .41131 m

.55787 .41131 L

s

.5166 .49284 m .50361 .4677 L .46364 .48218 L .693 0 0 r

F

.5166 .49284 m .53425 .48662 L .50361 .4677 L F

.5166 .49284 m .46364 .48218 L .46331 .54922 L .9 0 0 r

F

.5166 .49284 m .53425 .48662 L .53456 .55342 L 0 .461 .72 r

F

.53425 .48662 m .53456 .55342 L .55896 .55123 L .752 0 0 r

F

.53425 .48662 m .55896 .55123 L .53456 .55342 L 0 .581 .739 r

F

.53425 .48662 m .55844 .4843 L .55896 .55123 L F

.55844 .4843 m .58316 .55335 L .55896 .55123 L 0 .661 .738 r

F

.53456 .55342 m .53891 .54947 L .55896 .55123 L .679 0 0 r

F

.53891 .54947 m .55991 .53037 L .55896 .55123 L F

.53456 .55342 m .50364 .53553 L .55991 .53037 L F

0 g

.5166 .49284 m

.5167 .53433 L

s

.5166 .49284 m

.53425 .48662 L

s

.56072 .63156 m .5925 .6345 L .56318 .63454 L 0 .908 1 r

F

0 g

.56041 .6375 m

.56318 .63454 L

s

.58242 .48655 m .59955 .49271 L .65345 .48188 L .693 0 0 r

F

.58242 .48655 m .59955 .49271 L .60043 .55918 L 0 .752 .716 r

F

.58242 .48655 m .60043 .55918 L .58316 .55335 L F

.58316 .55335 m .61573 .53537 L .65482 .54894 L .679 0 0 r

F

.58316 .55335 m .65482 .54894 L .60043 .55918 L F

0 g

.58242 .48655 m

.59955 .49271 L

s

.59955 .49271 m

.59955 .49271 L

s

.56072 .63156 m .58656 .62703 L .5925 .6345 L 0 .908 1 r

F

0 g

.58537 .64187 m

.5925 .6345 L

s

.63819 .5726 m .65116 .63442 L .63901 .61781 L 1 0 0 r

F

.58656 .62703 m .63901 .61781 L .65116 .63442 L .665 0 0 r

F

0 g

.63457 .65048 m

.65116 .63442 L

s

.61256 .32821 m .65196 .40875 L .61356 .39355 L .966 0 0 r

F

0 g

.65196 .40875 m

.66378 .42894 L

s

.57451 .56406 m .60615 .56705 L .57681 .56709 L 0 .904 1 r

F

0 g

.57413 .57012 m

.57681 .56709 L

s

.57451 .56406 m .60043 .55918 L .60615 .56705 L 0 .904 1 r

F

.65345 .48188 m .6668 .56696 L .65482 .54894 L 1 0 0 r

F

0 g

.65361 .58047 m

.6668 .56696 L

s

.78581 .51738 m .81389 .61592 L .78859 .59098 L 1 0 0 r

F

.75888 .59621 m .78859 .59098 L .81389 .61592 L .669 0 0 r

F

0 g

.81389 .61592 m

.81645 .64129 L

s

.50121 .58234 m .51918 .57652 L .51929 .62156 L 0 .462 .721 r

F

.50121 .58234 m .51929 .62156 L .51918 .57652 L .605 0 0 r

F

.50121 .58234 m .4892 .55973 L .4497 .57288 L .676 0 0 r

F

.50121 .58234 m .51918 .57652 L .4892 .55973 L F

.50121 .58234 m .4497 .57288 L .4494 .61807 L .899 0 0 r

F

0 g

.50121 .58234 m

.50121 .58234 L

s

.56845 .57645 m .58605 .58221 L .63819 .5726 L .676 0 0 r

F

0 g

.56845 .57645 m

.58605 .58221 L

s

.2912 .2818 m .34805 .33284 L .34952 .26167 L .635 0 0 r

F

.2912 .2818 m .2892 .35203 L .34805 .33284 L F

.2912 .2818 m .33158 .24955 L .26676 .27225 L .722 0 0 r

F

.2912 .2818 m .34952 .26167 L .33158 .24955 L F

0 g

.26596 .29721 m

.2912 .2818 L

s

.52675 .63161 m .51929 .62156 L .53398 .62941 L 0 .908 1 r

F

.52675 .63161 m .50122 .62714 L .51929 .62156 L F

.55364 .62938 m .58656 .62703 L .56072 .63156 L F

0 g

.56072 .63156 m

.56318 .63454 L

s

.55357 .62025 m

.55364 .62938 L

s

.64825 .2611 m .70906 .35129 L .70708 .28102 L .937 0 0 r

F

.64825 .2611 m .70708 .28102 L .73133 .27137 L .722 0 0 r

F

0 g

.70708 .28102 m

.73211 .296 L

s

.54222 .5641 m .53456 .55342 L .54913 .56185 L 0 .904 1 r

F

0 g

.54216 .55274 m

.54219 .55784 L

s

.54222 .5641 m .51675 .5593 L .53456 .55342 L 0 .904 1 r

F

.56781 .56183 m .60043 .55918 L .57451 .56406 L F

0 g

.57451 .56406 m

.57681 .56709 L

s

.50354 .32841 m .55879 .38795 L .50358 .39374 L .751 0 0 r

F

0 g

.46399 .40907 m

.50358 .39374 L

s

.50354 .32841 m .55827 .32235 L .55879 .38795 L .751 0 0 r

F

0 g

.4643 .34447 m

.50354 .32841 L

s

.55827 .32235 m .61256 .32821 L .61356 .39355 L .852 0 0 r

F

0 g

.61256 .32821 m

.65064 .34413 L

s

.53398 .62941 m .54414 .61948 L .54384 .62859 L 0 .908 1 r

F

.53398 .62941 m .51929 .62156 L .54414 .61948 L F

0 g

.52675 .63161 m

.53398 .62941 L

s

.50122 .62714 m

.52675 .63161 L

s

.55364 .62938 m .56886 .62149 L .58656 .62703 L 0 .908 1 r

F

.54384 .62859 m .56886 .62149 L .55364 .62938 L F

0 g

.55364 .62938 m

.56072 .63156 L

s

.53425 .48662 m .55938 .46223 L .50361 .4677 L .693 0 0 r

F

.53425 .48662 m .55844 .4843 L .55938 .46223 L F

0 g

.53425 .48662 m

.53425 .48662 L

s

.53425 .48662 m

.55844 .4843 L

s

.58242 .48655 m .65345 .48188 L .61469 .46752 L .693 0 0 r

F

.58242 .48655 m .61573 .53537 L .58316 .55335 L .466 0 0 r

F

.58242 .48655 m .61469 .46752 L .61573 .53537 L F

.58242 .48655 m .61573 .53537 L .61469 .46752 L F

.58242 .48655 m .58316 .55335 L .61573 .53537 L F

.55844 .4843 m .58242 .48655 L .61469 .46752 L .693 0 0 r

F

.55844 .4843 m .58242 .48655 L .58316 .55335 L 0 .661 .738 r

F

.55896 .55123 m .61573 .53537 L .58316 .55335 L .679 0 0 r

F

0 g

.58242 .48655 m

.58306 .54449 L

s

.54913 .56185 m .55896 .55123 L .5585 .56102 L 0 .904 1 r

F

.54913 .56185 m .53456 .55342 L .55896 .55123 L F

0 g

.54222 .5641 m

.54913 .56185 L

s

.56781 .56183 m .58316 .55335 L .60043 .55918 L 0 .904 1 r

F

.5585 .56102 m .58316 .55335 L .56781 .56183 L F

0 g

.56781 .56183 m

.57451 .56406 L

s

.56772 .552 m

.56778 .55814 L

s

.54384 .62859 m .54414 .61948 L .56886 .62149 L 0 .908 1 r

F

0 g

.53398 .62941 m

.54384 .62859 L

s

.55364 .62938 m

.56886 .62149 L

s

.54384 .62859 m

.55364 .62938 L

s

.5585 .56102 m .55896 .55123 L .58316 .55335 L 0 .904 1 r

F

0 g

.54913 .56185 m

.5585 .56102 L

s

.58316 .55335 m

.58316 .55335 L

s

.5585 .56102 m

.56781 .56183 L

s

.55844 .4843 m .61469 .46752 L .55938 .46223 L .693 0 0 r

F

0 g

.55844 .4843 m

.55844 .4843 L

s

.55844 .4843 m

.55844 .4843 L

s

.55844 .4843 m

.58242 .48655 L

s

.50122 .62714 m .4494 .61807 L .4497 .57288 L p .899 0 0 r

F P

0 g

s

.50122 .62714 m .4494 .61807 L .48914 .60546 L .665 0 0 r

F

0 g

.56886 .62149 m

.58656 .62703 L

s

.51675 .5593 m .46331 .54922 L .46364 .48218 L p .9 0 0 r

F P

0 g

s

.51675 .5593 m .46331 .54922 L .50364 .53553 L .679 0 0 r

F

.51918 .57652 m .5445 .55476 L .4892 .55973 L .676 0 0 r

F

0 g

.53517 .56277 m

.54222 .5641 L

s

.51918 .57652 m .54388 .57434 L .5445 .55476 L .676 0 0 r

F

.56845 .57645 m .63819 .5726 L .59949 .55956 L F

0 g

.60043 .55918 m

.6011 .56011 L

s

.56845 .57645 m .59949 .55956 L .60009 .6053 L .466 0 0 r

F

.56845 .57645 m .60009 .6053 L .59949 .55956 L F

0 g

.56845 .57645 m

.56878 .61323 L

s

.54388 .57434 m .56845 .57645 L .59949 .55956 L .676 0 0 r

F

0 g

.51918 .57652 m

.54388 .57434 L

s

.54388 .57434 m

.56845 .57645 L

s

.53456 .55342 m

.53456 .55342 L

s

.52527 .55649 m

.53456 .55342 L

s

.55827 .32235 m .61356 .39355 L .55879 .38795 L .852 0 0 r

F

0 g

.61356 .39355 m

.65196 .40875 L

s

.58163 .41369 m

.61356 .39355 L

s

.50354 .32841 m

.55827 .32235 L

s

.61256 .32821 m

.61356 .39355 L

s

.55827 .32235 m

.61256 .32821 L

s

.46364 .48218 m .50364 .53553 L .46331 .54922 L .597 0 0 r

F

0 g

.46331 .54922 m

.50939 .55791 L

s

.46364 .48218 m .50361 .4677 L .50364 .53553 L .597 0 0 r

F

0 g

.50362 .49023 m

.5166 .49284 L

s

.46331 .54922 m

.46364 .48218 L

s

.26676 .27225 m .32993 .32127 L .2645 .34292 L .632 0 0 r

F

.26676 .27225 m .33158 .24955 L .32993 .32127 L F

0 g

.22123 .3006 m

.26676 .27225 L

s

.61469 .46752 m .65345 .48188 L .65482 .54894 L .966 0 0 r

F

0 g

.65345 .48188 m

.66536 .50095 L

s

.54388 .57434 m .59949 .55956 L .5445 .55476 L .676 0 0 r

F

0 g

.58316 .55335 m

.60043 .55918 L

s

.57567 .55748 m

.58316 .55335 L

s

.64825 .2611 m .73133 .27137 L .66592 .2489 L .722 0 0 r

F

.66592 .2489 m .73133 .27137 L .73357 .34208 L .939 0 0 r

F

0 g

.73133 .27137 m

.77757 .29957 L

s

.24248 .52373 m .28278 .57683 L .28491 .50229 L .496 0 0 r

F

.24248 .52373 m .23999 .59694 L .28278 .57683 L F

.24248 .52373 m .25968 .49416 L .21296 .51826 L .685 0 0 r

F

.24248 .52373 m .28491 .50229 L .25968 .49416 L F

.24248 .52373 m .21017 .5918 L .23999 .59694 L .896 0 0 r

F

.24248 .52373 m .21296 .51826 L .21017 .5918 L F

.24248 .52373 m .21017 .5918 L .21296 .51826 L F

.24248 .52373 m .23999 .59694 L .21017 .5918 L F

.4497 .57288 m .48914 .60546 L .4494 .61807 L .598 0 0 r

F

.4497 .57288 m .4892 .55973 L .48914 .60546 L F

0 g

.48917 .58012 m

.50121 .58234 L

s

.4494 .61807 m

.4497 .57288 L

s

.2892 .35203 m .32993 .32127 L .34805 .33284 L .712 0 0 r

F

.2892 .35203 m .2645 .34292 L .32993 .32127 L F

0 g

.24751 .3761 m

.2892 .35203 L

s

.2186 .36995 m

.2645 .34292 L

s

.59949 .55956 m .63819 .5726 L .63901 .61781 L .964 0 0 r

F

0 g

.63819 .5726 m

.65028 .58993 L

s

.71332 .50162 m .75888 .59621 L .75639 .52295 L 1 0 0 r

F

.71332 .50162 m .75639 .52295 L .78581 .51738 L .685 0 0 r

F

0 g

.75639 .52295 m

.77969 .54676 L

s

.64825 .2611 m .64969 .33229 L .70906 .35129 L .937 0 0 r

F

.64969 .33229 m .73357 .34208 L .70906 .35129 L .712 0 0 r

F

0 g

.70906 .35129 m

.75138 .37522 L

s

.50358 .39374 m

.55879 .38795 L

s

.55879 .38795 m

.61356 .39355 L

s

.51929 .62156 m .48914 .60546 L .54477 .60069 L .665 0 0 r

F

0 g

.4494 .61807 m

.50122 .62714 L

s

.51929 .62156 m

.54414 .61948 L

s

.56886 .62149 m .60009 .6053 L .63901 .61781 L .665 0 0 r

F

0 g

.54414 .61948 m

.56886 .62149 L

s

.53456 .55342 m

.55896 .55123 L

s

.54414 .61948 m .54477 .60069 L .60009 .6053 L .665 0 0 r

F

.55896 .55123 m .55991 .53037 L .61573 .53537 L .679 0 0 r

F

0 g

.55896 .55123 m

.58316 .55335 L

s

.55896 .55123 m

.55896 .55123 L

s

.21296 .51826 m .25728 .56922 L .21017 .5918 L .488 0 0 r

F

0 g

.24155 .55112 m

.24248 .52373 L

s

.21296 .51826 m .25968 .49416 L .25728 .56922 L .488 0 0 r

F

0 g

.18861 .54491 m

.21296 .51826 L

s

.71332 .50162 m .78581 .51738 L .73836 .49341 L .685 0 0 r

F

.73836 .49341 m .78581 .51738 L .78859 .59098 L 1 0 0 r

F

0 g

.78581 .51738 m

.81094 .54399 L

s

.59949 .55956 m .63901 .61781 L .60009 .6053 L .964 0 0 r

F

0 g

.63901 .61781 m

.65116 .63442 L

s

.34952 .26167 m .41983 .32039 L .42061 .24862 L .717 0 0 r

F

.34952 .26167 m .34805 .33284 L .41983 .32039 L F

.34952 .26167 m .41105 .23479 L .33158 .24955 L .722 0 0 r

F

.34952 .26167 m .42061 .24862 L .41105 .23479 L F

0 g

.33116 .26801 m

.34952 .26167 L

s

.64825 .2611 m .66755 .32066 L .64969 .33229 L .466 0 0 r

F

.64825 .2611 m .66592 .2489 L .66755 .32066 L F

0 g

.66634 .26723 m

.68342 .27301 L

s

.64825 .2611 m .66755 .32066 L .66592 .2489 L .466 0 0 r

F

.64825 .2611 m .64969 .33229 L .66755 .32066 L F

.57681 .24832 m .64969 .33229 L .64825 .2611 L .879 0 0 r

F

.57681 .24832 m .64825 .2611 L .66592 .2489 L .722 0 0 r

F

.61469 .46752 m .65482 .54894 L .61573 .53537 L .966 0 0 r

F

0 g

.65482 .54894 m

.6668 .56696 L

s

.66592 .2489 m .73357 .34208 L .66755 .32066 L .939 0 0 r

F

.64969 .33229 m .66755 .32066 L .73357 .34208 L .712 0 0 r

F

0 g

.73357 .34208 m

.78019 .36896 L

s

.23999 .59694 m .25728 .56922 L .28278 .57683 L .669 0 0 r

F

.23999 .59694 m .21017 .5918 L .25728 .56922 L F

0 g

.21723 .61929 m

.23999 .59694 L

s

.21017 .5918 m

.23999 .59694 L

s

.21017 .5918 m

.21296 .51826 L

s

.18565 .61678 m

.21017 .5918 L

s

.71332 .50162 m .71543 .57621 L .75888 .59621 L 1 0 0 r

F

.71543 .57621 m .78859 .59098 L .75888 .59621 L .669 0 0 r

F

0 g

.75888 .59621 m

.78233 .61851 L

s

.50361 .4677 m .55991 .53037 L .50364 .53553 L .751 0 0 r

F

0 g

.46331 .54922 m

.50364 .53553 L

s

.50361 .4677 m .55938 .46223 L .55991 .53037 L .751 0 0 r

F

0 g

.46364 .48218 m

.50361 .4677 L

s

.55938 .46223 m .61469 .46752 L .61573 .53537 L .852 0 0 r

F

0 g

.61469 .46752 m

.65345 .48188 L

s

.4892 .55973 m .54477 .60069 L .48914 .60546 L .752 0 0 r

F

0 g

.4494 .61807 m

.48914 .60546 L

s

.4892 .55973 m .5445 .55476 L .54477 .60069 L .752 0 0 r

F

0 g

.4497 .57288 m

.4892 .55973 L

s

.5445 .55476 m .59949 .55956 L .60009 .6053 L .852 0 0 r

F

0 g

.59949 .55956 m

.63819 .5726 L

s

.73836 .49341 m .78859 .59098 L .74074 .56851 L 1 0 0 r

F

.71543 .57621 m .74074 .56851 L .78859 .59098 L .669 0 0 r

F

0 g

.78859 .59098 m

.81389 .61592 L

s

.33158 .24955 m .41016 .30719 L .32993 .32127 L .715 0 0 r

F

.33158 .24955 m .41105 .23479 L .41016 .30719 L F

0 g

.26676 .27225 m

.33158 .24955 L

s

.34805 .33284 m .41016 .30719 L .41983 .32039 L .712 0 0 r

F

.34805 .33284 m .32993 .32127 L .41016 .30719 L F

0 g

.2892 .35203 m

.34805 .33284 L

s

.2645 .34292 m

.32993 .32127 L

s

.57681 .24832 m .66592 .2489 L .58607 .23445 L .722 0 0 r

F

.58607 .23445 m .66592 .2489 L .66755 .32066 L .88 0 0 r

F

0 g

.66592 .2489 m

.73133 .27137 L

s

.55938 .46223 m .61573 .53537 L .55991 .53037 L .852 0 0 r

F

0 g

.61573 .53537 m

.65482 .54894 L

s

.58316 .55335 m

.61573 .53537 L

s

.50361 .4677 m

.55938 .46223 L

s

.61469 .46752 m

.61573 .53537 L

s

.55938 .46223 m

.61469 .46752 L

s

.42061 .24862 m .49864 .31599 L .49865 .24401 L .777 0 0 r

F

.42061 .24862 m .41983 .32039 L .49864 .31599 L F

.42061 .24862 m .49849 .22956 L .41105 .23479 L .722 0 0 r

F

.42061 .24862 m .49865 .24401 L .49849 .22956 L F

0 g

.41086 .25041 m

.42061 .24862 L

s

.57681 .24832 m .57756 .3201 L .64969 .33229 L .879 0 0 r

F

.57756 .3201 m .66755 .32066 L .64969 .33229 L .712 0 0 r

F

0 g

.64969 .33229 m

.70906 .35129 L

s

.64906 .30109 m

.64946 .32055 L

s

.49865 .24401 m .57756 .3201 L .57681 .24832 L .828 0 0 r

F

.49865 .24401 m .57681 .24832 L .58607 .23445 L .722 0 0 r

F

0 g

.57681 .24832 m

.60373 .25314 L

s

.5445 .55476 m .60009 .6053 L .54477 .60069 L .852 0 0 r

F

0 g

.60009 .6053 m

.63901 .61781 L

s

.56886 .62149 m

.60009 .6053 L

s

.4892 .55973 m

.5445 .55476 L

s

.59949 .55956 m

.60009 .6053 L

s

.5445 .55476 m

.59949 .55956 L

s

.48914 .60546 m

.54477 .60069 L

s

.54477 .60069 m

.60009 .6053 L

s

.49865 .24401 m .49864 .31599 L .57756 .3201 L .828 0 0 r

F

.49865 .24401 m .58607 .23445 L .49849 .22956 L .722 0 0 r

F

0 g

.42061 .24862 m

.49865 .24401 L

s

.49865 .24401 m

.57681 .24832 L

s

.28491 .50229 m .34335 .56078 L .34491 .48517 L .635 0 0 r

F

.28491 .50229 m .28278 .57683 L .34335 .56078 L F

.28491 .50229 m .32638 .47485 L .25968 .49416 L .685 0 0 r

F

.28491 .50229 m .34491 .48517 L .32638 .47485 L F

0 g

.259 .51538 m

.28491 .50229 L

s

.50364 .53553 m

.55991 .53037 L

s

.55991 .53037 m

.61573 .53537 L

s

.65279 .48468 m .71543 .57621 L .71332 .50162 L .937 0 0 r

F

.65279 .48468 m .71332 .50162 L .73836 .49341 L .685 0 0 r

F

0 g

.71332 .50162 m

.73902 .51435 L

s

.58607 .23445 m .66755 .32066 L .58692 .30687 L .88 0 0 r

F

.57756 .3201 m .58692 .30687 L .66755 .32066 L .712 0 0 r

F

0 g

.64969 .33229 m

.66755 .32066 L

s

.66755 .32066 m

.73357 .34208 L

s

.66592 .2489 m

.66755 .32066 L

s

.41983 .32039 m .49847 .3022 L .49864 .31599 L .712 0 0 r

F

.41983 .32039 m .41016 .30719 L .49847 .3022 L F

0 g

.34805 .33284 m

.41983 .32039 L

s

.49864 .31599 m .58692 .30687 L .57756 .3201 L .712 0 0 r

F

0 g

.57756 .3201 m

.64969 .33229 L

s

.41105 .23479 m .49847 .3022 L .41016 .30719 L .776 0 0 r

F

0 g

.32993 .32127 m

.41016 .30719 L

s

.41105 .23479 m .49849 .22956 L .49847 .3022 L .776 0 0 r

F

0 g

.33158 .24955 m

.41105 .23479 L

s

.49849 .22956 m .58607 .23445 L .58692 .30687 L .828 0 0 r

F

0 g

.58607 .23445 m

.66592 .2489 L

s

.25968 .49416 m .32461 .5511 L .25728 .56922 L .632 0 0 r

F

.25968 .49416 m .32638 .47485 L .32461 .5511 L F

0 g

.21296 .51826 m

.25968 .49416 L

s

.65279 .48468 m .73836 .49341 L .67105 .4743 L .685 0 0 r

F

.67105 .4743 m .73836 .49341 L .74074 .56851 L .939 0 0 r

F

0 g

.73836 .49341 m

.78581 .51738 L

s

.49864 .31599 m .49847 .3022 L .58692 .30687 L .712 0 0 r

F

0 g

.41983 .32039 m

.49864 .31599 L

s

.49864 .31599 m

.57756 .3201 L

s

.28278 .57683 m .32461 .5511 L .34335 .56078 L .669 0 0 r

F

.28278 .57683 m .25728 .56922 L .32461 .5511 L F

0 g

.23999 .59694 m

.28278 .57683 L

s

.21017 .5918 m

.25728 .56922 L

s

.65279 .48468 m .65433 .56032 L .71543 .57621 L .937 0 0 r

F

.65433 .56032 m .74074 .56851 L .71543 .57621 L .669 0 0 r

F

0 g

.71543 .57621 m

.75888 .59621 L

s

.49849 .22956 m .58692 .30687 L .49847 .3022 L .828 0 0 r

F

0 g

.58692 .30687 m

.66755 .32066 L

s

.41105 .23479 m

.49849 .22956 L

s

.49849 .22956 m

.58607 .23445 L

s

.34491 .48517 m .41733 .55036 L .41816 .47406 L .717 0 0 r

F

.34491 .48517 m .34335 .56078 L .41733 .55036 L F

.34491 .48517 m .40826 .46227 L .32638 .47485 L .685 0 0 r

F

.34491 .48517 m .41816 .47406 L .40826 .46227 L F

0 g

.32601 .49056 m

.34491 .48517 L

s

.65279 .48468 m .67279 .55058 L .65433 .56032 L .466 0 0 r

F

.65279 .48468 m .67105 .4743 L .67279 .55058 L F

0 g

.67141 .48989 m

.68551 .49384 L

s

.65279 .48468 m .67279 .55058 L .67105 .4743 L .466 0 0 r

F

.65279 .48468 m .65433 .56032 L .67279 .55058 L F

.57919 .4738 m .65433 .56032 L .65279 .48468 L .879 0 0 r

F

.57919 .4738 m .65279 .48468 L .67105 .4743 L .685 0 0 r

F

0 g

.41016 .30719 m

.49847 .3022 L

s

.49847 .3022 m

.58692 .30687 L

s

.67105 .4743 m .74074 .56851 L .67279 .55058 L .939 0 0 r

F

.65433 .56032 m .67279 .55058 L .74074 .56851 L .669 0 0 r

F

0 g

.74074 .56851 m

.78859 .59098 L

s

.32638 .47485 m .40732 .5393 L .32461 .5511 L .715 0 0 r

F

.32638 .47485 m .40826 .46227 L .40732 .5393 L F

0 g

.25968 .49416 m

.32638 .47485 L

s

.34335 .56078 m .40732 .5393 L .41733 .55036 L .669 0 0 r

F

.34335 .56078 m .32461 .5511 L .40732 .5393 L F

0 g

.28278 .57683 m

.34335 .56078 L

s

.25728 .56922 m

.32461 .5511 L

s

.57919 .4738 m .67105 .4743 L .58876 .46198 L .685 0 0 r

F

.58876 .46198 m .67105 .4743 L .67279 .55058 L .88 0 0 r

F

0 g

.67105 .4743 m

.73836 .49341 L

s

.41816 .47406 m .4986 .54667 L .49861 .47013 L .777 0 0 r

F

.41816 .47406 m .41733 .55036 L .4986 .54667 L F

.41816 .47406 m .49844 .45782 L .40826 .46227 L .685 0 0 r

F

.41816 .47406 m .49861 .47013 L .49844 .45782 L F

0 g

.4081 .47558 m

.41816 .47406 L

s

.57919 .4738 m .57999 .55012 L .65433 .56032 L .879 0 0 r

F

.57999 .55012 m .67279 .55058 L .65433 .56032 L .669 0 0 r

F

0 g

.65433 .56032 m

.71543 .57621 L

s

.65372 .53048 m

.65413 .55049 L

s

.49861 .47013 m .57999 .55012 L .57919 .4738 L .828 0 0 r

F

.49861 .47013 m .57919 .4738 L .58876 .46198 L .685 0 0 r

F

0 g

.57919 .4738 m

.60336 .47737 L

s

.49861 .47013 m .4986 .54667 L .57999 .55012 L .828 0 0 r

F

.49861 .47013 m .58876 .46198 L .49844 .45782 L .685 0 0 r

F

0 g

.41816 .47406 m

.49861 .47013 L

s

.49861 .47013 m

.57919 .4738 L

s

.58876 .46198 m .67279 .55058 L .58967 .53903 L .88 0 0 r

F

.57999 .55012 m .58967 .53903 L .67279 .55058 L .669 0 0 r

F

0 g

.65433 .56032 m

.67279 .55058 L

s

.67279 .55058 m

.74074 .56851 L

s

.67105 .4743 m

.67279 .55058 L

s

.41733 .55036 m .49843 .53512 L .4986 .54667 L .669 0 0 r

F

.41733 .55036 m .40732 .5393 L .49843 .53512 L F

0 g

.34335 .56078 m

.41733 .55036 L

s

.4986 .54667 m .58967 .53903 L .57999 .55012 L .669 0 0 r

F

0 g

.57999 .55012 m

.65433 .56032 L

s

.40826 .46227 m .49843 .53512 L .40732 .5393 L .776 0 0 r

F

0 g

.32461 .5511 m

.40732 .5393 L

s

.40826 .46227 m .49844 .45782 L .49843 .53512 L .776 0 0 r

F

0 g

.32638 .47485 m

.40826 .46227 L

s

.49844 .45782 m .58876 .46198 L .58967 .53903 L .828 0 0 r

F

0 g

.58876 .46198 m

.67105 .4743 L

s

.4986 .54667 m .49843 .53512 L .58967 .53903 L .669 0 0 r

F

0 g

.41733 .55036 m

.4986 .54667 L

s

.4986 .54667 m

.57999 .55012 L

s

.49844 .45782 m .58967 .53903 L .49843 .53512 L .828 0 0 r

F

0 g

.58967 .53903 m

.67279 .55058 L

s

.40826 .46227 m

.49844 .45782 L

s

.49844 .45782 m

.58876 .46198 L

s

.40732 .5393 m

.49843 .53512 L

s

.49843 .53512 m

.58967 .53903 L

s

[ .01 .01 ] 0 setdash

.36102 .13705 m

.95343 .29205 L

s

.95343 .29205 m

.97417 .62726 L

s

.97417 .62726 m

.35383 .5079 L

s

.35383 .5079 m

.36102 .13705 L

s

.08119 .3876 m

.06355 .70016 L

s

.06355 .70016 m

.35383 .5079 L

s

.35383 .5079 m

.36102 .13705 L

s

.36102 .13705 m

.08119 .3876 L

s

.003 w

[ ] 0 setdash

.95343 .29205 m

.97417 .62726 L

s

.25 Mabswid

.95803 .36634 m

.95196 .36485 L

s

gsave

.97016 .36933 -61 -9.65233 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

69.875000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(50) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.96357 .45591 m

.95748 .45452 L

s

gsave

.97576 .45869 -61 -9.79093 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.96925 .54767 m

.96313 .54639 L

s

gsave

.98148 .55022 -61 -9.93326 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(50) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.95913 .38409 m

.95548 .3832 L

s

.96023 .40191 m

.95658 .40104 L

s

.96134 .41982 m

.95769 .41897 L

s

.96245 .43782 m

.9588 .43698 L

s

.96469 .47408 m

.96103 .47326 L

s

.96582 .49234 m

.96216 .49154 L

s

.96696 .5107 m

.96329 .5099 L

s

.9681 .52914 m

.96443 .52836 L

s

.95694 .34869 m

.9533 .34778 L

s

.95585 .33112 m

.95221 .33019 L

s

.95477 .31363 m

.95113 .31269 L

s

.95369 .29622 m

.95006 .29527 L

s

.9704 .56629 m

.96673 .56554 L

s

.97156 .585 m

.96788 .58426 L

s

.97272 .60381 m

.96904 .60308 L

s

.97389 .62271 m

.97021 .622 L

s

gsave

1.03669 .47257 -61 -9.79093 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Z) show

71.500000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  Evaluatable->False,

  AspectRatioFixed->True,

  ImageSize->{353, 353},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005Q0001HA000`40O003h00OogooHWoo003oOomR

Ool00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00

ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomR

Ool00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00

ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomR

Ool00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00

ogooHWoo003oOomROol00=Qoo`<008Ioo`00fGoo00<007ooOol0QGoo003IOol00`00Oomoo`25Ool0

0=Qoo`03001oo`0008Ioo`00f7oo00<007oo0000QWoo002POol30002Ool20003Ool2000[Ool01@00

Oomoogoo0000QGoo002QOol01000Oomoo`000Woo00<007oo00000Woo00<007ooOol09goo0`0000Ao

o`00000008Aoo`00MWoo0P008Goo100017oo00@007ooOol0009oo`03001oo`00009oo`03001oogoo

0;9oo`00M7oo0P000Woo10009Goo00@007ooOol0009oo`03001oo`00009oo`03001oogoo0;9oo`00

Lgoo00<007oo00001Woo10008Goo00@007ooOol0009oo`03001oo`00009oo`03001oogoo0;9oo`00

MGoo00<007ooOol01Woo1P007Goo00@007ooOol0009oo`03001oo`00009oo`03001oogoo0;9oo`00

MGoo00<007ooOol01goo00<007ooOol01P0067oo0P000goo0P000goo0P00]Goo001aOol00`00Oomo

o`0DOol3003FOol006moo`8001Uoo`D00=9oo`00KWoo00<007ooOol017oo00<007ooOol04goo00@0

07ooOomoo`@00<ioo`00MGoo00<007ooOol06Goo1P00bWoo001/Ool00`00Oomoo`06Ool00`00Oomo

o`0MOol50037Ool006Yoo`8000Uoo`03001oogoo01moo`03001oogoo00@00<=oo`00JGoo00<007oo

Ool0<Goo1@00_goo002ROol4002kOol006Moo`03001oogoo03Uoo`L0031oo`8008Eoo`00IWoo00<0

07ooOol037oo00<007ooOol0:goo00<007ooOol00Woo1@00;7oo00@007ooOol008Aoo`00IGoo00<0

07ooOol03Goo00<007ooOol0=Goo1000:7oo00@007ooOol008Aoo`00I7oo00<007ooOol03Woo00<0

07ooOol0=goo1P0097oo00@007ooOol008Aoo`00MGoo00<007ooOol0?Goo100087oo00@007ooOol0

08Aoo`00HWoo00<007ooOol0DWoo1P0077oo00@007ooOol008Aoo`00HGoo00<007ooOol0EWoo1P00

6Woo0P00QGoo001POol00`00Oomoo`0BOol00`00Oomoo`18Ool4002MOol007Eoo`03001oogoo04]o

o`D009Uoo`00GGoo00<007ooOol05Goo00<007ooOol0CWoo00<007oo00000`00UGoo001LOol00`00

Oomoo`0FOol00`00Oomoo`1BOol6002AOol005]oo`03001oogoo075oo`@008ioo`00dGoo00<007oo

00000`00RWoo001HOol00`00Oomoo`1kOol50026Ool005Moo`03001oogoo01]oo`03001oogoo06=o

o`@002]oo`<0009oo`8000=oo`8004]oo`00Egoo00<007ooOol06goo00<007ooOol0I7oo1`00:7oo

00@007ooOol0009oo`03001oo`00009oo`03001oogoo04Qoo`00EWoo00<007ooOol077oo00<007oo

Ool0I7oo00<007ooOol00goo10009Goo00@007ooOol0009oo`03001oo`00009oo`03001oogoo04Qo

o`00MGoo00<007ooOol0KWoo10008Goo00@007ooOol0009oo`03001oo`00009oo`03001oogoo04Qo

o`00Dgoo00<007ooOol0?goo7000=Woo00<007oo000010007Goo00@007ooOol0009oo`03001oo`00

009oo`03001oogoo04Qoo`00DWoo00<007ooOol0;goo4@003V003VP04@00;7oo0`006Woo00@007oo

Ool0009oo`03001oo`00009oo`03001oogoo04Qoo`00DGoo00<007ooOol08Goo00<007ooOol01goo

1@000UP07F0076P00g001@00:Goo1P0057oo0P000goo0P000goo0P00Bgoo001eOol00`00Oomoo`02

Ool50007F00MH00LJ008L005000VOol00`00Oomoo`04001XOol004moo`03001oogoo029oo`H000aH

01eP01aX00e`00H002Moo`@006Aoo`00CGoo0P0087oo1@0000=H0000F0003eP07F0076P04g001@00

9Goo1@00H7oo001<Ool00`00Oomoo`0LOol40006F0000`00F01H000>F00MH00LJ00HL004000ROol0

1000Oomoogoo0`00GGoo001XOol300000e00F01H000HF00MH00LJ006L0000`00L01`000AL0000`00

N0000002000UOol6001HOol006Eoo`<000A@01YH01eP01aX01Y`0003001h07P0009h00<002Ioo`D0

05Eoo`00BWoo00<007ooOol05Goo0`001e002EP000<005P0F0003UP07F0076P06W0000<007P0N000

1GP00`008goo00<007ooOol00Woo1000DGoo0018Ool2000EOol3000:D009F0000`00F01H000>F00M

H00LJ00JL0000`00N01h0008N004000WOol5001=Ool004Moo`03001oogoo019oo`<000e@00UH0003

001H05P000iH01eP01aX01Y`0003001h07P000ah00<002Moo`03001oo`00008004Yoo`00FGoo0`00

45002EP000<005P0F0003UP07F0076P06W0000<007P0N0003gP00`0097oo00@007ooOomoo`H004Eo

o`00AGoo00<007ooOol03goo0P004e006UP07F0076P06W0000<007P0N0004WP00P00:goo1000@Woo

0013Ool2000@Ool2000ED00JF00MH00LJ00JL0000`00N01h0003N0000`00N01h000=N0000g`00000

000ZOol00`00Oomoo`04000nOol0049oo`03001oogoo00moo`03000l03`001E@00UH0003001H05P0

00iH01eP01aX01Y`0003001h07P001=h00=l008002ioo`D003Yoo`00DWoo0P000c`05E002EP000<0

05P0F0003UP07F0076P06W0000<007P0N0004gP01G`000<007ooOol0;goo1@00=Woo0010Ool00`00

Oomoo`0>Ool00`00?00l0003?00ED009F0000`00F01H000>F00MH00LJ00JL0000`00N01h000CN006

O002000_Ool01000Oomoogoo1@00<Woo000nOol2000?Ool20006?00ED009F0000`00F01H000>F00M

H00LJ00KL0000`00N01h000BN008O002000eOol4000_Ool003eoo`03001oogoo00ioo`03000l03`0

00Hl01E@00UH0003001H05P000iH01eP01aX01]`0003001h07P0019h00Yl0003001oogoo03Aoo`03

001oo`0000<002]oo`00C7oo0P002C`05E006UP07F0076P06g0000<007P0N0004WP02g`00P00>Goo

0`00:Goo001;Ool00`00?00l0009?00ED00JF00MH00LJ00KL0000`00N01h000BN0000`00O01l000:

O002000hOol2000YOol003]oo`03001oogoo00]oo`8000/l0003001@050001=@00QH0003001H05P0

00mH01eP01aX01]`0003001h07P0019h00ml0003001oogoo039oo`05001oogooOol0000YOol003Yo

o`03001oogoo00]oo`03000l03`000`l01E@00QH0003001H05P000mH01IP00h001EX01]`0003001h

07P0019h011l0003001oogoo02moo`8000Aoo`03001oogoo02Moo`00>Goo00<007ooOol02goo0P00

3S`05E0025P000<005P0F0003eP026003P003UP03P001fP06g0000<007P0N0004WP047`000<007oo

Ool0;Woo00<007ooOol017oo00<007ooOol09goo0016Ool00`005000000>?00ED008F0000`00F01H

000=F00:000ZF00;000GL0000`00N01h000BN00AO0000`00Oomoo`0dOol00`00Oomoo`0WOol003Io

o`03001oogoo00eoo`03000D000000hl01E@019H00H003mH00L0011`0003001h07P0019h019l0003

001oogoo02Uoo`8000Qoo`03001oogoo02Moo`00=Goo00<007ooOol03Goo00@001@0500000hl01E@

00eH00D004aH00H000Y`0003001h07P0019h01=l0003001oogoo02Ioo`8000Yoo`8002Qoo`00=7oo

00<007ooOol03Goo00D001@0500D000000hl01E@00QH00D001iH01T0021H00L000=`0003001h07P0

019h01=l0003001oogoo03=oo`03001oogoo02Ioo`00@goo00<001@050000Q@000<003`0?00033`0

5E000UP01`004UP040002D`03F004P0065P01@004gP057`000<007ooOol08Goo0P003goo00<007oo

Ool09Woo000aOol00`00Oomoo`0>Ool00`00500D000350000`00?00l000<?00CD0040006F0000`00

F01H000:F00600000goo000d0009=0000`00C01<000:C005H0080005F00C000CF0020002F003000@

N00EO0000`00Oomoo`0NOol2000AOol00`00Oomoo`0VOol0031oo`03001oogoo00moo`03000D01@0

00<D0003000l03`000`l011@00<000YH0003001H05P000AH00H000Ioo`03000d03@000Td0003001<

04`000U<00H000AH00T000AP00E/010000aH0003001H05P000EH00<000eh01Il0003001oogoo031o

o`03001oogoo02Ioo`00<7oo00<007ooOol03Woo00<001@0500011@000<003`0?00033`03E000`00

3EP01`002Woo0P0033@000<004`0C0001d`00P0015P01P003F003V`01P0000=h00000000100015P0

0P002eP00`002WP05W`000<007ooOol06Woo00<007ooOol04Woo0P00:7oo000_Ool00`00Oomoo`0>

Ool00`00500D000550000`00?00l000<?00:D003000<F005000?Ool00`00=00d000<=0000`00C01<

0004C0030004F00200000d`0H01P000@H00BK0001000N00000000gP00W`01@003eP00`001gP05g`0

00<007ooOol05goo0P005Woo00<007ooOol09Woo0010Ool00`00500D000450000`00?00l000=?007

D003000<F003000BOol2000?=0001000C01<04`00`0015P00`000d`04V004V`000@007P0N01h0080

0003N01l07`0009l00=oo`<000mH00<000Ah01Ml0003001oogoo01Ioo`03001oogoo01Ioo`03001o

ogoo02Ioo`00;7oo00<007ooOol04Goo00<001@0500011@000<003`0?0003C`015000`003EP00P00

1goo00<007ooOol02Woo00<003@0=0003c@000@004`0000000AH00<000I<019P019/0003001h07P0

00=h00<0009l00Ioo`<000mH00<00003N01l07`001El0003001oogoo01Aoo`03001oogoo01Qoo`03

001oogoo02Ioo`00:goo00<007ooOol04Woo00<001@0500011@000<003`0?0003C`000A@00000000

00eH00<000Uoo`03001oogoo00Uoo`03000d03@0010d008000AH008000U<019P019/0003001h07P0

00Ih008000Uoo`@000iH008001Il0003001oogoo019oo`8001]oo`03001oogoo02Ioo`00:Woo00<0

07ooOol04goo00<001@0500011@000<003`0?00033`00P003EP00`0037oo00<007ooOol01goo0P00

4C@00P000UP010002d`04V004V`000<007P0N00027P00P002goo0`003EP00P0057`000<007ooOol0

4Goo00<007ooOol06goo00<007ooOol09Woo000oOol00`00500D000550000`00?00l000:?002000=

F002000?Ool00`00Oomoo`06Ool00`00=00d000@=0000`00F01H0002F003000<C00BH00BK0000`00

N01h000:N0000`00Oomoo`0;Ool3000<F002000BO0000`00Oomoo`0^Ool2000XOol002Qoo`03001o

ogoo01Aoo`03000D01@000DD0003000l03`000Pl008000aH00<001Uoo`03000d03@0010d0003001H

05P0009H0004000d03@0000<C00BH00BK0000`00N01h000:N0000`00Oomoo`0>Ool2000<F002000A

O0000`00Oomoo`0<Ool2000POol00`00Oomoo`0VOol002Ioo`8001Moo`03000D01@000DD0003000l

03`000Hl008000aH008001Yoo`80014d008000AH0005000d03@0=000000<C00BH00BK0000`00N01h

000:N0000g`0001oo`0@Ool2000<F0000`00O01l000>O0000`00Oomoo`0:Ool2000ROol00`00Oomo

o`0VOol002Eoo`03001oogoo01Moo`03000D01@000DD0003000l03`000@l008000aH008001]oo`03

000d03@0010d0003001H05P0009H008000@d0003001<04`000Y<019P019/0003001h07P000Yh0003

O00007oo019oo`8000]H008000il0003001oogoo02ioo`03001oogoo02Ioo`00?goo00<001@05000

1A@000<003`0?0000S`00P0035P00P0067oo00<007ooOol00Woo00<003@0=0003c@000<005P0F000

0UP000<003@0=00013@000<004`0C0002T`04V004V`000<007P0N0002WP00W`000<007ooOol04Woo

0P002eP00P0037`000<007ooOol01goo00<007ooOol097oo0P009goo000SOol00`00Oomoo`0IOol0

0`00500D000550000`00?00l0002000<F002000JOol01000Oomoogoo0P0023@000<003@0=00013@0

0P0015P000<003@0=0001C@000<004`0C0002T`04V004V`000<007P0N0002WP00W`000<007ooOol0

57oo00<005P0F0002UP00P002W`000<007ooOol01Goo0P009goo0P009goo000ROol00`00Oomoo`0J

Ool00``0500D00055003000<F002000LOol01000Oomoogoo0P003S@000<005P0F0000UP00P0023@0

00<004`0C0002T`04V004V`000<007P0N0002WP00g`000<007ooOol057oo0P0035P00P0027`000=/

07ooOol017oo00<007ooOol09Woo0`009goo000QOol00`00Oomoo`0KOol00``0500D00055003000:

F002000NOol01P00Oomoo`00300000dd0003001H05P0009H0003000d03@000Pd0003001<04`000Y<

019P019/0003001h07P000Yh00Al01Qoo`8000aH0003001l07`000El0003K01oogoo009oo`03001o

ogoo02Yoo`03001oogoo00Yoo`<000=oo`8001=oo`0087oo00<007ooOol077oo00<<01@0500011@0

00@005P0F01H00@000AH008002=oo`03000<000000/d008000AH0003000d03@000Td0003001<04`0

00Y<019P019/0003001h07P000Yh00Al01Yoo`8000]H0003001l07`000Al0003K01oogoo008002eo

o`03001oogoo00eoo`03001oo`00009oo`03001oogoo011oo`00?goo00<<01@050000a@000<005P0

F0001UP0100097oo00@000`0300000Xd0003001H05P0009H008000`d0003001<04`000Y<019P019/

0003001h07P000Yh0004O00007`0O00LOol00`00F01H0009F0000`00O01l0003O0000f`0Ool0000_

Ool00`00Oomoo`04Ool40005Ool00`00Ool00002Ool00`00Oomoo`0@Ool001ioo`03001oogoo01io

o`03300D01@000<D0003001H05P000MH0003001oogoo029oo`03001oo`00008<0003000d03@000Hd

008000AH0003000d03@000`d0003001<04`000Y<019P019/0003001h07P000Yh00Al01eoo`03001H

05P000QH0003001l07`000=l0003K01oogoo02moo`03001oogoo00eoo`03001oo`00009oo`03001o

ogoo011oo`0077oo0P008Goo00<<01@050000Q@000<005P0F0001eP000<007ooOol08goo00<007oo

30000P`000<003@0=0001C@000<005P0F0000eP000<003@0=0003C@000<004`0C0002T`04V004V`0

00<007P0N0002WP017`07Woo00<005P0F00025P000<007`0O0000W`000=/07ooOol0;goo00<007oo

Ool02goo0P000Woo00@007ooOol0019oo`006goo00<007ooOol08Goo00D<01@0500D000000YH0003

001oogoo02=oo`03001oo``0008<0003000d03@000@d0003001H05P0009H0080010d0003001<04`0

00Y<019P019/0003001h07P000Yh00Al01moo`03001H05P000QH0005001l07`0O01/000`Ool2000=

Ool01@00Oomoogoo00000Woo00<007ooOol047oo000JOol3000ROol010`0500D00002UP000<007oo

Ool097oo00<007oo30000P`000<003@0=0000S@00P0015P000<003@0=00043@000<004`0C0002T`0

3V002@003F`000<007P0N0002WP017`087oo00<005P0F00025P000@007`0O01/035oo`03001oogoo

00aoo`80009oo`8001=oo`006Woo00<007ooOol00P0087oo00<<01@000002UP000<007`000009goo

0``000D003@0=00d000000AH008001<d0003001<04`000Y<00EP00T000UH00T000A/0003001h07P0

00Yh00Al01moo`8000]H0003001l06`0035oo`03001oogoo02Eoo`006Woo00<007ooOol017oo1@00

6Goo00<<01@000002EP000@007`0O01l008002Eoo`<<0004000d03@00004F0000`00=00d000C=000

0`00C01<0009C006000KF006000;N004O00NOol01000=00<00002UP000<007`0K000<Goo00<007oo

Ool09Goo000JOol00`00Oomoo`0;Ool2000EOol00``0001H0009F0000`00O01l0003O0000`00Oomo

o`0ROol330030004F0000`00=00d000D=0000`00C01<0007C002000SF0020002F0020009N004O00L

Ool20002=00230000`00F01H0008F0000`00K01oo`0`Ool00`00Oomoo`0UOol001Yoo`03001oogoo

00eoo`80009oo`8000moo`03001H05P000QH0003001l07`000El0003001oogoo01moo`03001oo``0

008<00<0009H008001Ld0003001<04`000A<00<002AH0003001H05P000AH00<000Ih00Al01]oo`03

000d03@0008d00<<0003001H05P000QH0003001oogoo02moo`03001oogoo02Eoo`00<7oo0P003Goo

00<005P0F0001eP000<007`0O0001g`00P007goo00D007oo300<000000=H00<001Pd0004001<04`0

C003000:F0000`00F01H000IF0000`00F01H0008F0030003N004O00JOol00`00=00d0003=0043000

0`00F01H0007F0000`00Oomoo`0^Ool2000WOol003Eoo`@000Ioo`03001H05P000MH0003001l07`0

00Ul0003001oogoo01aoo`05001oo``030000003F0000`00=00d000H=0001000C00000009eP00P00

3UP00P0000=h07`0O0000W`06Goo00<003@0=00013@010`000<005P0F0001eP000<007ooOol0;goo

00<007ooOol09Goo000JOol00`00Oomoo`0NOol20002Ool00`00F01H0007F0000`00O01l000:O000

0`00Oomoo`0KOol01000Ool<00000UP00P006c@00`009eP000<005P0F00045P00P000g`05goo0P00

1c@010`000<005P0F0001eP000<007ooOol0;goo00<007ooOol09Goo000JOol00`00Oomoo`0POol3

0009F0000`00O01l000;O002000MOol010`0001H00006c@00P000eP0100045P000<005P0F0001EP0

00<005P0F0001EP00`005EP000<007`0O0005Woo00<003@0=0001c@010`000<005P0F0001eP000<0

07ooOol0;goo0P009Woo000IOol00`00Oomoo`0ROol00`00F01H0008F0000`00O01l0002O0000`00

O01l0008O002000KOol00`00F000000K=0000`00F01H0007F004000<F00@0il00`00F01H000EF000

0`00O01l000DOol20009=0000`00300<000230000`00F01H0007F0000`00Oomoo`0`Ool00`00Oomo

o`0TOol001Uoo`03001oogoo029oo`03001H05P000MH0003001l07`000il009h008001Moo`04001o

o`00000J=002000>F0040005F00A0il200030il3F0000`00F01H000@F0000`00O01oo`0AOol20000

0dP0000d0009=00530000`00F01H0007F0000`00Oomoo`0^Ool2000VOol003ioo`03001H05P000MH

0003001l07`000il00Ah008001Eoo`8001/d0003001H05P0019H00D000l3W`8000L3WaAH0003001l

07oo00moo`8000=80003000d03@000Pd00D<0003001H05P000MH0003001oogoo02moo`03001oogoo

02Aoo`00?Woo00<005P0F0001eP000<007`0O0003W`01WP00P004goo0P006C@00P005EP00P000`>O

100010>O1`002P>O55P000<007ooOol037oo0P001DP000<003@0=00023@01@`000<005P0F0001eP0

00<007ooOol0;goo00<007ooOol097oo000IOol00`00Oomoo`0ROol00`00F01H0007F0000`00O01l

000>O008N002000AOol2000H=0000`00F01H000DF0000`000il3W`070il400070GH200090ilCF000

0`00Oomoo`0:Ool20007B0000`00=00d0008=00530000`00F01H0007F0000`00Oomoo`0_Ool00`00

Oomoo`0TOol001Uoo`03001oogoo029oo`03001H05P000MH0003001l07`000il0003001h07P000Mh

008000ioo`03000<000001Ld0003001H05P001=H008000X3W`8000X1MP8000P3W`03001H05P0015H

0003001oogoo00Moo`8000U80003000d03@000Pd00D<0003001H05P000MH0003001oogoo02moo`03

001oogoo02Aoo`006Goo00<007ooOol08goo00<005P0F0001eP000<007`0O0003G`037P00P002goo

00@000`0300001Dd008001EH00030003W`>O00T3W`030001MP5f00X1MP8000L3W`03001H05P0015H

0003001oogoo00Ioo`8000]80003000d03@000Pd00@<0003001H05P000MH0003001oogoo031oo`03

001oogoo02Aoo`006Goo00<007ooOol08goo00<005P0F0001eP000<007`0O0003G`03WP00`0027oo

00@000`0300001@d0003001H05P001=H008000X3W`8000/1MP800083W`@000<3W`03001H05P0011H

0003001oogoo00Aoo`<000e80003000d03@000Pd00@<0003001H05P000MH0003001oogoo02moo`80

02Ioo`006Goo00<007ooOol097oo00<005P0F0001eP000<007`0O00037`03gP00W@01P0000Aoo`00

300<0080018d008001EH00030003W`>O00P3W`8000/1MP8000P3W`D0011H0004001oogooOol40000

0e@0B018000=B0000`00=00d0008=00330000`00F01H0007F0000`00Oomoo`0aOol00`00Oomoo`0T

Ool0045oo`03001H05P000MH0003001l07`000]l00mh00Id00<000<<0080014d0003001H05P001=H

008000X3W`030001MP5f00X1MP030003W`>O00P3W`8000=H00D000YH0003001oo`00008000ED00m8

0003000d03@000Pd008<0003001H05P000MH0003001oogoo039oo`03001oogoo02Aoo`00@Goo00<0

05P0F0001eP000<007`0O0002g`03gP02G@00``00P003c@00P005EP000<000>O0il020>O0P002`5f

0P002@>O0P002UP01P000eP00`0025@03dP000<003@0=00023@00P`000<005P0F0001eP000<007oo

Ool0<Woo00<007ooOol097oo000IOol00`00Oomoo`0VOol00`00F01H0007F0000`00O01l000:O00?

N009M0033002000>=0000`00F01H000CF002000:0il00`000GH1MP0:0GH00`000il3W`080il00`00

F01H000@F003000;E00?B0000`00=00d0008=0000``0001H0008F0000`00Oomoo`0cOol00`00Oomo

o`0TOol001Uoo`03001oogoo02Moo`03001H05P000MH0003001l07`000Ul00mh00Ud00<<0003000d

03@000/d008001EH00030003W`>O00P3W`8000/1MP8000T3W`8001=H008000aD00m80003000d03@0

00Pd0003300005P000MH0003001oogoo03Aoo`03001oogoo02Aoo`006Goo00<007ooOol0:7oo00<0

05P0F0001UP000<007`0O0002G`03gP02G@00``000<003@0=0002S@000<005P0F0004eP00P002P>O

00<0005f0GH02@5f0P002@>O0P004eP00P003U@03dP000<003@0=00023@000<005P0F0001eP000<0

07ooOol0<goo0P009Woo000IOol00`00Oomoo`0XOol00`00F01H0007F0000`00O01l0008O00?N009

M00330000`00=00d0008=002000DF00200040il?00040GH00`000il3W`080il00`00F01H000BF000

0`00E01D000>E00?B0000`00=00d0006=0020009F0000`00Oomoo`0eOol20006Ool2000MOol004Eo

o`03001H05P000MH008000Ql00mh00Ud00<<0003000d03@000Ld0003001H05P000aH00h000MP00QX

00l001=H0080015D00m80003000d03@000Dd0003001H05P000QH0003001oogoo03Ioo`8000Eoo`04

001oogoo000LOol004Ioo`8000UH0003001l07`000El00mh00Ud008<008000Pd0003001H05P0009H

00/001EP01MX00/000IH00800003G01D05@0011D00m80003000d03@000@d0003001H05P000MH0080

03Yoo`03001oogoo00=oo`04001oogoo000LOol001Uoo`03001oogoo02aoo`03001H05P000MH0003

001l07`000Al00mh00Ud008<008000Hd00L000=H01eP01iX00A`00L0009L019D00m80003000d03@0

008d008000UH0003001oogoo03Yoo`03001oogoo00=oo`04001oogoo000LOol001Uoo`03001oogoo

02eoo`03001H05P000MH008000Al00mh00Ud00<<00L000YH01eP01iX00]`00H000iD00m80005000d

03@0=000000:F0000`00Oomoo`0kOol00`00Oomoo`03Ool01000Oomoo`0077oo000HOol00`00Oomo

o`0_Ool20009F0001000O01l07`03gP01W@01`0045P07F007VP04G001`001e@03dP000@003@0=000

00UH008003eoo`8000Eoo`04001oogoo000@Ool50007Ool001Qoo`03001oogoo035oo`03001H05P0

00MH00800003O01h07P000eh0003M000000000<001MH01eP01iX01Q`00D0009D00m800<000UH0003

001oogoo03ioo`03001oogoo00Aoo`80019oo`04001oogoo0007Ool001Qoo`03001oogoo039oo`03

001H05P000QH008000]h00@00003D01H05P000MH0003001H05P000mH01eP01iX00E`0003001`0700

01=`0003001h000000<000a800<000UH0003001oogoo03moo`03001oogoo01Qoo`03001oogoo00Qo

o`00CWoo0P002UP00P001GP010001E002EP000<005P0F0003eP07F007VP06g0000<007P0N0000gP0

10001TP00P000eP010000eP00P00@Woo00<007ooOol06Goo00<007ooOol01goo001@Ool2000:F005

0009D009F0000`00F01H000?F00MH00NJ00KL0000`00N01h0007N0060009F0030014Ool00`00Oomo

o`0JOol00`00Oomoo`06Ool001Qoo`03001oogoo03Moo`8000IH00@000a@00UH0003001H05P000mH

01eP01iX01]`0003001h07P000Yh00@000MH008004Ioo`03001oogoo01Qoo`03001oo`0000Qoo`00

67oo00<007ooOol0>Goo1P0045006eP07F007VP06g0000<007P0N0003WP0100000=H00000000Agoo

0P006Woo10001goo000HOol00`00Oomoo`0iOol2000DD00KF00MH00NJ00KL0000`00N01h0002N000

0`00N01h000=N0020019Ool00`00Oomoo`0SOol001Qoo`03001oogoo03Moo`8001I@00UH0003001H

05P000mH01eP01iX01]`0003001h07P001Ah008004Moo`03001oogoo02=oo`00D7oo0P000S`05U00

2EP000<005P0F0003eP07F007VP06g0000<007P0N00057P00W`00P00AGoo00<007ooOol08goo001>

Ool20004?00FD009F0000`00F01H000?F00MH00NJ00KL0000`00N01h000DN004O0020013Ool00`00

Oomoo`0SOol001Qoo`03001oogoo035oo`8000Hl01I@00UH0003001H05P000mH01eP01iX01]`0003

001h07P001Ah00Il0080045oo`03001oogoo02=oo`0067oo00<007ooOol0;goo0P0023`05U002EP0

1@003EP07F007VP06g0000<007P0N00057P027`00P00?Woo0`0097oo000HOol00`00Oomoo`0]Ool2

000:?00FD007F0020007F0020009F00MH00NJ00KL0000`00N01h000DN00:O002000nOol00`00Oomo

o`0ROol001Qoo`03001oogoo02]oo`8000`l01I@019H008000=H0080009H01eP01iX01a`0003001h

07P001=h00al008003aoo`03001oogoo029oo`0067oo00<007ooOol0:Woo00<003`0?00033`05U00

15P000<005P0F0004UP00P000V000P006F007VP0770000<007P0N0004gP03W`000<007ooOol0>Goo

00<007ooOol08Woo0014Ool2000>?00FD002F002000GF004H002000GH00NJ00LL0000`00N01h000C

N00?O0000`00Oomoo`0hOol00`00Oomoo`0ROol004=oo`03000D000000hl01I@0003F00005P001QH

00QP00D0011P01iX01a`0003001h07P001=h011l0003001oogoo03Moo`03001oogoo029oo`005goo

00<007ooOol0:7oo00@001@0500000hl01E@0003001H05P001UH00mP00@000YP01iX01a`0003001h

07P001=h015l0003001oogoo03Eoo`8002Aoo`005goo00<007ooOol09goo00D001@0500D000000hl

01=@00800003D01H05P001UH01EP008000IP01iX01a`0003001h07P001=h019l008003Ioo`03001o

ogoo029oo`005goo00<007ooOol09goo00D001@0500D000000hl019@0004001@0500D00KF00FH00?

000FJ00LL0000`00N01h000CN00DO0000`00Oomoo`0cOol00`00Oomoo`0ROol001Moo`03001oogoo

02Ioo`03000D01@0008D0003000l03`000`l01I@01]H00QP00h000QD008000ED00l000MX01a`0003

001h07P001=h01El0003001oogoo039oo`03001oogoo029oo`00?goo00<001@050000a@000<003`0

?00033`03e0000<00500D000150065P02`006U@010003U@030005g0000<007P0N0004gP05W`000<0

07ooOol0<Goo00<007ooOol08Woo000nOol00`00500D000450000`00?00l000<?00>D0000`00D01@

0005D00AF007000/E004000CE009000>L0000`00N01h000CN00GO0000`00Oomoo`0`Ool00`00Oomo

o`0ROol001Moo`03001oogoo02=oo`03000D01@000DD0003000l03`000`l00e@0003001@050000I@

00]H00H001]D01X000AD008001QD00X000A`0003001h07P001=h01Ml0003001oogoo02ioo`03001o

o`0002Aoo`005goo00<007ooOol08goo00<001@050001A@000<003`0?00033`05U0015P01`004E@0

400000@d0000000001ID010001QD00H001Ah01Ml0003001oogoo02moo`8000Eoo`<000=oo`8001Mo

o`005goo00<007ooOol08goo00<001@050001A@000<003`0?0001S`000<003`0?0000c`02E000P00

2U001@004U@01P003c@00P000e@01@003U@06@0055@00P000U@0100047P05g`000<007ooOol0<7oo

00<007ooOol01Woo00<007oo00000Woo00<007ooOol057oo000GOol00`00Oomoo`0SOol00`00500D

000450000`00?00l000=?007D0020008D004000AE006000C=002000:E0050005E00B00020il00`00

0il3W`0500000e@000000004000<E0020008E004000<N00GO0000`00Oomoo`0`Ool00`00Oomoo`06

Ool00`00Ool00002Ool00`00Oomoo`0DOol001Moo`03001oogoo02=oo`03000D01@000@D0003000l

03`000dl00e@00@000mD00H001Pd0003001D05@000UD00/000UP00U/00/00003E000000000800003

E000000000@000AD008000iD00<000Uh01Ql0003001oogoo031oo`03001oogoo00Eoo`03001oo`00

009oo`03001oogoo01Aoo`00?Goo00<001@0500011@000<003`0?0003C`0150000<00500D0000e00

0`003U@01P006c@00P002U@00P0000=<0600H0004F004V`000@007P0000000A`009D0080009D00D0

019D00@000Eh01Ql0003001oogoo031oo`03001oogoo00=oo`80009oo`04001oogoo000FOol003eo

o`03000D01@000@D0003000l03`000dl00=@0003001@050000@000eD00@0009oo`04000<00`0000I

=002000:E0020003C00CH00BK0001000N01h07P00P001U@00P0000E`05@0000005@000@0019D00@0

0003N01l07`001Il0003001oogoo02moo`8000Eoo`05001oogooOol00002Ool00`00Oomoo`0DOol0

01Moo`03001oogoo02=oo`03000D01@000@D0003000l03`000dl009@00@000eD00@000Eoo`05000<

00`03000000H=0000`00E01D0007E0030005C00CH00BK0000`00N01h0003N0030009E0020002E005

000BE002000GO0000`00Oomoo`0`Ool00`00Oomoo`04Ool20002Ool2000GOol001Moo`03001oogoo

02=oo`03000D01@000@D0003000l03`000`l00<000eD00@000Uoo`@<0003000d03@001@d008000QD

008000Q<01=P019/0003001h07P000Ih008000YD0003001oogoo00L0011D008001El0003001oogoo

031oo`03001oogoo025oo`005goo00<007ooOol08goo1a@000<003`0?0002S`00`002e@010003Goo

10`000<003@0=0004S@00P0025@00P002T`04f004V`000<007P0N00027P00P001U@00P0027oo1P00

3U@00P004g`0<goo00<007ooOol08Goo000GOol00`00Oomoo`0SOol750000`00?00l0008?0040009

E003000AOol430000`00=00d000A=0000`00E01D0006E003000;C00CH00BK0000`00N01h0009N000

0g`0001D0003E0000`00Oomoo`0>Ool4000<E002000AO00cOol00`00Oomoo`0QOol003eoo`LD0003

000l03`000Hl00800003E00005@000QD008001Aoo`@<0003000d03@000ld008000MD0080008d0003

001<04`000U<01=P019/0003001h07P000Uh009l0004001D05@0000COol400000e@000000009E002

000?O00cOol00`00Oomoo`0QOol003eoo`LD0003000l03`000<l00<000]D008001Ioo`@<0003000d

03@000dd008000MD008000@d0003001<04`000U<01=P019/0003001h07P000Uh009l0003001D0000

01Qoo`D0009D008000ED008000el03=oo`03001oogoo025oo`00?Goo1a@000@003`0?00l008000=D

008000MD008001Qoo`@<0003000d03@000`d0003001D05@000ED008000Hd0003001<04`000U<01=P

019/0003001h07P000Uh00=l008001]oo`8000AD008000ED008000]l039oo`8002=oo`005Woo00<0

07ooOol097oo1a@000@003`0000000=D008000MD008001Yoo`@<0003000d03@000Xd008000MD0003

000d03@000Hd0003001<04`000U<01=P019/0003001h07P000Uh00Al0003001oogoo01]oo`<000ID

00H000Ul03=oo`03001oogoo025oo`005Woo00<007ooOol097oo1a@00`002e@00P0077oo10`000<0

03@0=00023@00P001e@00P002C@000<004`0C0002D`04f004V`000<007P0N0002GP017`08Goo0P00

2U@010001G`0<goo00<007ooOol08Goo000FOol00`00Oomoo`0TOol650001000E01D05@01@0015@0

0P007Woo10`000<003@0=0001c@000<005@0E0001E@00P002c@000<004`0C0002D`04f004V`000<0

07P0N0002GP017`08goo0P002E@000<007`0O0000W`00P0000=l07ooOol0<Goo00<007ooOol08Goo

000FOol00`00Oomoo`0TOol550001000E01D05@00P0015@0100087oo10`000<003@0=0001C@00P00

1U@00P0033@000<004`0C0002T`04f004V`000<007P0N0002GP00W`000<007`0Ool08goo0P002E@0

00<007`0O0000g`00`000Woo0P00;Goo00<007ooOol08Goo000mOol450001@00E01D05@000001e@0

00<007`0000087oo10`000<003@0=0000c@00P001U@00P003S@000<004`0C0002T`02V004P002F`0

00<007P0N0002GP017`08goo00@003@0=00000UD0003001l07`000=l00Ioo`8002]oo`03001oogoo

025oo`00?Goo0a@000<005@0E0002E@000@007`0O01l008001ioo`@<0003000d03@0008d0003001D

05@000ED0003000d03@000hd0003001<04`000U<00/0019D00/000Yh00Al029oo`03000d03@0008d

0003001D05@000MD008000=l00Yoo`@002Aoo`<0029oo`005Woo00<007ooOol097oo0Q@000D005@0

E01D000000MD0003001l07`000Al008001aoo`@<0003000d03@0008000ID0080014d0003001<04`0

00M<008002AD0080009D00<000Mh00Al021oo`8000Dd0003001D05@000UD0003001l07`0015oo`@0

01moo`03001oogoo021oo`005Woo00<007ooOol097oo00@D0000E01D008000MD0003001l07`000Ml

0003001oogoo01Uoo`@<00<000ID008001<d0003001<04`000A<00<0025D0003>01D05@0008000MD

00<000Ah00Al01moo`03000d03@000Dd0003300005@000YD0003001l07oo01Ioo`8001]oo`03001o

ogoo021oo`005Woo00<007ooOol097oo00@005@0E00000QD0004001l07`00008O002000IOol43003

0004E002000E=0001000C01<04`00`0085@000<003P0E0000e@000<005@0E0002U@00`0000=h07`0

O0000W`07Goo0P0023@00P`000<005@0E0002E@000<007ooOol05goo0P000goo0P0057oo00<007oo

Ool087oo000FOol00`00Oomoo`0SOol2000:E0000`00O01l000<O002000GOol330000`00E0000005

000G=0001000C00000009e@00P0045@00P000g`06goo0P002S@00``000<005@0E0002E@000<007oo

Ool07Goo0P004Woo00<007ooOol087oo000kOol2000:E0000`00O01l000=O002N003000DOol23000

0`00E01D0003E0000`00=00d000G=003000IE0080005E002000DE0000`00O01l000HOol300000dP0

000d0005=0001000=00d03@010`000<005@0E00025@000<007ooOol08Goo100037oo00<007ooOol0

87oo000jOol00`00Ool0000:E0000`00O01l000=O005N003000AOol230000`00E01D0002E002000G

=0020003E006000>E00500080kl7000DE0000`00O01l000EOol30004B0000`00=00d0008=0043000

0`00E01D0008E0000`00Oomoo`0WOol50004Ool2000ROol003aoo`03001D05@000QD0003001l07`0

00el00Qh00<000ioo`03300005@000AD008001Dd008000]D00H000ED0143_`8000@3_`<0019D0003

001l07oo015oo`<000M80003000d03@000Pd00@<0003001D05@000QD0003001oogoo02ioo`800003

Ool007oo025oo`005Woo00<007ooOol07goo00D007ooOomoo`0000YD0003001l07`000el0003001h

07P000Qh00<000]oo`03001D05@000=D0003000<000001<d008001=D00L000H3_`T000T3_`=D00=`

00eD0003001oogoo00eoo`<000Y80003000d03@000Pd00@<0003001D05@000QD0003001oogoo031o

o`80029oo`005Woo00<007ooOol07Goo0P0017oo00<005@0E0001e@000<007`0O0003W`03WP00`00

2Goo00D005@0E01D0000008<0003000d03@0010d0003001D05@001=D008000D3_`H000P1MP8000T3

_`]D0003L01D05@000AD0003001oogoo00Uoo`@000e80003000d03@000Pd00D<0003001D05@000MD

0003001oogoo02]oo`03001oogoo008002Aoo`005Goo00<007ooOol07Goo00<007ooOol017oo00<0

05@0E0001e@000<007`0O0003W`03gP00W@010001Woo00@005@0E000008<0003000d03@000hd0080

01AD008000T3_`8000/1MP8000P3_`03001D05@0011D0003001oogoo00=oo`D0009D00m80003000d

03@000Pd00D<0003001D05@000MD0003001oogoo02Yoo`@002Ioo`005Goo00<007ooOol097oo00<0

05@0E0001e@000<007`0O0003W`03gP01W@010000goo0P000``000<003@0=00033@00P0055@00P00

2@>o0P003@5f10001@>o00<005@0E00045@000<007ooOol010001e@03dP000<003@0=00023@01@`0

00<005@0E0001e@000<007ooOol0:7oo1000:7oo000bOol00`00Oomoo`07Ool00`00E01D0007E000

0`00O01l000>O00?N00:M004000430000`00=00d000;=0000`00E01D000BE00200090kl2000=0GH2

00040kl7000@E004000;E00?B0000`00=00d0008=00530000`00E01D0007E0000`00Oomoo`0SOol0

1000Oomoogoo0P00:goo000`Ool2000;Ool00`00E01D0007E0000`00O01l000=O00?N0000`00M01d

000;M00430000`00=00d0009=002000CE00200090kl2000=0GH200080kl20003E005000:E0000`00

E01D000:E0000`00E01D000?B0000`00=00d0008=00430000`00E01D0007E0000`00Oomoo`0TOol4

000]Ool001Eoo`03001oogoo02Eoo`03001D05@000MD0003001l07`000el00mh00id00@<0003000d

03@000Ld008001=D008000T3_`8000d1MP8000P3_`8000YD00H000=D0003001D05@000iD00m80003

000d03@000Pd00@<0003001D05@000ID0003001oogoo02Aoo`80031oo`005Goo00<007ooOol05Goo

00<007ooOol03Woo00<005@0E0001e@000<007`0O00037`03gP03W@010`000<003@0=0001C@00P00

4e@00P002@>o0P003@5f0P0020>o0P004U@00`004E@03dP000<003@0=00023@00``000<005@0E000

1e@000<007ooOol087oo1000<Woo000EOol00`00Oomoo`0COol2000BOol00`00E01D0006E0000`00

O01l000<O00?N00>M00430000`00=00d0004=0000`00E01D000AE002000:0kl00`000GH1MP0;0GH2

00080kl2000CE002000CE00?B0000`00=00d0008=00230000`00E01D0007E0000`00Oomoo`0NOol5

000dOol001Eoo`03001oogoo019oo`03001oogoo01=oo`03001D05@000ID0003001l07`000]l00mh

00id00@<0003000d03@0008d0080019D008000X3_`8000`1MP8000P3_`8001=D0080009L01=D00m8

0003000d03@000Pd0003300005@000QD0003001oogoo01moo`8003Moo`00@7oo00<005@0E0001e@0

00<007`0O0002W`03gP03W@010`000<003@0=0000P004U@00P002P>o0P00305f0P0020>o0P004e@0

0P0015`04e@03dP000<003@0=00023@000<<0000E0001e@000<007ooOol067oo00<007ooOol00Woo

0`00>Goo000WOol00`00Oomoo`0GOol00`00E01D0006E0000`00O01l000:O00?N00>M0043003000B

E002000:0kl3000;0GH200090kl00`00E01D000AE0020006G00CE00?B0000`00=00d0008=0000`00

E01D0007E0000`00Oomoo`0HOol00`00Oomoo`02000lOol002Ioo`03001oogoo01Uoo`03001D05@0

00ID0003001l07`000Ul00mh00id00@<00@000mD008000X3_`800081m`030001MP5f00L1MP8000T3

_`80019D008000QL01=D00m80003000d03@000Hd008000UD0003001oogoo01Uoo`<003ioo`005Goo

00<007ooOol03Goo00<007ooOol06goo0P001e@00P002G`03gP03W@00``000<005@0E0000U@02000

1E@00P002P>o0P000P9G0P7g00<0005f0GH01@5f0P002@>o0P004U@00P002U`04e@03dP000<003@0

=0001C@000<005@0E0001e@00P006Woo0`00@7oo000EOol00`00Oomoo`0:Ool00`00Oomoo`0POol2

0007E0020007O00?N00>M00230000`00E01D000;E00600090kl2000010:g0UL2E`9G0P7g00<0005f

0GH00`5f0P002@>o0P004U@00P0035`04e@03dP000<003@0=0000c@00P0025@00P005goo00<007oo

Ool00P00@goo000EOol00`00Oomoo`08Ool2000UOol00`00E01D0006E0020005O00?N00>M0000``0

001D000@E0030kl400030kl200030[L30UL20OL010000GH1MP5f0P002@>o0P001U@000<005@0E000

2E@00P003U`04e@03dP000@003@0=00d008000UD0003001oogoo01Moo`<004Eoo`005Goo00<007oo

Ool01goo00<007ooOol09Woo0P0025@00P000g`03gP03W@000<005@0E0003e@000<000>o0kl01@>o

0`0000<2m`000[L00P:g0`9G0P7g00@0005f000000T3_`80019D0080011L01=D00m80004000d03@0

0009E002000HOol20018Ool004Yoo`8000QD00800003O01h07P000eh00md0003001D05@000mD0003

0003_`>o00H3_`030002m`0000<2]`<2E`81m`8000T3_`80019D0080019L01=D00m800<000QD0080

01Eoo`03001oo`00008004Yoo`0077oo00<007ooOol0;Goo0P0025@00P003WP047@000<005@0E000

3e@000<000>o0kl01P>o2P000P>o10000`>o0P004U@00P0055`04e@03TP01@001E@00P005goo0`00

C7oo000DOol00`00Oomoo`04Ool00`00Oomoo`0`Ool20008E003000;N00AM0000`00E01D000?E003

00040kl2000?0kl6000?E00200000f@0G01L000CG00CE00;B0030005E005000GOol2001?Ool001Ao

o`03001oogoo00=oo`03001oogoo03=oo`<000QD00<000Qh019d0003001D05@0015D00H000P3_`L0

00ID00P000ED008000=T01EL01=D00Q800<000QD00<001=oo`03001oogoo00<0055oo`0057oo00<0

07ooOol0?7oo0`0025@00`001GP04W@00`002e@000<005@0E0000e@00P0015@020005E@01@001F@0

5E`04e@01DP00`0025@00`005goo0P003Woo0`000Woo0P000goo0P00>Woo000DOol01000Ool00000

?Woo0P002E@00`000WP04W@000<006`0K0000`003E@000<005@0E00085@00`0026@05E`04e@00TP0

0`002E@00P005goo0`004Goo00@007ooOol0009oo`03001oo`00009oo`03001oogoo03Moo`0057oo

0P00@Woo0`002E@0100047@000<006`0K0000f`010001e@00P0085@00`002f@05E`04E@010002E@0

0`0057oo00<007ooOol00`004goo00@007ooOol0009oo`03001oo`00009oo`03001oogoo03Moo`00

5Woo0P000goo0P00?Woo0`002U@01@002g@000<006`0K0001f`00`000U@00P007e@00`003V@05E`0

35@01@002U@00`0067oo0P005Woo00@007ooOol0009oo`03001oo`00009oo`03001oogoo03Moo`00

7Goo0P000Woo0P00>goo10002e@010001g@000<006`0K0002V`02@004E@02@004F@05E`025@01000

2e@0100057oo00@007ooOomoo`<001Qoo`04001oogoo0002Ool00`00Ool00002Ool00`00Oomoo`0g

Ool002=oo`8000=oo`8003Qoo`D000YD00D0009d0003001/06`0019/0003J000000000l000AX01IT

01EL00=D00D000YD00D001Qoo`04001oo`00000KOol01000Oomoo`000Woo00<007oo00000Woo00<0

07ooOol0=goo000ZOol20002Ool2000gOol60007E0000`00E0000007000?K00FJ00FI00@G008000:

E005000LOol3000LOol20003Ool20003Ool2000jOol0031oo`8000=oo`8003Ioo`D000AD008000ID

00X000E/01IX01IT00IL00X000eD00D001moo`<006Aoo`00=goo0P000Woo0P00=Goo1P0045@04000

2fP036@040004E@01P0087oo00@007oo000006Moo`00?Goo0P000goo0P00=7oo200065@05`006E@0

20009Goo0`00JGoo0014Ool20002Ool2000fOol8000hE008000WOol01000Oomoogoo0P00K7oo001:

Ool20002Ool2000hOolh000_Ool01000Ool00000KWoo001@Ool30002Ool2002GOol3001`Ool005Mo

o`80009oo`D006Ioo`03001oogoo021oo`03001oogoo00<0079oo`00HWoo1000H7oo00<007ooOol0

87oo0`00MGoo001XOol5001IOol00`00Oomoo`0NOol2000BOol2001TOol006moo`@005=oo`03001o

ogoo01Uoo`03001oogoo008001=oo`04001oogoo001SOol007Eoo`D006Qoo`<001Eoo`04001oogoo

001SOol007aoo`@005aoo`04001oogooOol3000GOol01000Oomoo`00Hgoo0022Ool40010Ool00`00

Oomoo`0COol4000JOol01000Oomoo`00Hgoo0029Ool4000iOol00`00Oomoo`0AOol3000MOol01000

Oomoo`00Hgoo002?Ool4000cOol00`00Oomoo`0=Ool00`00Oomoo`02000POol2001TOol009Ioo`@0

02aoo`03001oogoo00eoo`<008Qoo`00W7oo1000<7oo00@007ooOomoo`8008]oo`00Xgoo1000:Goo

1000SGoo002YOol4000QOol3002@Ool00;1oo`@0009oo`8000ioo`05001oogooOol00002Ool2002B

Ool00;Qoo`80009oo`8000Qoo`04001oogooOol3002DOol00;ioo`<0009oo`800003Ool007oo0080

09Moo`00aGoo0`004Woo0`000Woo0P000goo0P00Ngoo003KOol01000Oomoo`000Woo00<007oo0000

0Woo00<007ooOol0N7oo003COol40004Ool01000Oomoo`000Woo00<007oo00000Woo00<007ooOol0

N7oo003KOol01000Oomoo`000Woo00<007oo00000Woo00<007ooOol0N7oo003KOol01000Oomoo`00

0Woo00<007oo00000Woo00<007ooOol0N7oo003KOol01000Oomoo`000Woo00<007oo00000Woo00<0

07ooOol0N7oo003JOol20003Ool20003Ool2001kOol00?Uoo`<00003Ool00000069oo`00nWoo00@0

07ooOol006=oo`00ngoo0P00I7oo003kOol2001TOol00?Yoo`04001oogoo001SOol00?Yoo`04001o

ogoo001SOol00?Uoo`<00003Ool00000069oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo

003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?mo

of9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo

003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?mo

of9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo

003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?mo

of9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo

003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?mo

of9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo003oOomROol00?moof9oo`00ogooHWoo

003oOomROol00?moof9oo`00ogooHWoo002EOol00`00Ool000020005Ool30006Ool00`00Oomoo`02

Ool00`00Oomoo`2aOol009Eoo`8000=oo`05001oogooOol00003Ool00`00Oomoo`03Ool00`00Oomo

o`02Ool00`00Oomoo`2aOol009Eoo`03001oogoo009oo`04001oogoo0005Ool01`00Oomoogoo001o

o`00009oo`03001oo`000;9oo`00VWoo00@007ooOol000Uoo`03001oo`00009oo`03001oo`000;9o

o`00V7oo0P000goo00<007ooOol01goo00H007ooOol007oo0002Ool00`00Oomoo`2_Ool009Ioo`80

00Eoo`03001oogoo00Moo`06001oogoo001oo`000Woo00<007ooOol0[goo002EOol00`00Oomoo`05

Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01@00Oomoogoo0000/Goo002EOol00`00Oomoo`02Ool0

1000Oomoo`001Goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo0:ioo`00UGoo00@007oo

Oomoo`8000=oo`04001oogooOol20002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`2^

Ool009Ioo`<00003Ool007oo00=oo`<00003Ool007oo00<0009oo`<0009oo`<00:moo`00ogooHWoo

003oOomROol00?moof9oo`00\

\>"],

  ImageRangeCache->{{{0, 352}, {352, 0}} -> {-5.1835*^-06, -0.00904207, 

  0.00305811, 0.00305811}}]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell["Plot the Magnetic Field", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"The magnetic field vertical component profile is plotted along the y axis.",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell["\<\

RadPlotOptions[];

Plot[radFld[Grp,\"Bz\",{0,y,0}],{y,0,300}

,AxesOrigin->{0,0}

,FrameLabel->{\"Y [mm]\",\"Bz [T]\",\"X = Z = 0\",\"\"}];\

\>", "Input",

  AspectRatioFixed->True],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Times findfont 12  scalefont  setfont

% Scaling calculations

0.0238095 0.0031746 0.174296 0.108348 [

[.02381 -0.0125 -5 -15 ]

[.02381 -0.0125 5 0 ]

[.18254 -0.0125 -8 -15 ]

[.18254 -0.0125 8 0 ]

[.34127 -0.0125 -11 -15 ]

[.34127 -0.0125 11 0 ]

[.5 -0.0125 -11 -15 ]

[.5 -0.0125 11 0 ]

[.65873 -0.0125 -11 -15 ]

[.65873 -0.0125 11 0 ]

[.81746 -0.0125 -11 -15 ]

[.81746 -0.0125 11 0 ]

[.97619 -0.0125 -11 -15 ]

[.97619 -0.0125 11 0 ]

[ 0 0 -0.125 0 ]

[.5 -0.0125 -21.5 -30 ]

[.5 -0.0125 21.5 -15 ]

[-0.0125 .06595 -19 -7.5 ]

[-0.0125 .06595 0 7.5 ]

[-0.0125 .1743 -10 -7.5 ]

[-0.0125 .1743 0 7.5 ]

[-0.0125 .28264 -10 -7.5 ]

[-0.0125 .28264 0 7.5 ]

[-0.0125 .39099 -10 -7.5 ]

[-0.0125 .39099 0 7.5 ]

[-0.0125 .49934 -10 -7.5 ]

[-0.0125 .49934 0 7.5 ]

[-0.0125 .60769 -10 -7.5 ]

[-0.0125 .60769 0 7.5 ]

[ 0 0 -0.125 0 ]

[-0.01875 .30902 -55 -7.5 ]

[-0.01875 .30902 -19 7.5 ]

[ 0 .61803 .125 0 ]

[.5 .63053 -27 0 ]

[.5 .63053 27 15 ]

[ 1 0 .125 0 ]

[ -0.0005 -0.0005 0 0 ]

[ 1.0005 .61853 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 .5 r

.25 Mabswid

.18254 0 m

.18254 .61803 L

s

.34127 0 m

.34127 .61803 L

s

.5 0 m

.5 .61803 L

s

.65873 0 m

.65873 .61803 L

s

.81746 0 m

.81746 .61803 L

s

0 .06595 m

1 .06595 L

s

0 .1743 m

1 .1743 L

s

0 .28264 m

1 .28264 L

s

0 .39099 m

1 .39099 L

s

0 .49934 m

1 .49934 L

s

0 g

.02381 0 m

.02381 .00625 L

s

gsave

.02381 -0.0125 -66 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.18254 0 m

.18254 .00625 L

s

gsave

.18254 -0.0125 -69 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(50) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.34127 0 m

.34127 .00625 L

s

gsave

.34127 -0.0125 -72 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(100) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.5 0 m

.5 .00625 L

s

gsave

.5 -0.0125 -72 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(150) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.65873 0 m

.65873 .00625 L

s

gsave

.65873 -0.0125 -72 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(200) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.81746 0 m

.81746 .00625 L

s

gsave

.81746 -0.0125 -72 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(250) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.97619 0 m

.97619 .00625 L

s

gsave

.97619 -0.0125 -72 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(300) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.05556 0 m

.05556 .00375 L

s

.0873 0 m

.0873 .00375 L

s

.11905 0 m

.11905 .00375 L

s

.15079 0 m

.15079 .00375 L

s

.21429 0 m

.21429 .00375 L

s

.24603 0 m

.24603 .00375 L

s

.27778 0 m

.27778 .00375 L

s

.30952 0 m

.30952 .00375 L

s

.37302 0 m

.37302 .00375 L

s

.40476 0 m

.40476 .00375 L

s

.43651 0 m

.43651 .00375 L

s

.46825 0 m

.46825 .00375 L

s

.53175 0 m

.53175 .00375 L

s

.56349 0 m

.56349 .00375 L

s

.59524 0 m

.59524 .00375 L

s

.62698 0 m

.62698 .00375 L

s

.69048 0 m

.69048 .00375 L

s

.72222 0 m

.72222 .00375 L

s

.75397 0 m

.75397 .00375 L

s

.78571 0 m

.78571 .00375 L

s

.84921 0 m

.84921 .00375 L

s

.88095 0 m

.88095 .00375 L

s

.9127 0 m

.9127 .00375 L

s

.94444 0 m

.94444 .00375 L

s

.25 Mabswid

0 0 m

1 0 L

s

gsave

.5 -0.0125 -82.5 -34 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Y) show

%%IncludeResource: font Math2

%%IncludeFont: Math2

/Math2 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

74.625000 14.625000 moveto

(@) show

78.562500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(mm) show

%%IncludeResource: font Math2

%%IncludeFont: Math2

/Math2 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

97.312500 14.625000 moveto

(D) show

101.250000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math2

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math2

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math2

%%DocumentFonts: + font Times-Roman

grestore

0 .06595 m

.00625 .06595 L

s

gsave

-0.0125 .06595 -80 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .1743 m

.00625 .1743 L

s

gsave

-0.0125 .1743 -71 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .28264 m

.00625 .28264 L

s

gsave

-0.0125 .28264 -71 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .39099 m

.00625 .39099 L

s

gsave

-0.0125 .39099 -71 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(2) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .49934 m

.00625 .49934 L

s

gsave

-0.0125 .49934 -71 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(3) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

0 .60769 m

.00625 .60769 L

s

gsave

-0.0125 .60769 -71 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(4) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

0 .08762 m

.00375 .08762 L

s

0 .10929 m

.00375 .10929 L

s

0 .13096 m

.00375 .13096 L

s

0 .15263 m

.00375 .15263 L

s

0 .19597 m

.00375 .19597 L

s

0 .21764 m

.00375 .21764 L

s

0 .2393 m

.00375 .2393 L

s

0 .26097 m

.00375 .26097 L

s

0 .30431 m

.00375 .30431 L

s

0 .32598 m

.00375 .32598 L

s

0 .34765 m

.00375 .34765 L

s

0 .36932 m

.00375 .36932 L

s

0 .41266 m

.00375 .41266 L

s

0 .43433 m

.00375 .43433 L

s

0 .456 m

.00375 .456 L

s

0 .47767 m

.00375 .47767 L

s

0 .52101 m

.00375 .52101 L

s

0 .54268 m

.00375 .54268 L

s

0 .56435 m

.00375 .56435 L

s

0 .58602 m

.00375 .58602 L

s

0 .04428 m

.00375 .04428 L

s

0 .02261 m

.00375 .02261 L

s

0 .00094 m

.00375 .00094 L

s

.25 Mabswid

0 0 m

0 .61803 L

s

gsave

-0.01875 .30902 -116 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Bz) show

%%IncludeResource: font Math2

%%IncludeFont: Math2

/Math2 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

79.312500 14.625000 moveto

(@) show

83.250000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(T) show

%%IncludeResource: font Math2

%%IncludeFont: Math2

/Math2 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

90.562500 14.625000 moveto

(D) show

94.500000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math2

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math2

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math2

%%DocumentFonts: + font Times-Roman

grestore

.02381 .61178 m

.02381 .61803 L

s

.18254 .61178 m

.18254 .61803 L

s

.34127 .61178 m

.34127 .61803 L

s

.5 .61178 m

.5 .61803 L

s

.65873 .61178 m

.65873 .61803 L

s

.81746 .61178 m

.81746 .61803 L

s

.97619 .61178 m

.97619 .61803 L

s

.125 Mabswid

.05556 .61428 m

.05556 .61803 L

s

.0873 .61428 m

.0873 .61803 L

s

.11905 .61428 m

.11905 .61803 L

s

.15079 .61428 m

.15079 .61803 L

s

.21429 .61428 m

.21429 .61803 L

s

.24603 .61428 m

.24603 .61803 L

s

.27778 .61428 m

.27778 .61803 L

s

.30952 .61428 m

.30952 .61803 L

s

.37302 .61428 m

.37302 .61803 L

s

.40476 .61428 m

.40476 .61803 L

s

.43651 .61428 m

.43651 .61803 L

s

.46825 .61428 m

.46825 .61803 L

s

.53175 .61428 m

.53175 .61803 L

s

.56349 .61428 m

.56349 .61803 L

s

.59524 .61428 m

.59524 .61803 L

s

.62698 .61428 m

.62698 .61803 L

s

.69048 .61428 m

.69048 .61803 L

s

.72222 .61428 m

.72222 .61803 L

s

.75397 .61428 m

.75397 .61803 L

s

.78571 .61428 m

.78571 .61803 L

s

.84921 .61428 m

.84921 .61803 L

s

.88095 .61428 m

.88095 .61803 L

s

.9127 .61428 m

.9127 .61803 L

s

.94444 .61428 m

.94444 .61803 L

s

.25 Mabswid

0 .61803 m

1 .61803 L

s

gsave

.5 .63053 -88 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

74.625000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

85.437500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Z) show

95.625000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

106.437500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

112.437500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.99375 .06595 m

1 .06595 L

s

.99375 .1743 m

1 .1743 L

s

.99375 .28264 m

1 .28264 L

s

.99375 .39099 m

1 .39099 L

s

.99375 .49934 m

1 .49934 L

s

.99375 .60769 m

1 .60769 L

s

.125 Mabswid

.99625 .08762 m

1 .08762 L

s

.99625 .10929 m

1 .10929 L

s

.99625 .13096 m

1 .13096 L

s

.99625 .15263 m

1 .15263 L

s

.99625 .19597 m

1 .19597 L

s

.99625 .21764 m

1 .21764 L

s

.99625 .2393 m

1 .2393 L

s

.99625 .26097 m

1 .26097 L

s

.99625 .30431 m

1 .30431 L

s

.99625 .32598 m

1 .32598 L

s

.99625 .34765 m

1 .34765 L

s

.99625 .36932 m

1 .36932 L

s

.99625 .41266 m

1 .41266 L

s

.99625 .43433 m

1 .43433 L

s

.99625 .456 m

1 .456 L

s

.99625 .47767 m

1 .47767 L

s

.99625 .52101 m

1 .52101 L

s

.99625 .54268 m

1 .54268 L

s

.99625 .56435 m

1 .56435 L

s

.99625 .58602 m

1 .58602 L

s

.99625 .04428 m

1 .04428 L

s

.99625 .02261 m

1 .02261 L

s

.99625 .00094 m

1 .00094 L

s

.25 Mabswid

1 0 m

1 .61803 L

s

.001 w

0 .1743 m

1 .1743 L

s

.02381 0 m

.02381 .61803 L

s

.002 w

.02381 .60332 m

.02499 .60329 L

.02605 .60321 L

.02729 .60305 L

.02846 .60283 L

.03053 .6023 L

.03279 .6015 L

.03527 .60036 L

.0379 .59884 L

.04262 .59534 L

.04749 .59067 L

.05205 .58533 L

.06244 .56972 L

.07305 .54896 L

.08274 .52589 L

.10458 .46119 L

.14429 .31378 L

.18248 .17395 L

.20215 .11751 L

.22313 .0738 L

.23341 .05824 L

.24454 .04508 L

.25504 .0356 L

.26471 .02896 L

.27444 .02391 L

.28353 .02041 L

.29351 .0177 L

.2991 .01661 L

.3042 .01586 L

.309 .01534 L

.31143 .01514 L

.31411 .01496 L

.31639 .01485 L

.31767 .0148 L

.31884 .01477 L

.31987 .01475 L

.321 .01473 L

.32218 .01472 L

.32328 .01472 L

.32458 .01472 L

.32531 .01473 L

.32599 .01474 L

.32723 .01476 L

.32854 .0148 L

.33082 .01488 L

.33332 .015 L

.33886 .01537 L

.34404 .01586 L

.35445 .01719 L

.36433 .01887 L

Mistroke

.38287 .02308 L

.40271 .02915 L

.42111 .03631 L

.46029 .05708 L

.50193 .08705 L

.54205 .11904 L

.58065 .14553 L

.60063 .15604 L

.6217 .16465 L

.64138 .17064 L

.65973 .17474 L

.67021 .17655 L

.68012 .17796 L

.69869 .17996 L

.70837 .18072 L

.71864 .18136 L

.72741 .18178 L

.73707 .18214 L

.742 .18229 L

.74719 .18242 L

.75646 .18259 L

.76163 .18266 L

.76643 .18271 L

.76919 .18273 L

.7717 .18274 L

.77309 .18275 L

.7746 .18276 L

.77602 .18276 L

.77733 .18277 L

.77854 .18277 L

.77969 .18277 L

.78091 .18277 L

.7816 .18277 L

.78223 .18277 L

.78329 .18277 L

.78445 .18277 L

.78567 .18277 L

.78682 .18277 L

.78809 .18277 L

.78943 .18276 L

.79183 .18275 L

.79724 .18273 L

.80245 .18269 L

.80729 .18265 L

.8183 .18254 L

.83873 .18227 L

.85731 .18197 L

.89726 .18127 L

.93569 .18057 L

.97619 .17989 L

Mistroke

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  Evaluatable->False,

  AspectRatioFixed->True,

  ImageSize->{381, 235.375},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005m0000ja000`40O003h00OogooOWoo003oOomn

Ool00?moogioo`00dWoo0`005Goo0`00T7oo003BOol00`00Oomoo`0GOol00`00Oomoo`2>Ool00<Qo

o`<000Moo`04001oogooOol3000017oo000007oo1@0000Aoo`00001oo`8000Aoo`03001oogoo08io

o`00bGoo00<007ooOol01Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool01000

Oomoo`001Goo00<007ooOol0SWoo0039Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`00

0Woo00@007ooOol0009oo`04001oogoo0005Ool00`00Oomoo`2>Ool00<Uoo`03001oogoo00Ioo`03

001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo08io

o`00b7oo00<007oo00001goo00<007ooOol00Woo0P0000Eoo`00001oo`00009oo`800005Ool00000

Ool00005Ool00`00Oomoo`2>Ool00<Qoo`03001oo`0000Moo`04001oogooOol200001Goo001oogoo

00000Woo0P0000Eoo`00Oomoo`0000Ioo`03001oogoo08ioo`00b7oo00@007ooOol000Ioo`03001o

ogoo01Moo`03001oogoo08ioo`00agoo00<007ooOol00Woo00<007ooOol00goo0`005Goo0`00T7oo

0036Ool30002Ool3002_Ool00?moogioo`00ogooOWoo003oOomnOol00?moogioo`00ogooOWoo003o

OomnOol004aoo`<002Moo`<000Aoo`<002=oo`<000=oo`<000=oo`<0021oo`<0009oo`<000Aoo`<0

01moo`D0009oo`<000=oo`<001ioo`D00004Ool000000004Ool3000OOol40003Ool30003Ool3000@

Ool004]oo`05001oogooOol0000YOol01000Oomoo`000goo00<007ooOol08Goo00D007ooOomoo`00

00=oo`03001oo`0000=oo`03001oogoo01ioo`03001oogoo00Aoo`04001oogoo0003Ool00`00Oomo

o`0MOol01P00Oomoo`00Ool000=oo`03001oo`0000=oo`03001oogoo01aoo`04001oogoo0004Ool0

1000Oomoo`000goo00<007ooOol087oo00<007oo00000goo00<007oo00000goo00<007ooOol03Goo

001;Ool01@00Oomoogoo0000:Woo00<007oo00000goo00<007ooOol08Goo00D007ooOomoo`0000=o

o`03001oo`0000=oo`03001oogoo01ioo`03001oogoo00Eoo`03001oo`0000=oo`03001oogoo01io

o`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`0MOol00`00Oomoo`05Ool00`00Ool0

0003Ool00`00Oomoo`0POol00`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`0=Ool004]oo`05

001oogooOol0000ZOol00`00Ool00003Ool00`00Oomoo`0QOol01@00Oomoogoo00000goo00<007oo

00000goo00<007ooOol07Woo00<007ooOol01Goo00<007oo00000goo00<007ooOol07goo00@007oo

Ool000=oo`03001oo`0000=oo`03001oogoo01ioo`03001oogoo00Aoo`03001oo`0000=oo`03001o

ogoo021oo`03001oo`0000=oo`03001oo`0000=oo`03001oogoo00eoo`00Bgoo00D007ooOomoo`00

02Yoo`03001oo`0000=oo`03001oogoo025oo`05001oogooOol00003Ool00`00Ool00003Ool00`00

Oomoo`0NOol00`00Oomoo`05Ool00`00Ool00003Ool00`00Oomoo`0POol00`00Ool00003Ool00`00

Ool00003Ool00`00Oomoo`0OOol00`00Oomoo`03Ool00`00Ool00003Ool00`00Oomoo`0NOol20002

Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00eoo`00Bgoo00D007ooOomoo`0002Uoo`04001o

ogoo0003Ool00`00Oomoo`0QOol01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol07Woo

00<007ooOol017oo00@007ooOol000=oo`03001oogoo021oo`03001oo`0000=oo`03001oo`0000=o

o`03001oogoo01moo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`0OOol01000Oomoo`00

0goo00<007oo00000goo00<007ooOol03Goo001;Ool01@00Oomoogoo00009goo0P000goo00D007oo

Oomoo`0002=oo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`0NOol00`00Oomoo`02

Ool20003Ool01@00Oomoogoo00008Woo00<007oo00000goo00<007oo00000goo00<007ooOol07goo

00<007ooOol00P000goo00D007ooOomoo`00029oo`03001oo`0000=oo`03001oo`0000=oo`03001o

ogoo00eoo`00Bgoo00D007ooOomoo`0002Moo`03001oogoo009oo`05001oogooOol0000ROol20003

Ool01`00Oomoogoo001oo`0000=oo`03001oogoo01eoo`8000Aoo`03001oogoo009oo`05001oogoo

Ool0000NOol01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001oogoo01]oo`05001oogoo

Ool00002Ool00`00Oomoo`02Ool01@00Oomoogoo00007Woo00L007ooOomoo`00Ool00003Ool00`00

Ool00003Ool00`00Oomoo`0=Ool004aoo`<002Uoo`<0009oo`<002Aoo`03001oogoo009oo`<000=o

o`<0025oo`03001oogoo00=oo`<0009oo`<0021oo`<000=oo`<000=oo`<001moo`<000Aoo`<0009o

o`<0021oo`<000=oo`<000=oo`<0011oo`00ogooOWoo003oOomnOol00?moogioo`00ogooOWoo003o

OomnOol004Moool002P000moo`00Agoo00<007ooOol017oo00<007ooOol01Woo00<007ooOol01Woo

00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo

00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo

00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo

00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo

00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo

00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol03Goo

0017Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`00Oomoo`0/Ool00`00Oomoo`0/Ool00`00Oomo

o`0/Ool00`00Oomoo`0[Ool00`00Oomoo`0/Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool004Moo`03

001oogoo00Aoo`03001oogoo02]oo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`03

00moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol0

:goo00<03gooOol08Goo3P00;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<goo00<0

07ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`0?Oomoo`0MOol4000;Ool00`0?

Oomoo`06000VOol00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool0

04Moo`8000Eoo`03001oogoo02]oo`0300moogoo01Yoo`<000moo`0300moogoo00Ioo`8002Aoo`03

00moogoo02aoo`0300moogoo02]oo`0300moogoo039oo`8000moo`00Agoo00<007ooOol017oo00<0

07ooOol0:goo00<03gooOol05goo0`004Woo00<03gooOol027oo100087oo00<03gooOol0;7oo00<0

3gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0[

Ool00`0?Oomoo`0EOol2000EOol00`0?Oomoo`0<Ool5000KOol00`0?Oomoo`0/Ool00`0?Oomoo`0[

Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo02]oo`0300mo

ogoo01Aoo`03001oogoo01Eoo`0300moogoo015oo`<001Qoo`0300moogoo02aoo`0300moogoo02]o

o`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol0:goo00<03goo

Ool04goo00<007ooOol05Woo00<03gooOol057oo0P005Woo00<03gooOol0;7oo00<03gooOol0:goo

00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`0?Oomo

o`0BOol00`00Oomoo`0GOol00`0?Oomoo`0FOol2000DOol00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool0

0`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo02]oo`0300moogoo

015oo`03001oogoo01Qoo`0300moogoo01Qoo`03001oogoo015oo`0300moogoo02aoo`0300moogoo

02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo0P001Goo00<007ooOol0:goo00<03gooOol0

47oo00<007ooOol06Goo00<03gooOol06Goo0P004Goo00<03gooOol0;7oo00<03gooOol0:goo00<0

3gooOol0<Woo0P003goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`0?Oomoo`0?Ool00`00

Oomoo`0JOol00`0?Oomoo`0KOol2000?Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0c

Ool00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo02]oo`0300moogoo00ioo`03001o

ogoo01]oo`0300moogoo01eoo`03001oogoo00aoo`0300moogoo02aoo`0300moogoo02]oo`0300mo

ogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol0:goo00<03gooOol03Goo

00<007ooOol077oo00<03gooOol07Woo0P0037oo00<03gooOol0;7oo00<03gooOol0:goo00<03goo

Ool0<goo00<007ooOol03Goo000kOol30009Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`0?Oomo

o`0<Ool00`00Oomoo`0MOol00`0?Oomoo`0POol00`00Oomoo`09Ool00`0?Oomoo`0/Ool00`0?Oomo

o`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool003aoo`03001oogoo00Qoo`03001oogoo00Aoo`03

001oogoo02]oo`0300moogoo00]oo`03001oogoo01ioo`0300moogoo025oo`8000Uoo`0300moogoo

02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00?7oo00<007ooOol027oo0P00

1@0?00<0000?00l0>@0?00<0000?00l0A00?00<0000?00l0U`0?0`003goo000cOol70002Ool00`00

Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`0?Oomoo`0:Ool00`00Oomoo`0OOol00`0?

Oomoo`0TOol20006Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=

Ool003aoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo02]oo`0300moogoo00Yoo`03001o

ogoo01moo`0300moogoo02Ioo`03001oogoo00=oo`0300moogoo02aoo`0300moogoo02]oo`0300mo

ogoo03=oo`03001oogoo00eoo`00?7oo00<007ooOol027oo00<007ooOol017oo00<007ooOol0:goo

00<03gooOol02Goo00<007ooOol087oo00<03gooOol09goo0P000goo00<03gooOol0;7oo00<03goo

Ool0:goo00<03gooOol0<goo00<007ooOol03Goo000lOol00`00Oomoo`08Ool00`00Oomoo`04Ool0

0`00Oomoo`0[Ool00`0?Oomoo`08Ool00`00Oomoo`0QOol00`0?Oomoo`0YOol01000Oomoo`0?;Woo

00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo000kOol2000:Ool00`00Oomoo`04Ool0

0`00Oomoo`0[Ool00`0?Oomoo`08Ool00`00Oomoo`0QOol00`0?Oomoo`0ZOol200000`0?Oomoo`0/

Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool003aoo`03001oogoo00Qoo`03001o

ogoo00Aoo`03001oogoo02]oo`0300moogoo00Moo`03001oogoo029oo`0300moogoo02aoo`03001o

ogoo02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo0P001Goo00<007oo

Ool0:goo00<03gooOol01goo00<007ooOol08Woo00<03gooOol0;7oo00<03`00Ool0;7oo00<03goo

Ool0:goo00<03gooOol0<Woo0P003goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`0?Oomo

o`06Ool00`00Oomoo`0SOol00`0?Oomoo`0/Ool00`0?Ool0000/Ool00`0?Oomoo`0[Ool00`0?Oomo

o`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo02]oo`0300moogoo00Ioo`03

001oogoo02=oo`0300moogoo02aoo`0300moogoo008002Yoo`0300moogoo02]oo`0300moogoo03=o

o`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol0:goo00<03gooOol01Goo00<007oo

Ool097oo00<03gooOol0;7oo00<03gooOol00Woo00<007ooOol09goo00<03gooOol0:goo00<03goo

Ool0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`0?Oomoo`05Ool0

0`00Oomoo`0TOol00`0?Oomoo`0/Ool00`0?Oomoo`03Ool00`00Oomoo`0VOol00`0?Oomoo`0[Ool0

0`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo02]oo`0300moogoo

00Aoo`03001oogoo02Eoo`0300moogoo02aoo`0300moogoo00Aoo`03001oogoo02Eoo`0300moogoo

02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo0P001Goo00<007ooOol0:goo00<03gooOol0

17oo00<007ooOol09Goo00<03gooOol0;7oo00<03gooOol01Goo00<007ooOol097oo00<03gooOol0

:goo00<03gooOol0<Woo0P003goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`0?Oomoo`03

Ool00`00Oomoo`0VOol00`0?Oomoo`0/Ool00`0?Oomoo`06Ool2000TOol00`0?Oomoo`0[Ool00`0?

Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo02]oo`0300moogoo00=o

o`03001oogoo02Ioo`0300moogoo02aoo`0300moogoo00Qoo`03001oogoo025oo`0300moogoo02]o

o`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol0:goo00<03goo

Ool00goo00<007ooOol09Woo00<03gooOol0;7oo00<03gooOol02Goo00<007ooOol087oo00<03goo

Ool0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool0

0`0?Oomoo`02Ool00`00Oomoo`0WOol00`0?Oomoo`0/Ool00`0?Oomoo`0:Ool2000POol00`0?Oomo

o`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo02]oo`03

00moogoo009oo`03001oogoo02Moo`0300moogoo02aoo`0300moogoo00aoo`03001oogoo01eoo`03

00moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo0P001Goo00<007ooOol0:goo00<0

3gooOol00Woo00<007ooOol09goo00<03gooOol0;7oo00<03gooOol03Goo0P007Goo00<03gooOol0

:goo00<03gooOol0<Woo0P003goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool01@0?Oomoogoo

0000:Woo00<03gooOol0;7oo00<03gooOol03goo00<007ooOol06Woo00<03gooOol0:goo00<03goo

Ool0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool01@0?Oomoogoo0000

:Woo00<03gooOol0;7oo00<03gooOol047oo0P006Woo00<03gooOol0:goo00<03gooOol0<goo00<0

07ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool01@0?Oomoogoo0000:Woo00<03goo

Ool0;7oo00<03gooOol04Woo00<007ooOol05goo00<03gooOol0:goo00<03gooOol0<goo00<007oo

Ool03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool0100?Oomoo`00:goo00<03gooOol0;7oo

00<03gooOol04goo0P005goo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool0

0`00Oomoo`04Ool00`00Oomoo`0[Ool0100?Oomoo`00:goo00<03gooOol0;7oo00<03gooOol05Goo

00<007ooOol057oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomo

o`04Ool00`00Oomoo`0[Ool00`0?Ool0000/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0FOol2000DOol0

0`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`8000Eoo`03001oogoo02]oo`03

00moo`0002aoo`0300moogoo02aoo`0300moogoo01Qoo`80019oo`0300moogoo02]oo`0300moogoo

039oo`8000moo`00Agoo00<007ooOol017oo00<007ooOol0:goo00<03goo0000;7oo00<03gooOol0

;7oo00<03gooOol06Woo0P0047oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017

Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`0?001oo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0L

Ool4000<Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Ao

o`03001oogoo02]oo`0300l007oo02aoo`0300moogoo02aoo`0300moogoo021oo`<000Uoo`0300mo

ogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00?7oo0`0027oo00<007ooOol017oo00<007oo

Ool0:goo00<03`00Ool0;7oo00<03gooOol0;7oo00<03gooOol08goo0P001goo00<03gooOol0:goo

00<03gooOol0<goo00<007ooOol03Goo000kOol01@00Oomoogoo00001goo00<007ooOol017oo00<0

07ooOol0:goo00<007ooOol0;7oo00<03gooOol0;7oo00<03gooOol09Goo10000goo00<03gooOol0

:goo00<03gooOol0<goo00<007ooOol03Goo000kOol01@00Oomoogoo00001gooo`00:0003goo000k

Ool01@00Oomoogoo00001goo00<007ooOol017oo00<007ooOol0:goo00<007ooOol0;7oo00<03goo

Ool0;7oo00<03gooOol0;7oo00<03goo00001P009Goo00<03gooOol0<goo00<007ooOol03Goo000k

Ool01@00Oomoogoo00001goo00<007ooOol017oo00<007ooOol0:Woo00<0000?Ool0;Goo00<03goo

Ool0;7oo00<03gooOol0;7oo00<03gooOol01Woo40005Goo00<03gooOol00Woo:`001Woo00<007oo

Ool03Goo000kOol01@00Oomoogoo00001goo00<007ooOol017oo00<007ooOol0:Woo00<0000?Ool0

;Goo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol05Woo6P00<Goo00<007ooOol03Goo000k

Ool01@00Oomoogoo00001goo00<007ooOol017oo00<007ooOol0:Woo00<0000?Ool0;Goo00<03goo

Ool0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo000kOol0

1@00Oomoogoo00001goo00<007ooOol017oo00<007ooOol0:Woo00<0000?Ool0;Goo00<03gooOol0

;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo000lOol30008

Ool00`00Oomoo`04Ool00`00Oomoo`0YOol00`00Ool03`0^Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/

Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`8000Eoo`03001oogoo02Uo

o`03001oo`0?02ioo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300moogoo039o

o`8000moo`00Agoo00<007ooOol017oo00<007ooOol0:Goo00<007oo00l0;Woo00<03gooOol0;7oo

00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomo

o`04Ool00`00Oomoo`0YOol00`00Ool03`0^Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomo

o`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo02Qoo`04

001oogoo00l^Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol0

0`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo02Qoo`04001oogoo00l^Ool00`0?Oomo

o`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03

001oogoo00Aoo`03001oogoo02Qoo`04001oogoo00l^Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool0

0`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`8000Eoo`03001oogoo02Qoo`04

001oogoo00l^Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0bOol2

000?Ool004Moo`03001oogoo00Aoo`03001oogoo02Moo`05001oogooOol03`0^Ool00`0?Oomoo`0/

Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001o

ogoo00Aoo`03001oogoo02Moo`05001oogooOol03`0^Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool0

0`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo

02Moo`05001oogooOol03`0^Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?

Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo009o

o`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300moogoo03=o

o`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol09Woo00<007ooOol00Woo00<03goo

Ool0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<goo00<007oo

Ool03Goo0017Ool20005Ool00`00Oomoo`0VOol00`00Oomoo`02Ool00`0?Oomoo`0/Ool00`0?Oomo

o`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0bOol2000?Ool004Moo`03001oogoo

00Aoo`03001oogoo02Ioo`03001oogoo009oo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo

02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<0

07ooOol09Goo00<007ooOol00goo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<0

3gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0U

Ool00`00Oomoo`03Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[

Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo02Eoo`03001o

ogoo00=oo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300mo

ogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol09Goo00<007ooOol00goo

00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<goo

00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0TOol00`00Oomoo`04Ool00`0?Oomo

o`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomo

o`0=Ool004Moo`8000Eoo`03001oogoo02Aoo`03001oogoo00Aoo`0300moogoo02aoo`0300moogoo

02aoo`0300moogoo02aoo`0300moogoo02]oo`0300moogoo039oo`8000moo`00Agoo00<007ooOol0

17oo00<007ooOol097oo00<007ooOol017oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0

;7oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00

Oomoo`0SOol00`00Oomoo`05Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?

Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo02=o

o`03001oogoo00Eoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02]o

o`0300moogoo03=oo`03001oogoo00eoo`00?7oo0`0027oo00<007ooOol017oo00<007ooOol08goo

00<007ooOol01Goo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0:goo

00<03gooOol0<goo00<007ooOol03Goo000mOol00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomo

o`0SOol00`00Oomoo`05Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomo

o`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool003eoo`03001oogoo00Moo`8000D03`0300003`0?

02803`0300003`0?0?D03`<000moo`00?Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol0

8Woo00<007ooOol01Woo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0

:goo00<03gooOol0<goo00<007ooOol03Goo000mOol00`00Oomoo`07Ool00`00Oomoo`04Ool00`00

Oomoo`0ROol00`00Oomoo`06Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?

Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool003eoo`03001oogoo00Moo`03001oogoo00Ao

o`03001oogoo029oo`03001oogoo00Ioo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02ao

o`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`0077oo0`002Woo0`004Goo00<007oo

Ool01goo00<007ooOol017oo00<007ooOol08Goo00<007ooOol01goo00<03gooOol0;7oo00<03goo

Ool0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo000LOol0

0`00Oomoo`0<Ool00`00Oomoo`0>Ool20009Ool00`00Oomoo`04Ool00`00Oomoo`0QOol00`00Oomo

o`07Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomo

o`0cOol00`00Oomoo`0=Ool000aoo`H0009oo`D000=oo`03001oogoo00=oo`<000Ioo`03001oogoo

00moo`03001oogoo00Moo`8000Eoo`03001oogoo025oo`03001oogoo00Moo`0300moogoo02aoo`03

00moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300moogoo039oo`8000moo`003Goo00<0

07ooOol00Woo00@007ooOol0009oo`05001oogooOol00006Ool00`00Oomoo`05Ool00`00Oomoo`0I

Ool00`00Oomoo`04Ool00`00Oomoo`0QOol00`00Oomoo`07Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/

Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool000eoo`03001o

ogoo009oo`05001oogooOol00005Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0IOol0

0`00Oomoo`04Ool00`00Oomoo`0POol00`00Oomoo`08Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool0

0`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool000eoo`03001oogoo

009oo`05001oogooOol00005Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0IOol00`00

Oomoo`04Ool00`00Oomoo`0POol00`00Oomoo`08Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?

Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool000eoo`D0009oo`04001o

ogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0IOol00`00Oomoo`04Ool00`00

Oomoo`0POol00`00Oomoo`08Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?

Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool000eoo`05001oogooOol00002Ool50003Ool0

0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0IOol00`00Oomoo`04Ool00`00Oomoo`0OOol0

0`00Oomoo`09Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool0

0`0?Oomoo`0cOol00`00Oomoo`0=Ool000eoo`05001oogooOol0000:Ool00`00Oomoo`04Ool00`00

Oomoo`05Ool00`00Oomoo`0IOol00`00Oomoo`04Ool00`00Oomoo`0OOol00`00Oomoo`09Ool00`0?

Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00

Oomoo`0=Ool000eoo`05001oogooOol0000:Ool300001Goo001oogoo00000Woo00<007ooOol00`00

6goo0P001Goo00<007ooOol07goo00<007ooOol02Goo00<03gooOol0;7oo00<03gooOol0;7oo00<0

3gooOol0;7oo00<03gooOol0:goo00<03gooOol0<Woo0P003goo000<Ool5000?Ool7000POol00`00

Oomoo`04Ool00`00Oomoo`0OOol00`00Oomoo`09Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?

Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Ao

o`03001oogoo01ioo`03001oogoo00Yoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02ao

o`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007oo

Ool07Woo00<007ooOol02Woo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03goo

Ool0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0NOol0

0`00Oomoo`0:Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool0

0`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo01ioo`03001oogoo

00Yoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300moogoo

03=oo`03001oogoo00eoo`00Agoo0P001Goo00<007ooOol07Goo00<007ooOol02goo00<03gooOol0

;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<Woo0P003goo0017

Ool00`00Oomoo`04Ool00`00Oomoo`0MOol00`00Oomoo`0;Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/

Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001o

ogoo00Aoo`03001oogoo01eoo`03001oogoo00]oo`0300moogoo02aoo`0300moogoo02aoo`0300mo

ogoo02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo

00<007ooOol077oo00<007ooOol037oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo

00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomo

o`0LOol00`00Oomoo`0<Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomo

o`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo01aoo`03

001oogoo00aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`03

00moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol077oo00<007ooOol0

37oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0

<goo00<007ooOol03Goo0017Ool20005Ool00`00Oomoo`0KOol00`00Oomoo`0=Ool00`0?Oomoo`0/

Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0bOol2000?Ool004Mo

o`03001oogoo00Aoo`03001oogoo01]oo`03001oogoo00eoo`0300moogoo02aoo`0300moogoo02ao

o`0300moogoo02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007oo

Ool017oo00<007ooOol06goo00<007ooOol03Goo00<03gooOol0;7oo00<03gooOol0;7oo00<03goo

Ool0;7oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool0

0`00Oomoo`0KOol00`00Oomoo`0=Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool0

0`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool003]oo`D000Moo`03001oogoo00Aoo`03

001oogoo01Yoo`03001oogoo00ioo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`03

00moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00?7oo00@007ooOol000Moo`03001oogoo

00Aoo`03001oogoo01Yoo`03001oogoo00ioo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo

02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00?Goo00<007ooOol01goo0P00

1@0?00<0000?00l06P0?00<0000?00l0o@0?0`003goo000nOol00`00Oomoo`06Ool00`00Oomoo`04

Ool00`00Oomoo`0IOol00`00Oomoo`0?Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/

Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool003moo`03001oogoo00Eoo`03001o

ogoo00Aoo`03001oogoo01Uoo`03001oogoo00moo`0300moogoo02aoo`0300moogoo02aoo`0300mo

ogoo02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00?goo00<007ooOol01Goo

00<007ooOol017oo00<007ooOol06Goo00<007ooOol03goo00<03gooOol0;7oo00<03gooOol0;7oo

00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo000oOol00`00Oomo

o`05Ool00`00Oomoo`04Ool00`00Oomoo`0IOol00`00Oomoo`0?Ool00`0?Oomoo`0/Ool00`0?Oomo

o`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool003]oo`05

001oogooOol00007Ool00`00Oomoo`04Ool00`00Oomoo`0HOol00`00Oomoo`0@Ool00`0?Oomoo`0/

Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=

Ool003aoo`<000Qoo`8000Eoo`03001oogoo01Qoo`03001oogoo011oo`0300moogoo02aoo`0300mo

ogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300moogoo039oo`8000moo`00Agoo00<007oo

Ool017oo00<007ooOol067oo00<007ooOol047oo00<03gooOol0;7oo00<03gooOol0;7oo00<03goo

Ool0;7oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool0

0`00Oomoo`0HOol00`00Oomoo`0@Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool0

0`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo

01Moo`03001oogoo015oo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo

02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol05goo00<0

07ooOol04Goo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<0

3gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`0A

Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0c

Ool00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo01Ioo`03001oogoo019oo`0300mo

ogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300moogoo03=oo`03001o

ogoo00eoo`00Agoo0P001Goo00<007ooOol05Woo00<007ooOol04Woo00<03gooOol0;7oo00<03goo

Ool0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<Woo0P003goo0017Ool00`00Oomo

o`04Ool00`00Oomoo`0FOol00`00Oomoo`0BOol00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomo

o`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03

001oogoo01Ioo`03001oogoo019oo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`03

00moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol0

5Goo00<007ooOol04goo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0

:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0EOol00`00

Oomoo`0COol00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?

Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo01Eoo`03001oogoo01=o

o`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300moogoo03=o

o`03001oogoo00eoo`00Agoo0P001Goo00<007ooOol05Goo00<007ooOol04goo00<03gooOol0;7oo

00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<Woo0P003goo0017Ool0

0`00Oomoo`04Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool0

0`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo

00Aoo`03001oogoo01Aoo`03001oogoo01Aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo

02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<0

07ooOol057oo00<007ooOol057oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<0

3gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0C

Ool00`00Oomoo`0EOol00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[

Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo01=oo`03001o

ogoo01Eoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300mo

ogoo03=oo`03001oogoo00eoo`00Agoo0P001Goo00<007ooOol04goo00<007ooOol05Goo00<03goo

Ool0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<Woo0P003goo

0017Ool00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`0FOol00`0?Oomoo`0/Ool00`0?Oomo

o`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03

001oogoo00Aoo`03001oogoo019oo`03001oogoo01Ioo`0300moogoo02aoo`0300moogoo02aoo`03

00moogoo02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol0

17oo00<007ooOol04Woo00<007ooOol05Woo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0

;7oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00

Oomoo`0AOol00`00Oomoo`0GOol00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?

Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool003]oo`@000Qoo`03001oogoo00Aoo`03001o

ogoo015oo`03001oogoo01Moo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300mo

ogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00?goo00<007ooOol01Goo00<007ooOol017oo

00<007ooOol04Goo00<007ooOol05goo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo

00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo000oOol00`00Oomoo`05Ool2000500l0

0`0000l03`0A00l00`0000l03`3o00l700l3000?Ool003moo`03001oogoo00Eoo`03001oogoo00Ao

o`03001oogoo011oo`03001oogoo01Qoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02ao

o`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00?Goo0P0027oo00<007ooOol017oo

00<007ooOol047oo00<007ooOol067oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo

00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo000nOol00`00Oomoo`06Ool00`00Oomo

o`04Ool00`00Oomoo`0@Ool00`00Oomoo`0HOol00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomo

o`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool003moo`03001oogoo00Eoo`03

001oogoo00Aoo`03001oogoo00moo`03001oogoo01Uoo`0300moogoo02aoo`0300moogoo02aoo`03

00moogoo02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00>goo00D007ooOomo

o`0000Moo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo01Uoo`0300moogoo02aoo`0300mo

ogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00?7oo

0`0027oo0P001Goo00<007ooOol03goo00<007ooOol06Goo00<03gooOol0;7oo00<03gooOol0;7oo

00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<Woo0P003goo0017Ool00`00Oomoo`04Ool0

0`00Oomoo`0>Ool00`00Oomoo`0JOol00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool0

0`0?Oomoo`0[Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo

00ioo`03001oogoo01Yoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo

02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol03Goo00<0

07ooOol06goo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<0

3gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`0K

Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0c

Ool00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo01aoo`0300mo

ogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300moogoo03=oo`03001o

ogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol037oo00<007ooOol077oo00<03gooOol0;7oo

00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo

0017Ool20005Ool00`00Oomoo`0;Ool00`00Oomoo`0MOol00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool0

0`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0bOol2000?Ool004Moo`03001oogoo00Aoo`03

001oogoo00]oo`03001oogoo01eoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`03

00moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol0

2goo00<007ooOol07Goo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0

:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00

Oomoo`0NOol00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?

Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo01io

o`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300moogoo03=o

o`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol02Goo00<007ooOol07goo00<03goo

Ool0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<goo00<007oo

Ool03Goo0017Ool20005Ool00`00Oomoo`09Ool00`00Oomoo`0OOol00`0?Oomoo`0/Ool00`0?Oomo

o`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0bOol2000?Ool004Moo`03001oogoo

00Aoo`03001oogoo00Qoo`03001oogoo021oo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo

02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<0

07ooOol027oo00<007ooOol087oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<0

3gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00Oomoo`07

Ool00`00Oomoo`0QOol00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[

Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`03001oogoo00Ioo`03001o

ogoo029oo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300mo

ogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol017oo00<007ooOol01Woo00<007ooOol08Woo

00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<goo

00<007ooOol03Goo0017Ool20005Ool00`00Oomoo`05Ool00`00Oomoo`0SOol00`0?Oomoo`0/Ool0

0`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0bOol2000?Ool004Moo`03

001oogoo00Aoo`03001oogoo00Aoo`03001oogoo02Aoo`0300moogoo02aoo`0300moogoo02aoo`03

00moogoo02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00Agoo00<007ooOol0

17oo00<007ooOol017oo00<007ooOol097oo00<03gooOol0;7oo00<03gooOol0;7oo00<03gooOol0

;7oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo0017Ool00`00Oomoo`04Ool00`00

Oomoo`02Ool2000WOol00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[

Ool00`0?Oomoo`0cOol00`00Oomoo`0=Ool004Moo`03001oogoo00Aoo`05001oogooOol0000YOol0

0`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0[Ool00`0?Oomoo`0cOol0

0`00Oomoo`0=Ool003moo`03001oogoo00Eoo`03001oogoo00Aoo`@002Yoo`0300moogoo02aoo`03

00moogoo02aoo`0300moogoo02aoo`0300moogoo02]oo`0300moogoo03=oo`03001oogoo00eoo`00

?goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0:goo00<03gooOol0;7oo00<03gooOol0

;7oo00<03gooOol0;7oo00<03gooOol0:goo00<03gooOol0<goo00<007ooOol03Goo000kOol60006

Ool20005Ool00`00Oomoo`0[Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?Oomoo`0/Ool00`0?

Oomoo`0[Ool00`0?Oomoo`0aOol3000?Ool003]oo`05001oogooOol00007Ool00`00Oomoo`04Ool0

0`00Oomoo`0[Ool00`00Oomoo`0/Ool00`00Oomoo`0/Ool00`00Oomoo`0/Ool00`00Oomoo`0[Ool0

0`00Oomoo`0/Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool003aoo`04001oogoo0007Ool00`00Oomo

o`04Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo

o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo

o`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo

o`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo

o`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo

o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo

o`06Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool003eoo`03001oo`0000Moool002P000moo`00?Goo

00<007oo0000ogoo?Woo000nOol2003oOolnOol003moo`03001oogoo0?moocaoo`00ogooOWoo003o

OomnOol00?moogioo`00ogooOWoo003oOomnOol00<5oo`<0009oo`<000ioo`L000moo`<008eoo`00

`Woo00<007ooOol00Woo00<007ooOol00goo1`0017oo00<007ooOol00Woo00<007ooOol00Woo1`00

0goo00D007ooOomoo`0008aoo`00`goo00@007ooOol0015oo`03001oogoo009oo`03001oogoo00ao

o`05001oogooOol0002<Ool00<Aoo`8001=oo`03001oogoo011oo`05001oogooOol0002<Ool00<Eo

o`03001oogoo00Eoo`L000Ioo`03001oogoo00Eoo`L000=oo`05001oogooOol0002<Ool00<Aoo`80

01Aoo`03001oogoo00moo`05001oogooOol0002<Ool00<=oo`04001oogoo000DOol00`00Oomoo`0>

Ool01@00Oomoogoo0000S7oo0032Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool01@00Oomoogoo0000

3goo00D007ooOomoo`0008aoo`00`Goo0`000Woo0`003goo1P003goo0`00SGoo003oOomnOol00001

\

\>"],

  ImageRangeCache->{{{0, 380}, {234.375, 0}} -> {-83.4596, -2.66425, 1.06961, 

  0.0313395}}]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell["Plot the Field Integrals", "Section",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[TextData[StyleBox[

"This plots the vertical field integral along y for the transverse \

coordinates x varying from -400 to 400 mm.",

  Evaluatable->False,

  AspectRatioFixed->True]], "Text",

  Evaluatable->False,

  AspectRatioFixed->True],



Cell[CellGroupData[{



Cell["\<\

Plot[radFldInt[Grp,\"inf\",\"ibz\",{x,-300,0},{x,300,0}],{x,-400,400},

FrameLabel->{\"X [mm]\",\"IBz [T mm]\",\"Z = 0\",\"\"}];\

\>", "Input",

  AspectRatioFixed->True],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

/Times findfont 12  scalefont  setfont

% Scaling calculations

0.5 0.00119048 0.504222 0.00239829 [

[.02381 -0.0125 -15.5 -15 ]

[.02381 -0.0125 15.5 0 ]

[.2619 -0.0125 -15.5 -15 ]

[.2619 -0.0125 15.5 0 ]

[.5 -0.0125 -5 -15 ]

[.5 -0.0125 5 0 ]

[.7381 -0.0125 -11 -15 ]

[.7381 -0.0125 11 0 ]

[.97619 -0.0125 -11 -15 ]

[.97619 -0.0125 11 0 ]

[ 0 0 -0.125 0 ]

[.5 -0.0125 -21.5 -30 ]

[.5 -0.0125 21.5 -15 ]

[-0.0125 .02456 -31 -7.5 ]

[-0.0125 .02456 0 7.5 ]

[-0.0125 .14448 -31 -7.5 ]

[-0.0125 .14448 0 7.5 ]

[-0.0125 .26439 -31 -7.5 ]

[-0.0125 .26439 0 7.5 ]

[-0.0125 .38431 -25 -7.5 ]

[-0.0125 .38431 0 7.5 ]

[-0.0125 .50422 -10 -7.5 ]

[-0.0125 .50422 0 7.5 ]

[ 0 0 -0.125 0 ]

[-0.01875 .30902 -92 -7.5 ]

[-0.01875 .30902 -31 7.5 ]

[ 0 .61803 .125 0 ]

[.5 .63053 -15.5 0 ]

[.5 .63053 15.5 15 ]

[ 1 0 .125 0 ]

[ -0.0005 -0.0005 0 0 ]

[ 1.0005 .61853 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 0 .5 r

.25 Mabswid

.2619 0 m

.2619 .61803 L

s

.5 0 m

.5 .61803 L

s

.7381 0 m

.7381 .61803 L

s

0 .14448 m

1 .14448 L

s

0 .26439 m

1 .26439 L

s

0 .38431 m

1 .38431 L

s

0 .50422 m

1 .50422 L

s

0 g

.02381 0 m

.02381 .00625 L

s

gsave

.02381 -0.0125 -76.5 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(400) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.2619 0 m

.2619 .00625 L

s

gsave

.2619 -0.0125 -76.5 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(200) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.5 0 m

.5 .00625 L

s

gsave

.5 -0.0125 -66 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.7381 0 m

.7381 .00625 L

s

gsave

.7381 -0.0125 -72 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(200) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.97619 0 m

.97619 .00625 L

s

gsave

.97619 -0.0125 -72 -19 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(400) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

.08333 0 m

.08333 .00375 L

s

.14286 0 m

.14286 .00375 L

s

.20238 0 m

.20238 .00375 L

s

.32143 0 m

.32143 .00375 L

s

.38095 0 m

.38095 .00375 L

s

.44048 0 m

.44048 .00375 L

s

.55952 0 m

.55952 .00375 L

s

.61905 0 m

.61905 .00375 L

s

.67857 0 m

.67857 .00375 L

s

.79762 0 m

.79762 .00375 L

s

.85714 0 m

.85714 .00375 L

s

.91667 0 m

.91667 .00375 L

s

.25 Mabswid

0 0 m

1 0 L

s

gsave

.5 -0.0125 -82.5 -34 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(X) show

%%IncludeResource: font Math2

%%IncludeFont: Math2

/Math2 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

74.625000 14.625000 moveto

(@) show

78.562500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(mm) show

%%IncludeResource: font Math2

%%IncludeFont: Math2

/Math2 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

97.312500 14.625000 moveto

(D) show

101.250000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math2

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math2

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math2

%%DocumentFonts: + font Times-Roman

grestore

0 .02456 m

.00625 .02456 L

s

gsave

-0.0125 .02456 -92 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(200) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .14448 m

.00625 .14448 L

s

gsave

-0.0125 .14448 -92 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(150) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .26439 m

.00625 .26439 L

s

gsave

-0.0125 .26439 -92 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(100) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .38431 m

.00625 .38431 L

s

gsave

-0.0125 .38431 -86 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

71.312500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(50) show

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

0 .50422 m

.00625 .50422 L

s

gsave

-0.0125 .50422 -71 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

1.000000 setlinewidth

%%DocumentNeededResources: font Times-Roman

%%DocumentNeededFonts: Times-Roman

%%DocumentFonts: font Times-Roman

grestore

.125 Mabswid

0 .04855 m

.00375 .04855 L

s

0 .07253 m

.00375 .07253 L

s

0 .09651 m

.00375 .09651 L

s

0 .1205 m

.00375 .1205 L

s

0 .16846 m

.00375 .16846 L

s

0 .19244 m

.00375 .19244 L

s

0 .21643 m

.00375 .21643 L

s

0 .24041 m

.00375 .24041 L

s

0 .28838 m

.00375 .28838 L

s

0 .31236 m

.00375 .31236 L

s

0 .33634 m

.00375 .33634 L

s

0 .36032 m

.00375 .36032 L

s

0 .40829 m

.00375 .40829 L

s

0 .43227 m

.00375 .43227 L

s

0 .45626 m

.00375 .45626 L

s

0 .48024 m

.00375 .48024 L

s

0 .00058 m

.00375 .00058 L

s

0 .5282 m

.00375 .5282 L

s

0 .55219 m

.00375 .55219 L

s

0 .57617 m

.00375 .57617 L

s

0 .60015 m

.00375 .60015 L

s

.25 Mabswid

0 0 m

0 .61803 L

s

gsave

-0.01875 .30902 -153 -11.5 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(IBz) show

%%IncludeResource: font Math2

%%IncludeFont: Math2

/Math2 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

83.000000 14.625000 moveto

(@) show

86.937500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(T) show

97.250000 14.625000 moveto

(mm) show

%%IncludeResource: font Math2

%%IncludeFont: Math2

/Math2 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

116.000000 14.625000 moveto

(D) show

119.937500 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math2

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math2

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math2

%%DocumentFonts: + font Times-Roman

grestore

.02381 .61178 m

.02381 .61803 L

s

.2619 .61178 m

.2619 .61803 L

s

.5 .61178 m

.5 .61803 L

s

.7381 .61178 m

.7381 .61803 L

s

.97619 .61178 m

.97619 .61803 L

s

.125 Mabswid

.08333 .61428 m

.08333 .61803 L

s

.14286 .61428 m

.14286 .61803 L

s

.20238 .61428 m

.20238 .61803 L

s

.32143 .61428 m

.32143 .61803 L

s

.38095 .61428 m

.38095 .61803 L

s

.44048 .61428 m

.44048 .61803 L

s

.55952 .61428 m

.55952 .61803 L

s

.61905 .61428 m

.61905 .61803 L

s

.67857 .61428 m

.67857 .61803 L

s

.79762 .61428 m

.79762 .61803 L

s

.85714 .61428 m

.85714 .61803 L

s

.91667 .61428 m

.91667 .61803 L

s

.25 Mabswid

0 .61803 m

1 .61803 L

s

gsave

.5 .63053 -76.5 -4 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 23 translate 1 -1 scale

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(Z) show

73.187500 14.625000 moveto

%%IncludeResource: font Math1

%%IncludeFont: Math1

/Math1 findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(=) show

84.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(0) show

90.000000 14.625000 moveto

%%IncludeResource: font Times-Roman

%%IncludeFont: Times-Roman

/Times-Roman findfont 12.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

%%DocumentNeededResources: font Math1

%%DocumentNeededResources: + font Times-Roman

%%DocumentNeededFonts: Math1

%%DocumentNeededFont: + Times-Roman

%%DocumentFonts: font Math1

%%DocumentFonts: + font Times-Roman

grestore

.99375 .02456 m

1 .02456 L

s

.99375 .14448 m

1 .14448 L

s

.99375 .26439 m

1 .26439 L

s

.99375 .38431 m

1 .38431 L

s

.99375 .50422 m

1 .50422 L

s

.125 Mabswid

.99625 .04855 m

1 .04855 L

s

.99625 .07253 m

1 .07253 L

s

.99625 .09651 m

1 .09651 L

s

.99625 .1205 m

1 .1205 L

s

.99625 .16846 m

1 .16846 L

s

.99625 .19244 m

1 .19244 L

s

.99625 .21643 m

1 .21643 L

s

.99625 .24041 m

1 .24041 L

s

.99625 .28838 m

1 .28838 L

s

.99625 .31236 m

1 .31236 L

s

.99625 .33634 m

1 .33634 L

s

.99625 .36032 m

1 .36032 L

s

.99625 .40829 m

1 .40829 L

s

.99625 .43227 m

1 .43227 L

s

.99625 .45626 m

1 .45626 L

s

.99625 .48024 m

1 .48024 L

s

.99625 .00058 m

1 .00058 L

s

.99625 .5282 m

1 .5282 L

s

.99625 .55219 m

1 .55219 L

s

.99625 .57617 m

1 .57617 L

s

.99625 .60015 m

1 .60015 L

s

.25 Mabswid

1 0 m

1 .61803 L

s

.001 w

0 .50422 m

1 .50422 L

s

.5 0 m

.5 .61803 L

s

.002 w

.02381 .54224 m

.06244 .54963 L

.10458 .5602 L

.14415 .57318 L

.18221 .58836 L

.20342 .59684 L

.21345 .60019 L

.21786 .60139 L

.22037 .60197 L

.22272 .60244 L

.22515 .60283 L

.22738 .60309 L

.2286 .6032 L

.22977 .60327 L

.23099 .60331 L

.23168 .60332 L

.23233 .60332 L

.23298 .6033 L

.23369 .60328 L

.23498 .6032 L

.23623 .60307 L

.23738 .60292 L

.23863 .6027 L

.24 .60241 L

.24276 .60161 L

.24524 .60064 L

.24749 .59953 L

.24992 .59805 L

.25256 .59609 L

.25726 .59157 L

.26171 .58585 L

.26656 .57775 L

.27111 .56806 L

.27652 .55349 L

.28148 .53678 L

.29159 .49133 L

.30249 .4235 L

.32302 .25244 L

.33302 .1635 L

.34212 .09171 L

.34666 .06212 L

.34906 .04887 L

.35159 .03687 L

.35381 .0283 L

.35499 .02454 L

.35625 .02114 L

.35741 .01863 L

.35847 .01686 L

.35953 .01561 L

.36054 .01491 L

Mistroke

.36178 .01474 L

.36291 .01524 L

.36421 .0166 L

.36543 .01867 L

.36656 .02127 L

.36761 .02425 L

.36996 .03298 L

.37234 .04461 L

.37495 .06043 L

.38022 .10095 L

.40141 .3228 L

.40627 .37179 L

.41144 .41712 L

.41622 .45158 L

.4207 .47696 L

.42527 .49629 L

.42769 .50417 L

.4303 .51102 L

.43295 .51645 L

.43574 .52072 L

.43812 .52337 L

.43947 .52451 L

.44072 .52536 L

.44191 .526 L

.44319 .52652 L

.44441 .52687 L

.44553 .52707 L

.44654 .52716 L

.44764 .52718 L

.4488 .52711 L

.44988 .52697 L

.45115 .52672 L

.45235 .52641 L

.4546 .52567 L

.45966 .52345 L

.46841 .51885 L

.47786 .51428 L

.48326 .51222 L

.48563 .51149 L

.48822 .51081 L

.49051 .51032 L

.49296 .5099 L

.49432 .50973 L

.49555 .5096 L

.49679 .5095 L

.49796 .50944 L

.4991 .50941 L

.50035 .5094 L

.50166 .50943 L

.50289 .50948 L

Mistroke

.50403 .50956 L

.50508 .50966 L

.50743 .50996 L

.50995 .51041 L

.5127 .51104 L

.51771 .51256 L

.52298 .51464 L

.5286 .51731 L

.53871 .52263 L

.54372 .525 L

.54624 .52597 L

.54769 .52642 L

.549 .52675 L

.5497 .52689 L

.55045 .52702 L

.55125 .52711 L

.552 .52717 L

.55271 .52718 L

.55346 .52716 L

.5541 .52711 L

.5548 .52702 L

.55549 .52689 L

.55613 .52673 L

.55755 .52624 L

.55881 .52563 L

.56014 .5248 L

.56255 .52271 L

.56513 .51954 L

.56756 .51551 L

.56977 .51085 L

.57238 .50398 L

.5752 .49462 L

.58031 .4718 L

.58521 .44211 L

.58979 .40712 L

.6002 .3056 L

.611 .1871 L

.61632 .13267 L

.62125 .08857 L

.62596 .05457 L

.62859 .03976 L

.63097 .02922 L

.63224 .02473 L

.63359 .02089 L

.63429 .01925 L

.63507 .01774 L

.63578 .01663 L

.63642 .01583 L

.6377 .01489 L

.63841 .01472 L

Mistroke

.63908 .01478 L

.64026 .01543 L

.64155 .01689 L

.6427 .01884 L

.64378 .02121 L

.64623 .02844 L

.64862 .0378 L

.65119 .05017 L

.66009 .10784 L

.67979 .2778 L

.6902 .36766 L

.70131 .44937 L

.7121 .50982 L

.72189 .5485 L

.72661 .56236 L

.73173 .57435 L

.73656 .58319 L

.741 .58951 L

.7457 .59458 L

.74828 .59676 L

.75073 .59848 L

.75301 .59979 L

.75548 .60095 L

.75773 .60177 L

.75982 .60236 L

.761 .60263 L

.76227 .60286 L

.76347 .60304 L

.76458 .60316 L

.7658 .60325 L

.76649 .60329 L

.76714 .60331 L

.76844 .60332 L

.76917 .60331 L

.76983 .60329 L

.7705 .60325 L

.7712 .60321 L

.77246 .60311 L

.77382 .60296 L

.77531 .60276 L

.78048 .60178 L

.78569 .60044 L

.79063 .59891 L

.79992 .59559 L

.8208 .5871 L

.85904 .57201 L

.89972 .55898 L

.93889 .54934 L

.97619 .54224 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  Evaluatable->False,

  AspectRatioFixed->True,

  ImageSize->{334, 206.063},

  ImageMargins->{{0, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005>0000cQ000`40O003h00OogooCgoo003oOom?

Ool00?moodmoo`00ogooCgoo003oOom?Ool00?moodmoo`00ogooCgoo003oOom?Ool00?moodmoo`00

ogooCgoo003<Ool3000DOol3001XOol00<aoo`03001oogoo01Ioo`03001oogoo06Ioo`00`7oo0`00

0Woo0`0017oo00<007ooOol00`0000Aoo`00001oo`D00004Ool00000Ool20004Ool00`00Oomoo`1V

Ool00<5oo`03001oogoo009oo`03001oogoo00=oo`05001oogooOol00002Ool01000Oomoo`000Woo

00@007ooOol0009oo`03001oogoo00=oo`03001oogoo06Ioo`00`Woo00@007ooOol000Ioo`05001o

ogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo06Io

o`00`goo0P001goo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007oo

Ool00goo00<007ooOol0IWoo0034Ool00`00Oomoo`05Ool01000Oomoogoo0P0000Eoo`00001oo`00

009oo`800005Ool00000Ool00005Ool00`00Oomoo`1VOol00<=oo`8000Moo`03001oogoo00800005

Ool007ooOol00002Ool200001Goo001oogoo00001Woo00<007ooOol0IWoo0032Ool01000Oomoo`00

1Woo00<007ooOol05Woo00<007ooOol0IWoo0031Ool00`00Oomoo`02Ool00`00Oomoo`03Ool3000D

Ool3001XOol00<1oo`<0009oo`<008Ioo`00ogooCgoo003oOom?Ool00?moodmoo`00ogooCgoo003o

Oom?Ool00?moodmoo`00I7oo00<007ooOol00`000goo0`009goo1@000Woo0`000goo0`00:Woo0`00

;Goo1@000Woo0`000goo0`00;7oo00<007ooOol00`000goo0`001Goo001TOol00`00Ool00003Ool0

0`00Ool00003Ool00`00Oomoo`0UOol01P00Oomoo`00Ool000=oo`03001oo`0000=oo`03001oogoo

02Ioo`05001oogooOol0000]Ool01P00Oomoo`00Ool000=oo`03001oo`0000=oo`03001oogoo02Uo

o`03001oo`0000=oo`03001oo`0000=oo`03001oogoo009oo`00H7oo1`000goo00<007oo00000goo

00<007ooOol09Woo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo02Ioo`05001oogoo

Ool0000^Ool01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol09Goo1`000goo00<007oo

00000goo00<007ooOol00Woo001IOol80003Ool00`00Ool00003Ool00`00Ool00003Ool00`00Oomo

o`0MOol70003Ool01000Oomoo`000goo00<007oo00000goo00<007ooOol09Woo00D007ooOomoo`00

02moo`04001oogoo0003Ool00`00Ool00003Ool00`00Oomoo`0UOol01`00Oomoogoo001oo`0000=o

o`03001oo`0000=oo`03001oogoo009oo`00HGoo00H007ooOol007oo0003Ool00`00Ool00003Ool0

0`00Oomoo`0XOol00`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`0VOol01@00Oomoogoo0000

<7oo00<007oo00000goo00<007oo00000goo00<007ooOol09Woo00H007ooOol007oo0003Ool00`00

Ool00003Ool00`00Oomoo`02Ool0069oo`05001oo`00Ool00003Ool00`00Ool00003Ool00`00Oomo

o`0XOol00`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`0VOol01@00Oomoogoo0000<7oo00<0

07oo00000goo00<007oo00000goo00<007ooOol09goo00D007oo001oo`0000=oo`03001oo`0000=o

o`03001oogoo009oo`00HWoo00D007oo001oo`0000=oo`03001oo`0000=oo`03001oogoo02Qoo`03

001oo`0000=oo`03001oo`0000=oo`03001oogoo02Ioo`05001oogooOol0000`Ool00`00Ool00003

Ool00`00Ool00003Ool00`00Oomoo`0WOol01@00Ool007oo00000goo00<007oo00000goo00<007oo

Ool00Woo001SOol200000goo001oo`02Ool00`00Ool00003Ool00`00Oomoo`0TOol01`00Oomoogoo

001oo`0000=oo`03001oo`0000=oo`03001oogoo02Ioo`05001oogooOol0000/Ool01`00Oomoogoo

001oo`0000=oo`03001oo`0000=oo`03001oogoo02Qoo`800003Ool007oo009oo`03001oo`0000=o

o`03001oogoo009oo`00I7oo00<007ooOol00`000goo0`00:7oo0`000goo0`000goo0`00:Woo0`00

;Woo0`000goo0`000goo0`00;7oo00<007ooOol00`000goo0`001Goo003oOom?Ool00?moodmoo`00

ogooCgoo001POooX0006Ool0061oo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00]oo`03

001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03

001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03

001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo009oo`03

001oogoo00Aoo`00H7oo00<007ooOol0>Goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0

>Woo00<007ooOol017oo001POol00`00Oomoo`0iOol00`0?Oomoo`0DOol00`00Oomoo`0MOol00`00

Oomoo`0MOol2000EOol00`0?Oomoo`0jOol00`00Oomoo`04Ool004Qoo`D0009oo`<000=oo`<000Qo

o`03001oogoo03Uoo`0300moogoo01=oo`<001ioo`03001oogoo01aoo`<001Eoo`0300moogoo03Yo

o`03001oogoo00Aoo`00BGoo00H007ooOol007oo0003Ool00`00Ool00003Ool00`00Oomoo`05Ool0

0`00Oomoo`0iOol00`0?Oomoo`0COol01000Oomoo`007Goo00<007ooOol077oo00@007ooOol001Ao

o`0300moogoo03Yoo`03001oogoo00Aoo`00BWoo00D007ooOomoo`0000=oo`03001oo`0000=oo`03

001oogoo00Eoo`8003Yoo`0300moogoo01=oo`04001oogoo000MOol00`00Oomoo`0LOol01000Oomo

o`0057oo00<03gooOol0>Goo0P001Woo0011Ool70003Ool01000Oomoo`000goo00<007oo00000goo

00<007ooOol01Goo00<007ooOol0>Goo00<03gooOol04goo00@007ooOol001eoo`03001oogoo01ao

o`04001oogoo000DOol00`0?Oomoo`0jOol00`00Oomoo`04Ool004aoo`03001oo`0000=oo`03001o

o`0000=oo`03001oogoo00Eoo`03001oogoo03Uoo`0300moogoo019oo`05001oogooOol0000MOol0

0`00Oomoo`0KOol01@00Oomoogoo000057oo00<03gooOol0>Woo00<007ooOol017oo001<Ool00`00

Ool00003Ool00`00Ool00003Ool00`00Oomoo`05Ool00`00Oomoo`0iOol00`0?Oomoo`0BOol01@00

Oomoogoo00007Goo00<007ooOol06goo00<007ooOol00Woo00<007ooOol04Goo00<03gooOol0>Woo

00<007ooOol017oo001<Ool00`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`05Ool00`00Oomo

o`0iOol00`0?Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomo

o`02Ool00`00Oomoo`0AOol00`0?Oomoo`0jOol00`00Oomoo`04Ool004Qoo`07001oogooOol007oo

00000goo00<007oo00000goo00<007ooOol01Goo0P00>Woo00<03gooOol04Woo00<007ooOol00Woo

00<007ooOol06Woo00<007ooOol06goo00<007ooOol00Woo00<007ooOol04Goo00<03gooOol0>Goo

0P001Woo0019Ool30003Ool30003Ool30008Ool00`00Oomoo`0iOol00`0?Oomoo`0BOol00`00Oomo

o`02Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`0?Oomo

o`0jOol00`00Oomoo`04Ool0061oo`03001oogoo03Uoo`0300moogoo015oo`03001oogoo00Aoo`03

001oogoo01Uoo`03001oogoo01]oo`03001oogoo009oo`03001oogoo015oo`0300moogoo03Yoo`03

001oogoo00Aoo`00H7oo00<007ooOol0>Goo00<03gooOol04Goo00<007ooOol017oo00<007ooOol0

6Goo00<007ooOol06goo00<007ooOol00Woo00<007ooOol04Goo00<03gooOol0>Woo00<007ooOol0

17oo001POol00`00Oomoo`0iOol00`0?Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0IOol00`00

Oomoo`0JOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`0?Oomoo`0jOol00`00Oomoo`04Ool0061o

o`03001oogoo03Uoo`0300moogoo015oo`03001oogoo00Aoo`03001oogoo01Uoo`03001oogoo01Yo

o`03001oogoo00Aoo`03001oogoo011oo`0300moogoo03Yoo`03001oogoo00Aoo`00H7oo0P00>Woo

00<03gooOol04Goo00<007ooOol017oo00<007ooOol06Goo00<007ooOol06Woo00<007ooOol017oo

00<007ooOol047oo00<03gooOol0>Goo0P001Woo001POol00`00Oomoo`0iOol00`0?Oomoo`0@Ool0

0`00Oomoo`05Ool00`00Oomoo`0IOol00`00Oomoo`0JOol00`00Oomoo`04Ool00`00Oomoo`0@Ool0

0`0?Oomoo`0jOol00`00Oomoo`04Ool0061oo`03001oogoo03Uoo`0300moogoo011oo`03001oogoo

00Ioo`03001oogoo01Qoo`03001oogoo01Uoo`03001oogoo00Eoo`03001oogoo011oo`0300moogoo

03Yoo`03001oogoo00Aoo`00H7oo00<007ooOol0>Goo00<03gooOol047oo00<007ooOol01Woo00<0

07ooOol067oo00<007ooOol06Goo00<007ooOol01Goo00<007ooOol047oo00<03gooOol0>Woo00<0

07ooOol017oo001POol00`00Oomoo`0iOol00`0?Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`0H

Ool00`00Oomoo`0IOol00`00Oomoo`05Ool00`00Oomoo`0@Ool00`0?Oomoo`0jOol00`00Oomoo`04

Ool0061oo`8003Yoo`0300moogoo011oo`03001oogoo00Ioo`03001oogoo01Qoo`03001oogoo01Uo

o`03001oogoo00Ioo`03001oogoo00moo`0300moogoo03Uoo`8000Ioo`00H7oo00<007ooOol0>Goo

00<03gooOol047oo00<007ooOol01Woo00<007ooOol067oo00<007ooOol06Goo00<007ooOol01Woo

00<007ooOol03goo00<03gooOol0>Woo00<007ooOol017oo001POol00`00Oomoo`0iOol00`0?Oomo

o`0@Ool00`00Oomoo`06Ool00`00Oomoo`0HOol00`00Oomoo`0IOol00`00Oomoo`06Ool00`00Oomo

o`0?Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool0061oo`03001oogoo03Uoo`0300moogoo011oo`03

001oogoo00Ioo`03001oogoo01Qoo`03001oogoo01Uoo`03001oogoo00Ioo`03001oogoo00moo`03

00moogoo03Yoo`03001oogoo00Aoo`00H7oo00<007ooOol0>Goo00<03gooOol03goo00<007ooOol0

1goo00<007ooOol067oo00<007ooOol067oo00<007ooOol01goo00<007ooOol03goo00<03gooOol0

>Woo00<007ooOol017oo001POol00`00Oomoo`0iOol00`0?Oomoo`0?Ool00`00Oomoo`07Ool00`00

Oomoo`0HOol00`00Oomoo`0HOol00`00Oomoo`07Ool00`00Oomoo`0?Ool00`0?Oomoo`0jOol00`00

Oomoo`04Ool0061oo`8003Yoo`0300moogoo00moo`03001oogoo00Moo`03001oogoo01Qoo`03001o

ogoo01Qoo`03001oogoo00Moo`03001oogoo00moo`0300moogoo03Uoo`8000Ioo`00H7oo00<007oo

Ool0>Goo00<03gooOol03goo00<007ooOol027oo00<007ooOol05goo00<007ooOol067oo00<007oo

Ool027oo00<007ooOol03Woo00<03gooOol0>Woo00<007ooOol017oo001POol00`00Oomoo`0iOol0

0`0?Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`0GOol00`00Oomoo`0HOol00`00Oomoo`08Ool0

0`00Oomoo`0>Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool004Uoo`<0009oo`<000Aoo`<000Qoo`03

001oogoo03Uoo`0300moogoo00moo`03001oogoo00Qoo`03001oogoo01Moo`03001oogoo01Qoo`03

001oogoo00Qoo`03001oogoo00ioo`0300moogoo03Yoo`03001oogoo00Aoo`00BWoo00<007ooOol0

17oo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo03Uoo`0300moogoo00moo`03001oogoo

00Qoo`03001oogoo01Moo`03001oogoo01Qoo`03001oogoo00Qoo`03001oogoo00ioo`0300moogoo

03Yoo`03001oogoo00Aoo`00BWoo00<007ooOol01Goo00<007oo00000goo00<007ooOol01Goo0P00

C00?00<0000?00l0200?00<0000?00l05`0?00<0000?00l0600?00<0000?00l0200?00<0000?00l0

BP0?0P001Woo0011Ool70002Ool00`00Oomoo`05Ool00`00Ool00003Ool00`00Oomoo`05Ool00`00

Oomoo`0iOol00`0?Oomoo`0>Ool00`00Oomoo`09Ool00`00Oomoo`0GOol00`00Oomoo`0HOol00`00

Oomoo`08Ool00`00Oomoo`0>Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool004Yoo`03001oogoo00Eo

o`03001oo`0000=oo`03001oogoo00Eoo`03001oogoo03Uoo`0300moogoo00ioo`03001oogoo00Uo

o`03001oogoo01Moo`03001oogoo01Qoo`03001oogoo00Qoo`03001oogoo00ioo`0300moogoo03Yo

o`03001oogoo00Aoo`00BWoo00<007ooOol017oo00@007ooOol000=oo`03001oogoo00Eoo`03001o

ogoo03Uoo`0300moogoo00ioo`03001oogoo00Uoo`03001oogoo01Moo`03001oogoo01Qoo`03001o

ogoo00Qoo`03001oogoo00ioo`0300moogoo03Yoo`03001oogoo00Aoo`00BWoo00<007ooOol00Woo

0P000goo00D007ooOomoo`0000Moo`03001oogoo03Uoo`0300moogoo00ioo`03001oogoo00Uoo`03

001oogoo01Moo`03001oogoo01Moo`03001oogoo00Yoo`03001oogoo00eoo`0300moogoo03Yoo`03

001oogoo00Aoo`00BGoo0P0017oo00<007ooOol00Woo00D007ooOomoo`0000Moo`03001oogoo03Uo

o`0300moogoo00ioo`03001oogoo00Uoo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo00Yo

o`03001oogoo00eoo`0300moogoo03Yoo`03001oogoo00Aoo`00BWoo00<007ooOol00goo0`000Woo

0`0027oo0P00>Woo00<03gooOol03Woo00<007ooOol02Woo00<007ooOol05Woo00<007ooOol05goo

00<007ooOol02Woo00<007ooOol03Goo00<03gooOol0>Goo0P001Woo001POol00`00Oomoo`0iOol0

0`0?Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0:Ool0

0`00Oomoo`0=Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool0061oo`03001oogoo03Uoo`0300moogoo

00ioo`03001oogoo00Yoo`03001oogoo01Ioo`03001oogoo01Moo`03001oogoo00Yoo`03001oogoo

00eoo`0300moogoo03Yoo`03001oogoo00Aoo`00H7oo00<007ooOol0>Goo00<03gooOol03Woo00<0

07ooOol02Woo00<007ooOol05Woo00<007ooOol05goo00<007ooOol02Woo00<007ooOol03Goo00<0

3gooOol0>Woo00<007ooOol017oo001POol00`00Oomoo`0iOol00`0?Oomoo`0=Ool00`00Oomoo`0;

Ool00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`0?Oomoo`0j

Ool00`00Oomoo`04Ool0061oo`03001oogoo03Uoo`0300moogoo00eoo`03001oogoo00]oo`03001o

ogoo01Ioo`03001oogoo01Moo`03001oogoo00Yoo`03001oogoo00eoo`0300moogoo03Yoo`03001o

ogoo00Aoo`00H7oo0P00>Woo00<03gooOol03Goo00<007ooOol02goo00<007ooOol05Woo00<007oo

Ool05goo00<007ooOol02goo00<007ooOol037oo00<03gooOol0>Goo0P001Woo001POol00`00Oomo

o`0iOol00`0?Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomo

o`0;Ool00`00Oomoo`0<Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool0061oo`03001oogoo03Uoo`03

00moogoo00eoo`03001oogoo00]oo`03001oogoo01Ioo`03001oogoo01Moo`03001oogoo00]oo`03

001oogoo00aoo`0300moogoo03Yoo`03001oogoo00Aoo`00H7oo00<007ooOol0>Goo00<03gooOol0

3Goo00<007ooOol02goo00<007ooOol05Woo00<007ooOol05goo00<007ooOol02goo00<007ooOol0

37oo00<03gooOol0>Woo00<007ooOol017oo001POol00`00Oomoo`0iOol00`0?Oomoo`0=Ool00`00

Oomoo`0;Ool00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`0?

Oomoo`0jOol00`00Oomoo`04Ool0061oo`8003Yoo`0300moogoo00eoo`03001oogoo00aoo`03001o

ogoo01Eoo`03001oogoo01Ioo`03001oogoo00aoo`03001oogoo00aoo`0300moogoo03Uoo`8000Io

o`00H7oo00<007ooOol0>Goo00<03gooOol03Goo00<007ooOol037oo00<007ooOol05Goo00<007oo

Ool05Woo00<007ooOol037oo00<007ooOol037oo00<03gooOol0>Woo00<007ooOol017oo001POol0

0`00Oomoo`0iOol00`0?Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0EOol00`00Oomoo`0FOol0

0`00Oomoo`0<Ool00`00Oomoo`0<Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool0061oo`03001oogoo

03Uoo`0300moogoo00aoo`03001oogoo00eoo`03001oogoo01Eoo`03001oogoo01Ioo`03001oogoo

00eoo`03001oogoo00]oo`0300moogoo03Yoo`03001oogoo00Aoo`00H7oo00<007ooOol0>Goo00<0

3gooOol037oo00<007ooOol03Goo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol03Goo00<0

07ooOol02goo00<03gooOol0>Woo00<007ooOol017oo001POol00`00Oomoo`0iOol00`0?Oomoo`0<

Ool00`00Oomoo`0=Ool00`00Oomoo`0EOol00`00Oomoo`0FOol00`00Oomoo`0=Ool00`00Oomoo`0;

Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool0061oo`8003Yoo`0300moogoo00aoo`03001oogoo00eo

o`03001oogoo01Eoo`03001oogoo01Ioo`03001oogoo00eoo`03001oogoo00]oo`0300moogoo03Uo

o`8000Ioo`00H7oo00<007ooOol0>Goo00<03gooOol037oo00<007ooOol03Goo00<007ooOol05Goo

00<007ooOol05Woo00<007ooOol03Goo00<007ooOol02goo00<03gooOol0>Woo00<007ooOol017oo

001POol00`00Oomoo`0iOol00`0?Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0EOol00`00Oomo

o`0FOol00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool004Uoo`<0

00=oo`<000=oo`<000Qoo`03001oogoo03Uoo`0300moogoo00aoo`03001oogoo00eoo`03001oogoo

01Eoo`03001oogoo01Ioo`03001oogoo00eoo`03001oogoo00]oo`0300moogoo03Yoo`03001oogoo

00Aoo`00BWoo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo00Eoo`03001oogoo03Uo

o`0300moogoo00aoo`03001oogoo00ioo`03001oogoo01Aoo`03001oogoo01Ioo`03001oogoo00eo

o`03001oogoo00]oo`0300moogoo03Yoo`03001oogoo00Aoo`00BWoo00D007ooOomoo`0000=oo`03

001oo`0000=oo`03001oogoo00Eoo`8004T03`0300003`0?00h03`0300003`0?01@03`0300003`0?

01H03`0300003`0?00h03`0300003`0?04H03`8000Ioo`00@Goo1`000Woo00D007ooOomoo`0000=o

o`03001oo`0000=oo`03001oogoo00Eoo`03001oogoo03Uoo`0300moogoo00]oo`03001oogoo00mo

o`03001oogoo01Aoo`03001oogoo01Ioo`03001oogoo00ioo`03001oogoo00Yoo`0300moogoo03Yo

o`03001oogoo00Aoo`00BWoo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo00Eoo`03

001oogoo03Uoo`0300moogoo00]oo`03001oogoo00moo`03001oogoo01Aoo`03001oogoo01Ioo`03

001oogoo00ioo`03001oogoo00Yoo`0300moogoo03Yoo`03001oogoo00Aoo`00BWoo00D007ooOomo

o`0000=oo`03001oo`0000=oo`03001oogoo00Eoo`03001oogoo03Uoo`0300moogoo00]oo`03001o

ogoo00moo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo00moo`03001oogoo00Yoo`0300mo

ogoo03Yoo`03001oogoo00Aoo`00BWoo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo

00Eoo`03001oogoo03Uoo`0300moogoo00]oo`03001oogoo00moo`03001oogoo01Aoo`03001oogoo

01Eoo`03001oogoo00moo`03001oogoo00Yoo`0300moogoo03Yoo`03001oogoo00Aoo`00BGoo0P00

0goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`05Ool00`00Oomoo`0iOol00`0?Oomoo`0;Ool0

0`00Oomoo`0?Ool00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0?Ool00`00Oomoo`0:Ool0

0`0?Oomoo`0jOol00`00Oomoo`04Ool001Ioo`<001moo`<000moo`03001oogoo009oo`<000=oo`<0

00Qoo`8003Yoo`0300moogoo00]oo`03001oogoo00moo`03001oogoo01Aoo`03001oogoo01Eoo`03

001oogoo00moo`03001oogoo00Yoo`0300moogoo03Uoo`8000Ioo`005Woo00<007ooOol08Goo00<0

07ooOol08goo00<007ooOol0>Goo00<03gooOol02goo00<007ooOol03goo00<007ooOol057oo00<0

07ooOol05Goo00<007ooOol03goo00<007ooOol02Woo00<03gooOol0>Woo00<007ooOol017oo0002

Ool300000goo000000040002Ool50003Ool00`00Oomoo`02Ool30006Ool3000017oo000007oo1@00

00Aoo`00001oo`8000Aoo`03001oogoo02=oo`03001oogoo03Uoo`0300moogoo00]oo`03001oogoo

00moo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo00moo`03001oogoo00Yoo`0300moogoo

03Yoo`03001oogoo00Aoo`000goo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01@00Oomoogoo

00001Goo00<007ooOol01Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00<0

07ooOol08goo00<007ooOol0>Goo00<03gooOol02Woo00<007ooOol04Goo00<007ooOol04goo00<0

07ooOol05Goo00<007ooOol047oo00<007ooOol02Goo00<03gooOol0>Woo00<007ooOol017oo0003

Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo00Ioo`04

001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo02=oo`03001oogoo03Uo

o`0300moogoo00Yoo`03001oogoo015oo`03001oogoo01=oo`03001oogoo01Eoo`03001oogoo011o

o`03001oogoo00Uoo`0300moogoo03Yoo`03001oogoo00Aoo`000goo00D007ooOomoo`0000Aoo`05

001oogooOol00005Ool00`00Oomoo`03Ool00`00Oomoo`06Ool01000Oomoo`000Woo00@007ooOol0

009oo`04001oogoo0005Ool00`00Oomoo`0SOol2000jOol00`0?Oomoo`0:Ool00`00Oomoo`0AOol0

0`00Oomoo`0COol00`00Oomoo`0EOol00`00Oomoo`0@Ool00`00Oomoo`09Ool00`0?Oomoo`0iOol2

0006Ool000=oo`04001oogooOol50002Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol0

1Woo0P0000Eoo`00001oo`00009oo`800005Ool00000Ool00005Ool00`00Oomoo`0SOol00`00Oomo

o`0iOol00`0?Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0COol00`00Oomoo`0EOol00`00Oomo

o`0@Ool00`00Oomoo`09Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool000=oo`05001oogooOol00003

Ool00`00Oomoo`050003Ool00`00Oomoo`03Ool00`00Oomoo`05Ool200001Goo001oogoo00000Woo

0P0000Eoo`00Oomoo`0000Ioo`03001oogoo02=oo`03001oogoo03Uoo`0300moogoo00Yoo`03001o

ogoo015oo`03001oogoo01=oo`03001oogoo01Eoo`03001oogoo011oo`03001oogoo00Uoo`0300mo

ogoo03Yoo`03001oogoo00Aoo`000goo00D007ooOomoo`0000=oo`03001oogoo00Qoo`03001oogoo

00=oo`03001oogoo01]oo`03001oogoo02=oo`03001oogoo03Uoo`0300moogoo00Yoo`03001oogoo

015oo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo015oo`03001oogoo00Uoo`0300moogoo

03Yoo`03001oogoo00Aoo`000goo00D007ooOomoo`0000=oo`03001oogoo00Qoo`@0009oo`04001o

ogoo000HOol3000UOol00`00Oomoo`0iOol00`0?Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0C

Ool00`00Oomoo`0DOol00`00Oomoo`0AOol00`00Oomoo`09Ool00`0?Oomoo`0jOol00`00Oomoo`04

Ool0009oo`<00003Ool0000000<000ioo`L0041oo`03001oogoo03Uoo`0300moogoo00Yoo`03001o

ogoo015oo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo015oo`03001oogoo00Uoo`0300mo

ogoo03Yoo`03001oogoo00Aoo`00H7oo0P00>Woo00<03gooOol02Goo00<007ooOol04Woo00<007oo

Ool04goo00<007ooOol057oo00<007ooOol04Goo00<007ooOol02Goo00<03gooOol0>Goo0P001Woo

001POol00`00Oomoo`0iOol00`0?Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomo

o`0DOol00`00Oomoo`0AOol00`00Oomoo`09Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool0061oo`03

001oogoo03Uoo`0300moogoo00Uoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo01Aoo`03

001oogoo019oo`03001oogoo00Qoo`0300moogoo03Yoo`03001oogoo00Aoo`00H7oo00<007ooOol0

>Goo00<03gooOol02Goo00<007ooOol04goo00<007ooOol04Woo00<007ooOol057oo00<007ooOol0

4Woo00<007ooOol027oo00<03gooOol0>Woo00<007ooOol017oo001POol00`00Oomoo`0iOol00`0?

Oomoo`09Ool00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0DOol00`00Oomoo`0BOol00`00

Oomoo`08Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool0061oo`8003Yoo`0300moogoo00Uoo`03001o

ogoo01=oo`03001oogoo019oo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo00Qoo`0300mo

ogoo03Uoo`8000Ioo`00H7oo00<007ooOol0>Goo00<03gooOol02Goo00<007ooOol04goo00<007oo

Ool04Woo00<007ooOol04goo00<007ooOol04goo00<007ooOol027oo00<03gooOol0>Woo00<007oo

Ool017oo001POol00`00Oomoo`0iOol00`0?Oomoo`09Ool00`00Oomoo`0COol00`00Oomoo`0BOol0

0`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`08Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool0

061oo`03001oogoo03Uoo`0300moogoo00Qoo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo

01=oo`03001oogoo01=oo`03001oogoo00Qoo`0300moogoo03Yoo`03001oogoo00Aoo`00CWoo0`00

17oo0`0027oo00<007ooOol0>Goo00<03gooOol027oo00<007ooOol057oo00<007ooOol04Woo00<0

07ooOol04goo00<007ooOol04goo00<007ooOol027oo00<03gooOol0>Woo00<007ooOol017oo001A

Ool01000Oomoo`000goo00<007ooOol01Goo00<007ooOol0>Goo00<03gooOol027oo00<007ooOol0

57oo00<007ooOol04Woo00<007ooOol04goo00<007ooOol04goo00<007ooOol027oo00<03gooOol0

>Woo00<007ooOol017oo001BOol00`00Ool00003Ool00`00Oomoo`05Ool2001500l00`0000l03`0D

00l00`0000l03`0B00l00`0000l03`0C00l00`0000l03`0D00l00`0000l03`1300l20006Ool004Mo

o`L000Aoo`03001oo`0000=oo`03001oogoo00Eoo`03001oogoo03Uoo`0300moogoo00Qoo`03001o

ogoo01Aoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo01Aoo`03001oogoo00Moo`0300mo

ogoo03Yoo`03001oogoo00Aoo`00DWoo00<007oo00000goo00<007ooOol01Goo00<007ooOol0>Goo

00<03gooOol027oo00<007ooOol057oo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol05Goo

00<007ooOol01goo00<03gooOol0>Woo00<007ooOol017oo001AOol01000Oomoo`000goo00<007oo

Ool01Goo00<007ooOol0>Goo00<03gooOol027oo00<007ooOol05Goo00<007ooOol04Goo00<007oo

Ool04Woo00<007ooOol05Goo00<007ooOol01goo00<03gooOol0>Woo00<007ooOol017oo001?Ool2

0003Ool01@00Oomoogoo00001goo00<007ooOol0>Goo00<03gooOol027oo00<007ooOol05Goo00<0

07ooOol04Goo00<007ooOol04Woo00<007ooOol05Goo00<007ooOol01goo00<03gooOol0>Woo00<0

07ooOol017oo001?Ool00`00Oomoo`02Ool01@00Oomoogoo00001goo0P00>Woo00<03gooOol01goo

00<007ooOol05Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol05Goo00<007ooOol01goo

00<03gooOol0>Goo0P001Woo001@Ool30002Ool30008Ool00`00Oomoo`0iOol00`0?Oomoo`07Ool0

0`00Oomoo`0FOol00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`0FOol00`00Oomoo`06Ool0

0`0?Oomoo`0jOol00`00Oomoo`04Ool0061oo`03001oogoo03Uoo`0300moogoo00Moo`03001oogoo

01Ioo`03001oogoo015oo`03001oogoo019oo`03001oogoo01Ioo`03001oogoo00Ioo`0300moogoo

03Yoo`03001oogoo00Aoo`00H7oo00<007ooOol0>Goo00<03gooOol01goo00<007ooOol05Woo00<0

07ooOol04Goo00<007ooOol04Woo00<007ooOol05Woo00<007ooOol01Woo00<03gooOol0>Woo00<0

07ooOol017oo001POol00`00Oomoo`0iOol00`0?Oomoo`07Ool00`00Oomoo`0FOol00`00Oomoo`0A

Ool00`00Oomoo`0AOol00`00Oomoo`0GOol00`00Oomoo`06Ool00`0?Oomoo`0jOol00`00Oomoo`04

Ool0061oo`03001oogoo03Uoo`0300moogoo00Moo`03001oogoo01Ioo`03001oogoo015oo`03001o

ogoo015oo`03001oogoo01Moo`03001oogoo00Ioo`0300moogoo03Yoo`03001oogoo00Aoo`00H7oo

0P00>Woo00<03gooOol01goo00<007ooOol05Woo00<007ooOol04Goo00<007ooOol04Goo00<007oo

Ool05goo00<007ooOol01Woo00<03gooOol0>Goo0P001Woo001POol00`00Oomoo`0iOol00`0?Oomo

o`06Ool00`00Oomoo`0HOol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0HOol00`00Oomo

o`05Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool0061oo`03001oogoo03Uoo`0300moogoo00Ioo`03

001oogoo01Qoo`03001oogoo011oo`03001oogoo015oo`03001oogoo01Qoo`03001oogoo00Eoo`03

00moogoo03Yoo`03001oogoo00Aoo`00H7oo00<007ooOol0>Goo00<03gooOol01Woo00<007ooOol0

67oo00<007ooOol047oo00<007ooOol04Goo00<007ooOol067oo00<007ooOol01Goo00<03gooOol0

>Woo00<007ooOol017oo001POol00`00Oomoo`0iOol00`0?Oomoo`06Ool00`00Oomoo`0HOol00`00

Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0HOol00`00Oomoo`05Ool00`0?Oomoo`0jOol00`00

Oomoo`04Ool0061oo`03001oogoo03Uoo`0300moogoo00Ioo`03001oogoo01Qoo`03001oogoo011o

o`03001oogoo015oo`03001oogoo01Qoo`03001oogoo00Eoo`0300moogoo03Yoo`03001oogoo00Ao

o`00H7oo0P00>Woo00<03gooOol01Goo00<007ooOol06Goo00<007ooOol047oo00<007ooOol047oo

00<007ooOol06Goo00<007ooOol01Goo00<03gooOol0>Goo0P001Woo001POol00`00Oomoo`0iOol0

0`0?Oomoo`05Ool00`00Oomoo`0IOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0IOol0

0`00Oomoo`05Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool0061oo`03001oogoo03Uoo`0300moogoo

00Eoo`03001oogoo01Yoo`03001oogoo00moo`03001oogoo011oo`03001oogoo01Yoo`03001oogoo

00Aoo`0300moogoo03Yoo`03001oogoo00Aoo`00H7oo00<007ooOol0>Goo00<03gooOol01Goo00<0

07ooOol06Woo00<007ooOol03goo00<007ooOol047oo00<007ooOol06Woo00<007ooOol017oo00<0

3gooOol0>Woo00<007ooOol017oo001POol00`00Oomoo`0iOol00`0?Oomoo`05Ool00`00Oomoo`0J

Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0JOol00`00Oomoo`04Ool00`0?Oomoo`0j

Ool00`00Oomoo`04Ool0061oo`8003Yoo`0300moogoo00Eoo`03001oogoo01Yoo`03001oogoo00mo

o`03001oogoo011oo`03001oogoo01Yoo`03001oogoo00Aoo`0300moogoo03Uoo`8000Ioo`00H7oo

00<007ooOol0>Goo00<03gooOol017oo00<007ooOol06goo00<007ooOol03goo00<007ooOol03goo

00<007ooOol06goo00<007ooOol017oo00<03gooOol0>Woo00<007ooOol017oo001POol00`00Oomo

o`0iOol00`0?Oomoo`04Ool00`00Oomoo`0LOol00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomo

o`0KOol00`00Oomoo`04Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool005Ioo`<000Moo`03001oogoo

03Uoo`0300moogoo00Aoo`03001oogoo01aoo`03001oogoo00ioo`03001oogoo00moo`03001oogoo

01]oo`03001oogoo00Aoo`0300moogoo03Yoo`03001oogoo00Aoo`00EGoo00D007ooOomoo`0000Io

o`03001oogoo03Uoo`0300moogoo00Aoo`03001oogoo01aoo`03001oogoo00ioo`03001oogoo00mo

o`03001oogoo01aoo`03001oogoo00=oo`0300moogoo03Yoo`03001oogoo00Aoo`00EGoo00D007oo

Oomoo`0000Ioo`03001oogoo03Uoo`0300moogoo00Aoo`03001oogoo01aoo`03001oogoo00ioo`03

001oogoo00ioo`03001oogoo01eoo`03001oogoo00=oo`0300moogoo03Yoo`03001oogoo00Aoo`00

EGoo00D007ooOomoo`0000IoonP000Ioo`00EGoo00D007ooOomoo`0000Ioo`03001oogoo03Uoo`03

00moogoo00=oo`03001oogoo01ioo`03001oogoo00Yoo`L000eoo`03001oogoo01eoo`03001oogoo

00=oo`0300moogoo03Yoo`03001oogoo00Aoo`00EGoo00D007ooOomoo`0000Ioo`03001oogoo03Uo

o`0300moogoo00=oo`03001oogoo01moo`03001oogoo00Moo`8000=oo`04001oogooOol30009Ool0

0`00Oomoo`0NOol00`00Oomoo`03Ool00`0?Oomoo`0jOol00`00Oomoo`04Ool005Eoo`05001oogoo

Ool00006Ool00`00Oomoo`0iOol00`0?Oomoo`03Ool00`00Oomoo`0POol00`00Oomoo`04Ool20005

Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0POol00`00Oomoo`02Ool00`0?Oomoo`0j

Ool00`00Oomoo`04Ool005Eoo`05001oogooOol00006Ool00`00Oomoo`0iOol00`0?Oomoo`03Ool0

0`00Oomoo`0POol20003Ool20007Ool00`00Oomoo`05Ool40002Ool2000ROol00`00Oomoo`02Ool0

0`0?Oomoo`0jOol00`00Oomoo`04Ool005Ioo`<000Moo`8003Yoo`0300moogoo009oo`03001oogoo

029oo`@000Uoo`03001oogoo00Qoo`@002=oo`03001oogoo009oo`0300moogoo03Uoo`8000Ioo`00

H7oo00<007ooOol0>Goo00<03gooOol00Woo00<007ooOol0;goo00<007ooOol0<7oo00D007ooOomo

o`0?03aoo`03001oogoo00Aoo`00H7oo00<007ooOol0>Goo00<03gooOol00Woo00<007ooOol0;goo

00<007ooOol0<7oo00D007ooOomoo`0?03aoo`03001oogoo00Aoo`00H7oo00<007ooOol00Woo0`00

=7oo00<03gooOol00Woo00<007ooOol0;goo00<007ooOol0<7oo00D007ooOomoo`0?03Eoo`<000Ao

o`03001oogoo00Aoo`00H7oo00<007ooOol01Goo1000<7oo00D03gooOomoo`00039oo`03001oogoo

035oo`04001oogoo00laOol40007Ool00`00Oomoo`04Ool0061oo`03001oogoo00Uoo`@002aoo`05

00moogooOol0000bOol00`00Oomoo`0aOol01000Oomoo`0?;7oo1@002goo00<007ooOol017oo001P

Ool2000>Ool3000YOol01@0?Oomoogoo0000<Woo00<007ooOol0<Goo00@007ooOol03bQoo`@000mo

o`8000Ioo`00H7oo00<007ooOol047oo10009Goo00D03gooOomoo`00039oo`03001oogoo039oo`03

001oo`0?02Aoo`@001Aoo`03001oogoo00Aoo`00H7oo00<007ooOol057oo0`008Woo00@03gooOol0

03=oo`03001oogoo039oo`03001oo`0?025oo`<001Qoo`03001oogoo00Aoo`00H7oo00<007ooOol0

5goo0`007goo00@03gooOol003=oo`03001oogoo039oo`03001oo`0?01eoo`@001]oo`03001oogoo

00Aoo`00H7oo00<007ooOol06Woo0`0077oo00<03goo0000=7oo00<007ooOol0<goo00<0000?Ool0

6Woo0P007goo00<007ooOol017oo001POol2000NOol3000IOol00`0?Ool0000dOol00`00Oomoo`0c

Ool00`0000moo`0HOol2000POol20006Ool0061oo`03001oogoo021oo`<001Ioo`0300l007oo03Ao

o`03001oogoo03=oo`0300003goo01Ioo`8002=oo`03001oogoo00Aoo`00H7oo00<007ooOol08goo

0`004goo00<007ooOol0=7oo00<007ooOol0=7oo00<007ooOol04goo0P009Goo00<007ooOol017oo

001POol00`00Oomoo`0VOol3000?Ool00`0000moo`0eOol00`00Oomoo`0dOol00`0?001oo`0@Ool3

000WOol00`00Oomoo`04Ool0061oo`03001oogoo02Uoo`8000eoo`0300003goo03Eoo`03001oogoo

03Aoo`0300moo`0000ioo`8002Yoo`03001oogoo00Aoo`00H7oo00<007ooOol0:goo0P002Woo00<0

07oo00l0=Woo00<007ooOol0=7oo00@03gooOol000Uoo`@002aoo`03001oogoo00Aoo`00H7oo0P00

;Woo2P000Woo00<03gooOol0=7oo00<007ooOol0=7oo00@03gooOomoo`T002moo`8000Ioo`00H7oo

00<007ooOol0<Woo0P001Goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol017oo00<007oo

Ool0<goo00<007ooOol017oo001POol00`00Oomoo`02Ool00`00Oomoo`0dOol00`00Oomoo`0dOol0

0`00Oomoo`0dOol00`00Oomoo`0eOol00`00Oomoo`02Ool00`00Oomoo`04Ool0061oo`03001oogoo

009oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo

00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo

00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo

00]oo`03001oogoo00]oo`03001oogoo009oo`03001oogoo00Aoo`00H7ooj0001Woo003oOom?Ool0

0?moodmoo`00ogooCgoo003oOom?Ool00?moodmoo`00ogooCgoo003oOom?Ool00<Ioo`L000moo`<0

06moo`00agoo00<007ooOol00Woo00<007ooOol00Woo1`000goo00D007ooOomoo`0006ioo`00agoo

00<007ooOol00Woo00<007ooOol037oo00D007ooOomoo`0006ioo`00b7oo00<007ooOol047oo00D0

07ooOomoo`0006ioo`00bGoo00<007ooOol01Goo1`000goo00D007ooOomoo`0006ioo`00bGoo00<0

07ooOol03goo00D007ooOomoo`0006ioo`00bWoo00<007ooOol03Woo00D007ooOomoo`0006ioo`00

agoo00D007ooOomoo`0000moo`05001oogooOol0001^Ool00<Moo`H000moo`<006moo`00ogooCgoo

003oOom?Ool00?moodmoo`00ogooCgoo003oOom?Ool00?moodmoo`00ogooCgoo0000\

\>"],

  ImageRangeCache->{{{0, 333}, {205.063, 0}} -> {-770.055, -279.861, 3.63372, 

  1.80373}}]

}, Open  ]]

}, Open  ]]

},

FrontEndVersion->"Microsoft Windows 3.0",

ScreenRectangle->{{0, 1280}, {0, 968}},

WindowToolbars->{},

CellGrouping->Manual,

WindowSize->{551, 531},

WindowMargins->{{56, Automatic}, {Automatic, 34}},

PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},

ShowCellLabel->False,

ShowCellTags->False,

RenderingOptions->{"ObjectDithering"->True,

"RasterDithering"->False},

CharacterEncoding->"MacintoshAutomaticEncoding",

StyleDefinitions -> "Classroom.nb"

]





(***********************************************************************

Cached data follows.  If you edit this Notebook file directly, not using

Mathematica, you must remove the line containing CacheID at the top of 

the file.  The cache data will then be recreated when you save this file 

from within Mathematica.

***********************************************************************)



(*CellTagsOutline

CellTagsIndex->{}

*)



(*CellTagsIndex

CellTagsIndex->{}

*)



(*NotebookFileOutline

Notebook[{

Cell[1709, 49, 143, 3, 43, "Title"],

Cell[1855, 54, 77, 2, 29, "Text"],



Cell[CellGroupData[{

Cell[1957, 60, 79, 2, 56, "Section"],

Cell[2039, 64, 2213, 53, 338, "Text"]

}, Open  ]],



Cell[CellGroupData[{

Cell[4289, 122, 102, 2, 56, "Section"],

Cell[4394, 126, 222, 6, 29, "Text"],

Cell[4619, 134, 52, 1, 50, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[4708, 140, 85, 2, 56, "Section"],

Cell[4796, 144, 299, 7, 48, "Text"],

Cell[5098, 153, 761, 26, 464, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[5896, 184, 105, 2, 56, "Section"],

Cell[6004, 188, 924, 26, 105, "Text"],

Cell[6931, 216, 62, 1, 50, "Input"]

}, Open  ]],



Cell[CellGroupData[{

Cell[7030, 222, 94, 2, 56, "Section"],

Cell[7127, 226, 198, 5, 29, "Text"],



Cell[CellGroupData[{

Cell[7350, 235, 283, 12, 212, "Input"],

Cell[7636, 249, 164990, 6680, 361, 131303, 6258, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[172675, 6935, 90, 2, 56, "Section"],

Cell[172768, 6939, 207, 5, 29, "Text"],



Cell[CellGroupData[{

Cell[173000, 6948, 187, 6, 104, "Input"],

Cell[173190, 6956, 51996, 1417, 244, 18498, 997, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[225235, 8379, 91, 2, 56, "Section"],

Cell[225329, 8383, 243, 6, 29, "Text"],



Cell[CellGroupData[{

Cell[225597, 8393, 178, 4, 86, "Input"],

Cell[225778, 8399, 45429, 1305, 215, 18507, 967, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]]

}

]

*)









(***********************************************************************

End of Mathematica Notebook file.

***********************************************************************)



